@@ -117,7 +117,7 @@ usefile = False
 filename = ""
 
 
-def main(argv=None):
+def main(argv=None):  # noqa: PLR0912, PLR0915
     # pylint: disable=global-statement
     # pylint: disable=too-many-branches
     # pylint: disable=too-many-locals
@@ -132,7 +132,7 @@ def main(argv=None):
 
     argv = argv if argv else sys.argv[1:]
     utils.subprocess_setup()
-    global filename, usefile
+    global filename, usefile  # noqa: PLW0603
     utils.pcs_options = {}
 
     # we want to support optional arguments for --wait, so if an argument
@@ -144,7 +144,8 @@ def main(argv=None):
             tempsecs = arg.replace("--wait=", "")
             if tempsecs:
                 waitsecs = tempsecs
-                arg = "--wait"
+                new_argv.append("--wait")
+                continue
         new_argv.append(arg)
     argv = new_argv
 
@@ -180,13 +181,13 @@ def main(argv=None):
         sys.exit(1)
 
     full = False
-    for option, dummy_value in pcs_options:
+    for option, _ in pcs_options:
         if option == "--full":
             full = True
             break
 
     for opt, val in pcs_options:
-        if not opt in utils.pcs_options:
+        if opt not in utils.pcs_options:
             utils.pcs_options[opt] = val
         else:
             # If any options are a list then they've been entered twice which
