@@ -1,5 +1,5 @@
 class Env:
-    # pylint: disable=too-many-instance-attributes, too-few-public-methods
+    # pylint: disable=too-many-instance-attributes
     def __init__(self):
         self.cib_data = None
         self.user = None
@@ -10,3 +10,4 @@ class Env:
         self.known_hosts_getter = None
         self.debug = False
         self.request_timeout = None
+        self.report_processor = None
