@@ -95,14 +95,14 @@ def bind(cli_env, run_with_middleware, run_library_command):
 
 def bind_all(env, run_with_middleware, dictionary):
     return wrapper(
-        dict(
-            (exposed_fn, bind(env, run_with_middleware, library_fn))
+        {
+            exposed_fn: bind(env, run_with_middleware, library_fn)
             for exposed_fn, library_fn in dictionary.items()
-        )
+        }
     )
 
 
-def load_module(env, middleware_factory, name):
+def load_module(env, middleware_factory, name):  # noqa: PLR0911, PLR0912
     # pylint: disable=too-many-branches
     # pylint: disable=too-many-return-statements
     if name == "acl":
@@ -140,6 +140,7 @@ def load_module(env, middleware_factory, name):
                 "update_recipient": alert.update_recipient,
                 "remove_recipient": alert.remove_recipient,
                 "get_all_alerts": alert.get_all_alerts,
+                "get_config_dto": alert.get_config_dto,
             },
         )
 
@@ -207,6 +208,7 @@ def load_module(env, middleware_factory, name):
                 "remove_links": cluster.remove_links,
                 "remove_nodes": cluster.remove_nodes,
                 "remove_nodes_from_cib": cluster.remove_nodes_from_cib,
+                "rename": cluster.rename,
                 "setup": cluster.setup,
                 "setup_local": cluster.setup_local,
                 "update_link": cluster.update_link,
@@ -312,6 +314,7 @@ def load_module(env, middleware_factory, name):
             env,
             middleware.build(middleware_factory.cib),
             {
+                "get_config_dto": node.get_config_dto,
                 "maintenance_unmaintenance_all": (
                     node.maintenance_unmaintenance_all
                 ),
@@ -427,6 +430,7 @@ def load_module(env, middleware_factory, name):
                 "is_any_resource_except_stonith": resource.is_any_resource_except_stonith,
                 "is_any_stonith": resource.is_any_stonith,
                 "manage": resource.manage,
+                "update_meta": resource.update_meta,
                 "move": resource.move,
                 "move_autoclean": resource.move_autoclean,
                 "restart": resource.restart,
