@@ -130,7 +130,9 @@ def split_list(arg_list: Argv, separator: str) -> list[Argv]:
     """
     separator_indexes = [i for i, x in enumerate(arg_list) if x == separator]
     bounds = zip(
-        [0] + [i + 1 for i in separator_indexes], separator_indexes + [None]
+        [0] + [i + 1 for i in separator_indexes],
+        separator_indexes + [None],
+        strict=False,
     )
     return [arg_list[i:j] for i, j in bounds]
 
@@ -650,7 +652,7 @@ class InputModifiers:
         checked -- option incompatible with any of incompatible options
         incompatible -- set of options incompatible with checked
         """
-        if not checked in self._defined_options:
+        if checked not in self._defined_options:
             return
         disallowed = self._defined_options & set(incompatible)
         if disallowed:
@@ -685,10 +687,7 @@ class InputModifiers:
         return option in self._defined_options
 
     def is_specified_any(self, option_list: StringIterable) -> bool:
-        for option in option_list:
-            if self.is_specified(option):
-                return True
-        return False
+        return any(self.is_specified(option) for option in option_list)
 
     def get(
         self, option: str, default: ModifierValueType = None
