@@ -5,7 +5,7 @@ from pcs.common.tools import timeout_to_seconds
 
 
 def timeout_to_seconds_legacy(
-    timeout: Union[int, str]
+    timeout: Union[int, str],
 ) -> Union[int, str, None]:
     """
     Transform pacemaker style timeout to number of seconds. If timeout is not
