@@ -304,6 +304,19 @@ class UseCommandNodeAddRemote(CliReportMessageCustom):
         )
 
 
+class UseCommandRemoveAndAddGuestNode(CliReportMessageCustom):
+    _obj: messages.UseCommandRemoveAndAddGuestNode
+
+    @property
+    def message(self) -> str:
+        return (
+            "Changing connection parameters of an existing guest node is not "
+            "sufficient for connecting to a different guest node, remove the "
+            "existing guest node with 'pcs cluster node remove-guest' and add "
+            "a new one with 'pcs cluster node add-guest'"
+        )
+
+
 class CorosyncNodeConflictCheckSkipped(CliReportMessageCustom):
     _obj: messages.CorosyncNodeConflictCheckSkipped
 
@@ -668,7 +681,7 @@ def _create_report_msg_map() -> Dict[str, type]:
     for report_msg_cls in get_all_subclasses(CliReportMessageCustom):
         # pylint: disable=protected-access
         code = (
-            get_type_hints(report_msg_cls)
+            get_type_hints(report_msg_cls)  # noqa: SLF001
             .get("_obj", item.ReportItemMessage)
             ._code
         )
