@@ -2,6 +2,7 @@ from pcs import (
     alert,
     usage,
 )
+from pcs.cli.alert import command as alert_command
 from pcs.cli.common.errors import raise_command_replaced
 from pcs.cli.common.routing import create_router
 
@@ -12,7 +13,7 @@ alert_cmd = create_router(
         "update": alert.alert_update,
         "delete": alert.alert_remove,
         "remove": alert.alert_remove,
-        "config": alert.print_alert_config,
+        "config": alert_command.alert_config,
         "show": lambda lib, argv, modifiers: raise_command_replaced(
             ["pcs alert config"], pcs_version="0.12"
         ),
