@@ -5,7 +5,9 @@ from pcs.cli.common.routing import create_router
 
 property_cmd = create_router(
     {
-        "help": lambda _lib, _argv, _modifiers: print(usage.property(_argv)),
+        "help": lambda _lib, _argv, _modifiers: print(
+            usage.property_usage(_argv)
+        ),
         "set": cluster_property.set_property,
         "unset": cluster_property.unset_property,
         "list": lambda lib, argv, modifiers: raise_command_replaced(
