@@ -6,7 +6,6 @@ from pcs.cli.common.parse_args import (
     InputModifiers,
     group_by_keywords,
 )
-from pcs.cli.reports.output import deprecation_warning
 from pcs.cli.tag.output import print_config
 
 
@@ -22,18 +21,6 @@ def tag_create(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     lib.tag.create(tag_id, idref_list)
 
 
-def tag_list_cmd(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
-    """
-    Options:
-      * -f - CIB file
-    """
-    deprecation_warning(
-        "This command is deprecated and will be removed. "
-        "Please use 'pcs tag config' instead."
-    )
-    return tag_config(lib, argv, modifiers)
-
-
 def tag_config(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     Options:
