@@ -1,4 +1,5 @@
 # pylint: disable=too-many-lines
+import contextlib
 import datetime
 import json
 import math
@@ -61,6 +62,7 @@ from pcs.common.node_communicator import (
 from pcs.common.str_tools import (
     format_list,
     indent,
+    join_multilines,
 )
 from pcs.common.tools import format_os_error
 from pcs.common.types import (
@@ -70,9 +72,8 @@ from pcs.common.types import (
 from pcs.lib import sbd as lib_sbd
 from pcs.lib.commands.remote_node import _destroy_pcmk_remote_env
 from pcs.lib.communication.nodes import CheckAuth
-from pcs.lib.communication.tools import RunRemotelyBase
+from pcs.lib.communication.tools import RunRemotelyBase, run_and_raise
 from pcs.lib.communication.tools import run as run_com_cmd
-from pcs.lib.communication.tools import run_and_raise
 from pcs.lib.corosync import qdevice_net
 from pcs.lib.corosync.live import (
     QuorumStatusException,
@@ -486,7 +487,7 @@ def stop_cluster_all() -> None:
     stop_cluster_nodes(all_nodes)
 
 
-def stop_cluster_nodes(nodes: StringCollection) -> None:
+def stop_cluster_nodes(nodes: StringCollection) -> None:  # noqa: PLR0912
     """
     Commandline options:
       * --force - no error when possible quorum loss
@@ -794,7 +795,7 @@ def kill_local_cluster_services() -> tuple[str, int]:
     return utils.run([settings.killall_exec, "-9"] + all_cluster_daemons)
 
 
-def cluster_push(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
+def cluster_push(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:  # noqa: PLR0912, PLR0915
     """
     Options:
       * --wait
@@ -804,6 +805,25 @@ def cluster_push(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     # pylint: disable=too-many-branches
     # pylint: disable=too-many-locals
     # pylint: disable=too-many-statements
+
+    def get_details_from_crm_verify():
+        # get a new runner to run crm_verify command and pass the CIB filename
+        # into it so that the verify is run on the file instead on the live
+        # cluster CIB
+        verify_runner = utils.cmd_runner(cib_file_override=filename)
+        # Request verbose output, otherwise we may only get an unhelpful
+        # message:
+        # Configuration invalid (with errors) (-V may provide more detail)
+        # verify_returncode is always expected to be non-zero to indicate
+        # invalid CIB - ve run the verify because the CIB is invalid
+        (
+            verify_stdout,
+            verify_stderr,
+            verify_returncode,
+            verify_can_be_more_verbose,
+        ) = lib_pacemaker.verify(verify_runner, verbose=True)
+        return join_multilines([verify_stdout, verify_stderr])
+
     del lib
     modifiers.ensure_only_supported("--wait", "--config", "-f")
     if len(argv) > 2:
@@ -848,8 +868,10 @@ def cluster_push(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     except (EnvironmentError, xml.parsers.expat.ExpatError) as e:
         utils.err("unable to parse new cib: %s" % e)
 
+    EXITCODE_INVALID_CIB = 78
+    runner = utils.cmd_runner()
+
     if diff_against:
-        runner = utils.cmd_runner()
         command = [
             settings.crm_diff_exec,
             "--original",
@@ -878,7 +900,18 @@ def cluster_push(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
         ]
         output, stderr, retval = runner.run(command, patch)
         if retval != 0:
-            utils.err("unable to push cib\n" + stderr + output)
+            push_output = stderr + output
+            verify_output = (
+                get_details_from_crm_verify()
+                if retval == EXITCODE_INVALID_CIB
+                else ""
+            )
+            error_text = (
+                f"{push_output}\n\n{verify_output}"
+                if verify_output.strip()
+                else push_output
+            )
+            utils.err("unable to push cib\n" + error_text)
 
     else:
         command = ["cibadmin", "--replace", "--xml-file", filename]
@@ -896,9 +929,28 @@ def cluster_push(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
                 " that."
             )
         elif retval != 0:
-            utils.err("unable to push cib\n" + output)
+            verify_output = (
+                get_details_from_crm_verify()
+                if retval == EXITCODE_INVALID_CIB
+                else ""
+            )
+            error_text = (
+                f"{output}\n\n{verify_output}"
+                if verify_output.strip()
+                else output
+            )
+            utils.err("unable to push cib\n" + error_text)
 
     print_to_stderr("CIB updated")
+    try:
+        cib_errors = lib_pacemaker.get_cib_verification_errors(runner)
+        if cib_errors:
+            print_to_stderr("\n".join(cib_errors))
+    except lib_pacemaker.BadApiResultFormat as e:
+        print_to_stderr(
+            f"Unable to verify CIB: {e.original_exception}\n"
+            f"crm_verify output:\n{e.pacemaker_response}"
+        )
 
     if not modifiers.is_specified("--wait"):
         return
@@ -915,7 +967,7 @@ def cluster_push(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
         utils.err("\n".join(msg).strip())
 
 
-def cluster_edit(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
+def cluster_edit(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:  # noqa: PLR0912
     """
     Options:
       * --config - edit configuration section of CIB
@@ -973,7 +1025,7 @@ def cluster_edit(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
         utils.err("$EDITOR environment variable is not set")
 
 
-def get_cib(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
+def get_cib(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:  # noqa: PLR0912
     """
     Options:
       * --config show configuration section of CIB
@@ -1167,7 +1219,7 @@ def node_remove(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     lib.cluster.remove_nodes(argv, force_flags=force_flags)
 
 
-def cluster_uidgid(
+def cluster_uidgid(  # noqa: PLR0912
     lib: Any, argv: Argv, modifiers: InputModifiers, silent_list: bool = False
 ) -> None:
     """
@@ -1275,7 +1327,7 @@ def cluster_reload(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
 
 # Completely tear down the cluster & remove config files
 # Code taken from cluster-clean script in pacemaker
-def cluster_destroy(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
+def cluster_destroy(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:  # noqa: PLR0912
     """
     Options:
       * --all - destroy cluster on all cluster nodes => destroy whole cluster
@@ -1349,30 +1401,23 @@ def cluster_destroy(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     else:
         print_to_stderr("Shutting down pacemaker/corosync services...")
         for service in ["pacemaker", "corosync-qdevice", "corosync"]:
-            try:
+            # It is safe to ignore error since we want it not to be running
+            # anyways.
+            with contextlib.suppress(LibraryError):
                 utils.stop_service(service)
-            except LibraryError:
-                # It is safe to ignore error since we want it not to be running
-                # anyways.
-                pass
         print_to_stderr("Killing any remaining services...")
         kill_local_cluster_services()
-        try:
+        # previously errors were suppressed in here, let's keep it that way
+        # for now
+        with contextlib.suppress(Exception):
             utils.disableServices()
-        # pylint: disable=bare-except
-        except:
-            # previously errors were suppressed in here, let's keep it that way
-            # for now
-            pass
-        try:
+
+        # it's not a big deal if sbd disable fails
+        with contextlib.suppress(Exception):
             service_manager = utils.get_service_manager()
             service_manager.disable(
                 lib_sbd.get_sbd_service_name(service_manager)
             )
-        # pylint: disable=bare-except
-        except:
-            # it's not a big deal if sbd disable fails
-            pass
 
         print_to_stderr("Removing all cluster configuration files...")
         dummy_output, dummy_retval = utils.run(
@@ -1408,13 +1453,10 @@ def cluster_destroy(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
                     ";",
                 ]
             )
-        try:
+        # errors from deleting other files are suppressed as well we do not
+        # want to fail if qdevice was not set up
+        with contextlib.suppress(Exception):
             qdevice_net.client_destroy()
-        # pylint: disable=bare-except
-        except:
-            # errors from deleting other files are suppressed as well
-            # we do not want to fail if qdevice was not set up
-            pass
 
 
 def cluster_verify(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
@@ -1430,7 +1472,7 @@ def cluster_verify(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     lib.cluster.verify(verbose=modifiers.get("--full"))
 
 
-def cluster_report(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
+def cluster_report(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:  # noqa: PLR0912
     """
     Options:
       * --force - allow overwriting existing files - DEPRECATED
@@ -1487,11 +1529,7 @@ def cluster_report(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
         utils.err("cluster is not configured on this node")
     newoutput = ""
     for line in output.split("\n"):
-        if (
-            line.startswith("cat:")
-            or line.startswith("grep")
-            or line.startswith("tail")
-        ):
+        if line.startswith(("cat:", "grep", "tail")):
             continue
         if "We will attempt to remove" in line:
             continue
@@ -1501,9 +1539,10 @@ def cluster_report(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
             continue
         if "to diagnose" in line:
             continue
+        new_line = line
         if "--dest" in line:
-            line = line.replace("--dest", "<dest>")
-        newoutput = newoutput + line + "\n"
+            new_line = line.replace("--dest", "<dest>")
+        newoutput = newoutput + new_line + "\n"
     if retval != 0:
         utils.err(newoutput)
     print_to_stderr(newoutput)
@@ -1541,14 +1580,14 @@ def send_local_configs(
                         "Unable to set pcsd configs on {0}".format(node_name)
                     )
         # pylint: disable=bare-except
-        except:
+        except:  # noqa: E722
             err_msgs.append("Unable to communicate with pcsd")
     else:
         err_msgs.append("Unable to set pcsd configs")
     return err_msgs
 
 
-def cluster_auth_cmd(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
+def cluster_auth_cmd(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:  # noqa: PLR0912
     """
     Options:
       * --corosync_conf - corosync.conf file
