@@ -2,7 +2,7 @@
 # pylint: disable=wildcard-import
 # Wildcard import of deprecated report codes will prevent creation of a new
 # report with the code of deprecated report
-from .deprecated_codes import *
+from .deprecated_codes import *  # noqa: F403
 from .types import ForceCode as F
 from .types import MessageCode as M
 
@@ -54,6 +54,7 @@ AGENT_SELF_VALIDATION_SKIPPED_UPDATED_RESOURCE_MISCONFIGURED = M(
 AGENT_SELF_VALIDATION_RESULT = M("AGENT_SELF_VALIDATION_RESULT")
 BAD_CLUSTER_STATE_FORMAT = M("BAD_CLUSTER_STATE_FORMAT")
 BAD_CLUSTER_STATE_DATA = M("BAD_CLUSTER_STATE_DATA")
+BAD_PCMK_API_RESPONSE_FORMAT = M("BAD_PCMK_API_RESPONSE_FORMAT")
 BOOTH_ADDRESS_DUPLICATION = M("BOOTH_ADDRESS_DUPLICATION")
 BOOTH_ALREADY_IN_CIB = M("BOOTH_ALREADY_IN_CIB")
 BOOTH_AUTHFILE_NOT_USED = M("BOOTH_AUTHFILE_NOT_USED")
@@ -141,6 +142,9 @@ CIB_ACL_TARGET_ALREADY_EXISTS = M("CIB_ACL_TARGET_ALREADY_EXISTS")
 CIB_ALERT_RECIPIENT_ALREADY_EXISTS = M("CIB_ALERT_RECIPIENT_ALREADY_EXISTS")
 CIB_ALERT_RECIPIENT_VALUE_INVALID = M("CIB_ALERT_RECIPIENT_VALUE_INVALID")
 CIB_CANNOT_FIND_MANDATORY_SECTION = M("CIB_CANNOT_FIND_MANDATORY_SECTION")
+CIB_CLUSTER_NAME_REMOVAL_FAILED = M("CIB_CLUSTER_NAME_REMOVAL_FAILED")
+CIB_CLUSTER_NAME_REMOVAL_STARTED = M("CIB_CLUSTER_NAME_REMOVAL_STARTED")
+CIB_CLUSTER_NAME_REMOVED = M("CIB_CLUSTER_NAME_REMOVED")
 CIB_DIFF_ERROR = M("CIB_DIFF_ERROR")
 CIB_FENCING_LEVEL_ALREADY_EXISTS = M("CIB_FENCING_LEVEL_ALREADY_EXISTS")
 CIB_FENCING_LEVEL_DOES_NOT_EXIST = M("CIB_FENCING_LEVEL_DOES_NOT_EXIST")
@@ -162,6 +166,7 @@ CIB_UPGRADE_FAILED_TO_MINIMAL_REQUIRED_VERSION = M(
     "CIB_UPGRADE_FAILED_TO_MINIMAL_REQUIRED_VERSION"
 )
 CIB_UPGRADE_SUCCESSFUL = M("CIB_UPGRADE_SUCCESSFUL")
+CIB_XML_MISSING = M("CIB_XML_MISSING")
 CLUSTER_DESTROY_STARTED = M("CLUSTER_DESTROY_STARTED")
 CLUSTER_DESTROY_SUCCESS = M("CLUSTER_DESTROY_SUCCESS")
 CLUSTER_ENABLE_STARTED = M("CLUSTER_ENABLE_STARTED")
@@ -285,6 +290,7 @@ CRM_MON_ERROR = M("CRM_MON_ERROR")
 DEFAULTS_CAN_BE_OVERRIDDEN = M("DEFAULTS_CAN_BE_OVERRIDDEN")
 DEPRECATED_OPTION = M("DEPRECATED_OPTION")
 DEPRECATED_OPTION_VALUE = M("DEPRECATED_OPTION_VALUE")
+DLM_CLUSTER_RENAME_NEEDED = M("DLM_CLUSTER_RENAME_NEEDED")
 DR_CONFIG_ALREADY_EXIST = M("DR_CONFIG_ALREADY_EXIST")
 DR_CONFIG_DOES_NOT_EXIST = M("DR_CONFIG_DOES_NOT_EXIST")
 DUPLICATE_CONSTRAINTS_EXIST = M("DUPLICATE_CONSTRAINTS_EXIST")
@@ -301,6 +307,8 @@ FILE_DISTRIBUTION_SUCCESS = M("FILE_DISTRIBUTION_SUCCESS")
 FILE_IO_ERROR = M("FILE_IO_ERROR")
 FILE_REMOVE_FROM_NODE_ERROR = M("FILE_REMOVE_FROM_NODE_ERROR")
 FILE_REMOVE_FROM_NODE_SUCCESS = M("FILE_REMOVE_FROM_NODE_SUCCESS")
+GFS2_LOCK_TABLE_RENAME_NEEDED = M("GFS2_LOCK_TABLE_RENAME_NEEDED")
+GUEST_NODE_NAME_ALREADY_EXISTS = M("GUEST_NODE_NAME_ALREADY_EXISTS")
 HOST_NOT_FOUND = M("HOST_NOT_FOUND")
 HOST_ALREADY_AUTHORIZED = M("HOST_ALREADY_AUTHORIZED")
 HOST_ALREADY_IN_CLUSTER_CONFIG = M("HOST_ALREADY_IN_CLUSTER_CONFIG")
@@ -324,6 +332,7 @@ INVALID_TIMEOUT_VALUE = M("INVALID_TIMEOUT_VALUE")
 MULTIPLE_RESULTS_FOUND = M("MULTIPLE_RESULTS_FOUND")
 MUTUALLY_EXCLUSIVE_OPTIONS = M("MUTUALLY_EXCLUSIVE_OPTIONS")
 NO_ACTION_NECESSARY = M("NO_ACTION_NECESSARY")
+NO_STONITH_MEANS_WOULD_BE_LEFT = M("NO_STONITH_MEANS_WOULD_BE_LEFT")
 NODE_ADDRESSES_ALREADY_EXIST = M("NODE_ADDRESSES_ALREADY_EXIST")
 NODE_ADDRESSES_CANNOT_BE_EMPTY = M("NODE_ADDRESSES_CANNOT_BE_EMPTY")
 NODE_ADDRESSES_DUPLICATION = M("NODE_ADDRESSES_DUPLICATION")
@@ -356,6 +365,7 @@ NODE_NAMES_ALREADY_EXIST = M("NODE_NAMES_ALREADY_EXIST")
 NODE_NAMES_DUPLICATION = M("NODE_NAMES_DUPLICATION")
 NODE_NOT_FOUND = M("NODE_NOT_FOUND")
 NODE_REMOVE_IN_PACEMAKER_FAILED = M("NODE_REMOVE_IN_PACEMAKER_FAILED")
+NODE_REPORTS_UNEXPECTED_CLUSTER_NAME = M("NODE_REPORTS_UNEXPECTED_CLUSTER_NAME")
 NONE_HOST_FOUND = M("NONE_HOST_FOUND")
 NODE_USED_AS_TIE_BREAKER = M("NODE_USED_AS_TIE_BREAKER")
 NODES_TO_REMOVE_UNREACHABLE = M("NODES_TO_REMOVE_UNREACHABLE")
@@ -364,8 +374,9 @@ NODE_IN_LOCAL_CLUSTER = M("NODE_IN_LOCAL_CLUSTER")
 NOT_AUTHORIZED = M("NOT_AUTHORIZED")
 OBJECT_WITH_ID_IN_UNEXPECTED_CONTEXT = M("OBJECT_WITH_ID_IN_UNEXPECTED_CONTEXT")
 OMITTING_NODE = M("OMITTING_NODE")
-PACEMAKER_SIMULATION_RESULT = M("PACEMAKER_SIMULATION_RESULT")
 PACEMAKER_LOCAL_NODE_NAME_NOT_FOUND = M("PACEMAKER_LOCAL_NODE_NAME_NOT_FOUND")
+PACEMAKER_RUNNING = M("PACEMAKER_RUNNING")
+PACEMAKER_SIMULATION_RESULT = M("PACEMAKER_SIMULATION_RESULT")
 PARSE_ERROR_COROSYNC_CONF = M("PARSE_ERROR_COROSYNC_CONF")
 PARSE_ERROR_COROSYNC_CONF_EXTRA_CHARACTERS_AFTER_OPENING_BRACE = M(
     "PARSE_ERROR_COROSYNC_CONF_EXTRA_CHARACTERS_AFTER_OPENING_BRACE"
@@ -385,6 +396,7 @@ PARSE_ERROR_COROSYNC_CONF_MISSING_SECTION_NAME_BEFORE_OPENING_BRACE = M(
 PARSE_ERROR_COROSYNC_CONF_UNEXPECTED_CLOSING_BRACE = M(
     "PARSE_ERROR_COROSYNC_CONF_UNEXPECTED_CLOSING_BRACE"
 )
+PARSE_ERROR_INVALID_FILE_STRUCTURE = M("PARSE_ERROR_INVALID_FILE_STRUCTURE")
 PARSE_ERROR_JSON_FILE = M("PARSE_ERROR_JSON_FILE")
 PCSD_VERSION_TOO_OLD = M("PCSD_VERSION_TOO_OLD")
 PCSD_SSL_CERT_AND_KEY_DISTRIBUTION_STARTED = M(
@@ -635,6 +647,9 @@ USE_COMMAND_NODE_ADD_REMOTE = M("USE_COMMAND_NODE_ADD_REMOTE")
 USE_COMMAND_NODE_ADD_GUEST = M("USE_COMMAND_NODE_ADD_GUEST")
 USE_COMMAND_NODE_REMOVE_REMOTE = M("USE_COMMAND_NODE_REMOVE_REMOTE")
 USE_COMMAND_NODE_REMOVE_GUEST = M("USE_COMMAND_NODE_REMOVE_GUEST")
+USE_COMMAND_REMOVE_AND_ADD_GUEST_NODE = M(
+    "USE_COMMAND_REMOVE_AND_ADD_GUEST_NODE"
+)
 USING_DEFAULT_ADDRESS_FOR_HOST = M("USING_DEFAULT_ADDRESS_FOR_HOST")
 USING_DEFAULT_WATCHDOG = M("USING_DEFAULT_WATCHDOG")
 WAIT_FOR_IDLE_STARTED = M("WAIT_FOR_IDLE_STARTED")
