@@ -98,10 +98,7 @@ class CrmRuleReturnCode(Enum):
 
 
 def constraint_order_cmd(lib, argv, modifiers):
-    if not argv:
-        sub_cmd = "config"
-    else:
-        sub_cmd = argv.pop(0)
+    sub_cmd = "config" if not argv else argv.pop(0)
 
     try:
         if sub_cmd == "set":
@@ -163,7 +160,7 @@ def _validate_resources_not_in_same_group(cib_dom, resource1, resource2):
 # <role> <src> with <role> <tgt> [score] [options]
 # Specifying score as a single argument is deprecated, though. The correct way
 # is score=value in options.
-def colocation_add(lib, argv, modifiers):
+def colocation_add(lib, argv, modifiers):  # noqa: PLR0912, PLR0915
     """
     Options:
       * -f - CIB file
@@ -239,14 +236,11 @@ def colocation_add(lib, argv, modifiers):
 
     if not argv:
         raise CmdLineInputError()
-    if len(argv) == 1:
+    if len(argv) == 1 or utils.is_score_or_opt(argv[1]):
         resource2 = argv.pop(0)
     else:
-        if utils.is_score_or_opt(argv[1]):
-            resource2 = argv.pop(0)
-        else:
-            role2 = _validate_and_prepare_role(argv.pop(0))
-            resource2 = argv.pop(0)
+        role2 = _validate_and_prepare_role(argv.pop(0))
+        resource2 = argv.pop(0)
 
     score, nv_pairs = _parse_score_options(argv)
 
@@ -464,7 +458,7 @@ def order_start(lib, argv, modifiers):
     _order_add(resource1, resource2, order_options, modifiers)
 
 
-def _order_add(resource1, resource2, options_list, modifiers):
+def _order_add(resource1, resource2, options_list, modifiers):  # noqa: PLR0912, PLR0915
     """
     Commandline options:
       * -f - CIB file
@@ -849,7 +843,7 @@ def _verify_score(score):
         )
 
 
-def location_prefer(
+def location_prefer(  # noqa: PLR0912
     lib: Any, argv: parse_args.Argv, modifiers: parse_args.InputModifiers
 ) -> None:
     """
@@ -896,18 +890,12 @@ def location_prefer(
         if not skip_node_check:
             report_list += _verify_node_name(node, existing_nodes)
         if len(nodeconf_a) == 1:
-            if prefer:
-                score = "INFINITY"
-            else:
-                score = "-INFINITY"
+            score = "INFINITY" if prefer else "-INFINITY"
         else:
             score = nodeconf_a[1]
             _verify_score(score)
             if not prefer:
-                if score[0] == "-":
-                    score = score[1:]
-                else:
-                    score = "-" + score
+                score = score[1:] if score[0] == "-" else "-" + score
 
         parameters_list.append(
             [
@@ -927,7 +915,7 @@ def location_prefer(
         location_add(lib, parameters, modifiers, skip_score_and_node_check=True)
 
 
-def location_add(
+def location_add(  # noqa: PLR0912, PLR0915
     lib: Any,
     argv: parse_args.Argv,
     modifiers: parse_args.InputModifiers,
@@ -1021,24 +1009,26 @@ def location_add(
     # Verify current constraint doesn't already exist
     # If it does we replace it with the new constraint
     dummy_dom, constraintsElement = getCurrentConstraints(dom)
-    elementsToRemove = []
     # If the id matches, or the rsc & node match, then we replace/remove
-    for rsc_loc in constraintsElement.getElementsByTagName("rsc_location"):
+    elementsToRemove = [
+        rsc_loc
+        for rsc_loc in constraintsElement.getElementsByTagName("rsc_location")
         # pylint: disable=too-many-boolean-expressions
-        if rsc_loc.getAttribute("id") == constraint_id or (
+        if rsc_loc.getAttribute("id") == constraint_id
+        or (
             rsc_loc.getAttribute("node") == node
             and (
                 (
-                    RESOURCE_TYPE_RESOURCE == rsc_type
+                    rsc_type == RESOURCE_TYPE_RESOURCE
                     and rsc_loc.getAttribute("rsc") == rsc_value
                 )
                 or (
-                    RESOURCE_TYPE_REGEXP == rsc_type
+                    rsc_type == RESOURCE_TYPE_REGEXP
                     and rsc_loc.getAttribute("rsc-pattern") == rsc_value
                 )
             )
-        ):
-            elementsToRemove.append(rsc_loc)
+        )
+    ]
     for etr in elementsToRemove:
         constraintsElement.removeChild(etr)
 
@@ -1079,7 +1069,7 @@ def getCurrentConstraints(passed_dom=None):
 
 # If returnStatus is set, then we don't error out, we just print the error
 # and return false
-def constraint_rm(
+def constraint_rm(  # noqa: PLR0912
     lib,
     argv,
     modifiers,
