@@ -54,11 +54,13 @@ API_V1_MAP: Mapping[str, str] = {
     "alert-add-recipient/v1": "alert.add_recipient",
     "alert-update-recipient/v1": "alert.update_recipient",
     "alert-remove-recipient/v1": "alert.remove_recipient",
+    "cfgsync-get-configs/v1": "cfgsync.get_configs",
     "cluster-add-nodes/v1": "cluster.add_nodes",
     "cluster-node-clear/v1": "cluster.node_clear",
     "cluster-remove-nodes/v1": "cluster.remove_nodes",
     "cluster-setup/v1": "cluster.setup",
     "cluster-generate-cluster-uuid/v1": "cluster.generate_cluster_uuid",
+    "cluster-property-remove-name/v1": "cluster_property.remove_cluster_name",
     "constraint-colocation-create-with-set/v1": "constraint.colocation.create_with_set",
     "constraint-order-create-with-set/v1": "constraint.order.create_with_set",
     "constraint-ticket-create-with-set/v1": "constraint.ticket.create_with_set",
@@ -170,6 +172,7 @@ class _BaseApiV1Handler(BaseHandler):
         self.finish(json.dumps(to_dict(response)))
 
     def write_error(self, status_code: int, **kwargs: Any) -> None:
+        del status_code
         response = communication.dto.InternalCommunicationResultDto(
             status=communication.const.COM_STATUS_EXCEPTION,
             status_msg=None,
