@@ -1,10 +1,7 @@
-from pcs.daemon import (
-    ruby_pcsd,
-    session,
-)
+from pcs.daemon import ruby_pcsd
 from pcs.daemon.app.auth import (
     NotAuthorizedException,
-    SessionAuthProvider,
+    UnixSocketAuthProvider,
 )
 from pcs.daemon.app.common import (
     LegacyApiHandler,
@@ -13,6 +10,7 @@ from pcs.daemon.app.common import (
 from pcs.daemon.app.sinatra_common import SinatraMixin
 from pcs.daemon.app.ui_common import AjaxMixin
 from pcs.lib.auth.provider import AuthProvider
+from pcs.lib.auth.types import AuthUser
 
 
 class SinatraAjaxProtected(LegacyApiHandler, SinatraMixin, AjaxMixin):
@@ -21,32 +19,28 @@ class SinatraAjaxProtected(LegacyApiHandler, SinatraMixin, AjaxMixin):
     It allows to use this urls only for ajax calls.
     """
 
-    _auth_provider: SessionAuthProvider
+    _auth_provider: UnixSocketAuthProvider
 
     def initialize(
         self,
-        session_storage: session.Storage,
         ruby_pcsd_wrapper: ruby_pcsd.Wrapper,
         auth_provider: AuthProvider,
     ) -> None:
         self.initialize_sinatra(ruby_pcsd_wrapper)
-        self._auth_provider = SessionAuthProvider(
-            self, auth_provider, session_storage
-        )
+        self._auth_provider = UnixSocketAuthProvider(self, auth_provider)
 
     def prepare(self) -> None:
         if not self.is_ajax:
             raise self.unauthorized()
-        self._auth_provider.init_session()
 
     async def _handle_request(self):
         try:
-            auth_user = await self._auth_provider.auth_by_sid()
+            auth_user = await self._get_auth_user()
         except NotAuthorizedException as e:
             raise self.unauthorized() from e
-        self._auth_provider.update_session(auth_user)
-        if self._auth_provider.is_sid_in_request_cookies():
-            self._auth_provider.put_request_cookies_sid_to_response_cookies_sid()
+
+        # Webui version needs to deal with extra session operation here.
+        self._after_get_auth_user_hook(auth_user)
 
         result = await self.ruby_pcsd_wrapper.request(
             auth_user,
@@ -54,9 +48,14 @@ class SinatraAjaxProtected(LegacyApiHandler, SinatraMixin, AjaxMixin):
         )
         self.send_sinatra_result(result)
 
+    async def _get_auth_user(self):
+        return await self._auth_provider.auth_by_socket_user()
+
+    def _after_get_auth_user_hook(self, auth_user: AuthUser):
+        pass
+
 
 def get_routes(
-    session_storage: session.Storage,
     auth_provider: AuthProvider,
     ruby_pcsd_wrapper: ruby_pcsd.Wrapper,
 ) -> RoutesType:
@@ -67,7 +66,6 @@ def get_routes(
             r"/.*",
             SinatraAjaxProtected,
             dict(
-                session_storage=session_storage,
                 ruby_pcsd_wrapper=ruby_pcsd_wrapper,
                 auth_provider=auth_provider,
             ),
