@@ -9,6 +9,7 @@ from pcs.lib.commands import (  # services,
     acl,
     alert,
     booth,
+    cfgsync,
     cib,
     cib_options,
     cluster,
@@ -93,6 +94,10 @@ COMMAND_MAP: Mapping[str, _Cmd] = {
         cmd=alert.create_alert,
         required_permission=p.WRITE,
     ),
+    "alert.get_config_dto": _Cmd(
+        cmd=alert.get_config_dto,
+        required_permission=p.READ,
+    ),
     "alert.remove_alert": _Cmd(
         cmd=alert.remove_alert,
         required_permission=p.WRITE,
@@ -125,6 +130,10 @@ COMMAND_MAP: Mapping[str, _Cmd] = {
         cmd=booth.ticket_unstandby,
         required_permission=p.WRITE,
     ),
+    "cfgsync.get_configs": _Cmd(
+        cmd=cfgsync.get_configs,
+        required_permission=p.FULL,
+    ),
     "cluster.add_nodes": _Cmd(
         cmd=cluster.add_nodes,
         required_permission=p.FULL,
@@ -145,6 +154,10 @@ COMMAND_MAP: Mapping[str, _Cmd] = {
         cmd=cluster.remove_nodes,
         required_permission=p.FULL,
     ),
+    "cluster.rename": _Cmd(
+        cmd=cluster.rename,
+        required_permission=p.FULL,
+    ),
     "cluster.setup": _Cmd(
         cmd=cluster.setup,
         required_permission=p.SUPERUSER,
@@ -161,6 +174,10 @@ COMMAND_MAP: Mapping[str, _Cmd] = {
         cmd=cluster_property.set_properties,
         required_permission=p.WRITE,
     ),
+    "cluster_property.remove_cluster_name": _Cmd(
+        cmd=cluster_property.remove_cluster_name,
+        required_permission=p.WRITE,
+    ),
     "cluster.wait_for_pcmk_idle": _Cmd(
         cmd=cluster.wait_for_pcmk_idle,
         required_permission=p.READ,
@@ -359,6 +376,10 @@ COMMAND_MAP: Mapping[str, _Cmd] = {
         cmd=resource.manage,
         required_permission=p.WRITE,
     ),
+    "resource.update_meta": _Cmd(
+        cmd=resource.update_meta,
+        required_permission=p.WRITE,
+    ),
     "resource.move": _Cmd(
         cmd=resource.move,
         required_permission=p.WRITE,
