@@ -6,7 +6,6 @@ from base64 import (
     binascii,
 )
 from collections import namedtuple
-from time import time as now
 
 import pycurl
 from tornado.curl_httpclient import CurlError
@@ -27,7 +26,6 @@ from pcs.lib.auth.types import AuthUser
 SYNC_CONFIGS = "sync_configs"
 SINATRA = "sinatra"
 
-DEFAULT_SYNC_CONFIG_DELAY = 5
 RUBY_LOG_LEVEL_MAP = {
     "UNKNOWN": logging.NOTSET,
     "FATAL": logging.CRITICAL,
@@ -46,6 +44,8 @@ def get_request_id():
 
 
 class SinatraResult(namedtuple("SinatraResult", "headers, status, body")):
+    __slots__ = ()
+
     @classmethod
     def from_response(cls, response):
         return cls(response["headers"], response["status"], response["body"])
@@ -81,6 +81,8 @@ class RubyDaemonRequest(
         "RubyDaemonRequest", "request_type, path, query, headers, method, body"
     )
 ):
+    __slots__ = ()
+
     def __new__(
         cls,
         request_type,
@@ -282,10 +284,3 @@ class Wrapper:
                 )
             )
         )
-
-    async def sync_configs(self):
-        try:
-            return (await convert_yielded(self.run_ruby(SYNC_CONFIGS)))["next"]
-        except HTTPError:
-            log.pcsd.error("Config synchronization failed")
-            return int(now()) + DEFAULT_SYNC_CONFIG_DELAY
