@@ -5,4 +5,4 @@ from .common import add_bundled_packages_to_path
 
 add_bundled_packages_to_path()
 
-from pcs.app import main
+from pcs.app import main  # noqa: E402
