@@ -9,5 +9,5 @@ def add_bundled_packages_to_path() -> None:
     installed in a pcs-specific location rather than in a standard system
     location for the python packages.
     """
-    if settings.pcs_bundled_pacakges_dir not in sys.path:
-        sys.path.insert(0, settings.pcs_bundled_pacakges_dir)
+    if settings.pcs_bundled_packages_dir not in sys.path:
+        sys.path.insert(0, settings.pcs_bundled_packages_dir)
