@@ -5,4 +5,4 @@ from .common import add_bundled_packages_to_path
 
 add_bundled_packages_to_path()
 
-from pcs.snmp.pcs_snmp_agent import main
+from pcs.snmp.pcs_snmp_agent import main  # noqa: E402
