@@ -1,5 +1,5 @@
 from typing import (
-    List,
+    Iterable,
     cast,
 )
 
@@ -36,22 +36,24 @@ def find_grouped_ip_element_to_remove(booth_element):
     return None
 
 
-def get_remover(resource_remove):
-    def remove_from_cluster(booth_element_list):
-        for element in booth_element_list:
-            ip_resource_to_remove = find_grouped_ip_element_to_remove(element)
-            if ip_resource_to_remove is not None:
-                resource_remove(ip_resource_to_remove.attrib["id"])
-            resource_remove(element.attrib["id"])
+def find_elements_to_remove(
+    booth_element_list: Iterable[_Element],
+) -> list[_Element]:
+    elements_to_remove = []
+    for element in booth_element_list:
+        ip_resource_to_remove = find_grouped_ip_element_to_remove(element)
+        if ip_resource_to_remove is not None:
+            elements_to_remove.append(ip_resource_to_remove)
+        elements_to_remove.append(element)
 
-    return remove_from_cluster
+    return elements_to_remove
 
 
 def find_for_config(
     resources_section: _Element, booth_config_file_path: str
-) -> List[_Element]:
+) -> list[_Element]:
     return cast(
-        List[_Element],
+        list[_Element],
         resources_section.xpath(
             """
             .//primitive[
@@ -69,9 +71,9 @@ def find_for_config(
 
 def find_bound_ip(
     resources_section: _Element, booth_config_file_path: str
-) -> List[_Element]:
+) -> list[str]:
     return cast(
-        List[_Element],
+        list[str],
         resources_section.xpath(
             """
             .//group[
