@@ -148,7 +148,7 @@ def update_nvset(nvset_element, nvpair_dict, id_provider):
         set_nvpair_in_nvset(nvset_element, name, value, id_provider)
 
 
-def get_nvset(nvset):
+def get_nvset(nvset: _Element) -> list[dict[str, Optional[str]]]:
     """
     Returns nvset element as list of nvpairs with format:
     [
@@ -162,16 +162,14 @@ def get_nvset(nvset):
 
     nvset -- nvset element
     """
-    nvpair_list = []
-    for nvpair in nvset.findall("./nvpair"):
-        nvpair_list.append(
-            {
-                "id": nvpair.get("id"),
-                "name": nvpair.get("name"),
-                "value": nvpair.get("value", ""),
-            }
-        )
-    return nvpair_list
+    return [
+        {
+            "id": nvpair.get("id"),
+            "name": nvpair.get("name"),
+            "value": nvpair.get("value"),
+        }
+        for nvpair in nvset.findall("./nvpair")
+    ]
 
 
 @overload
