@@ -137,9 +137,9 @@ class ElementsToRemove:
         self._ids_to_remove = element_ids_to_remove
         self._dependant_element_ids = self._ids_to_remove - initial_ids
         self._missing_ids = set(missing_ids)
-        self._unsupported_ids = set(
+        self._unsupported_ids = {
             str(el.attrib["id"]) for el in unsupported_elements
-        )
+        }
 
         all_ids = set(
             chain(
@@ -560,7 +560,9 @@ def _is_last_element(parent_element: _Element, child_tag: str) -> bool:
     return len(parent_element.findall(f"./{child_tag}")) == 1
 
 
-def _is_empty_after_inner_el_removal(parent_el: _Element) -> bool:
+def _is_empty_after_inner_el_removal(  # noqa: PLR0911
+    parent_el: _Element,
+) -> bool:
     # pylint: disable=too-many-return-statements
     if is_any_clone(parent_el):
         return True
