@@ -1,11 +1,14 @@
-from pcs.lib.cib.resource import (
+from . import (
     bundle,
     clone,
     common,
     group,
     guest_node,
+    hierarchy,
     operations,
     primitive,
-    relation,
+    relations,
     remote_node,
+    stonith,
+    validations,
 )
