@@ -1,6 +1,5 @@
 from typing import (
     List,
-    Mapping,
     Optional,
     Set,
     Tuple,
@@ -21,6 +20,9 @@ from pcs.lib.xml_tools import find_parent
 
 from .bundle import get_inner_resource as get_bundle_inner_resource
 from .bundle import is_bundle
+from .clone import (
+    get_inner_primitives as get_clone_inner_primitive_resources,
+)
 from .clone import get_inner_resource as get_clone_inner_resource
 from .clone import is_any_clone
 from .group import get_inner_resources as get_group_inner_resources
@@ -28,24 +30,7 @@ from .group import is_group
 from .primitive import is_primitive
 
 
-def are_meta_disabled(meta_attributes: Mapping[str, str]) -> bool:
-    return meta_attributes.get("target-role", "Started").lower() == "stopped"
-
-
-def _can_be_evaluated_as_positive_num(value: str) -> bool:
-    string_wo_leading_zeros = str(value).lstrip("0")
-    return (
-        bool(string_wo_leading_zeros) and string_wo_leading_zeros[0].isdigit()
-    )
-
-
-def is_clone_deactivated_by_meta(meta_attributes: Mapping[str, str]) -> bool:
-    return are_meta_disabled(meta_attributes) or any(
-        not _can_be_evaluated_as_positive_num(meta_attributes.get(key, "1"))
-        for key in ["clone-max", "clone-node-max"]
-    )
-
-
+# DEPRECATED, use get_element_by_id
 def find_one_resource(
     context_element: _Element,
     resource_id: str,
@@ -67,6 +52,8 @@ def find_one_resource(
     return resource, report_list
 
 
+# DEPRECATED, use get_elements_by_ids
+# Issue: produces report with CIB tags when wrong element type was found
 def find_resources(
     context_element: _Element,
     resource_ids: StringCollection,
@@ -85,8 +72,9 @@ def find_resources(
     resource_el_list = []
     for res_id in resource_ids:
         searcher = ElementSearcher(resource_tags, res_id, context_element)
-        if searcher.element_found():
-            resource_el_list.append(searcher.get_element())
+        found_element = searcher.get_element()
+        if found_element is not None:
+            resource_el_list.append(found_element)
         else:
             report_list.extend(searcher.get_errors())
     return resource_el_list, report_list
@@ -102,7 +90,7 @@ def find_primitives(resource_el: _Element) -> List[_Element]:
         in_bundle = get_bundle_inner_resource(resource_el)
         return [in_bundle] if in_bundle is not None else []
     if is_any_clone(resource_el):
-        resource_el = get_clone_inner_resource(resource_el)
+        return get_clone_inner_primitive_resources(resource_el)
     if is_group(resource_el):
         return get_group_inner_resources(resource_el)
     if is_primitive(resource_el):
@@ -119,7 +107,7 @@ def get_all_inner_resources(resource_el: _Element) -> Set[_Element]:
     resource_el -- resource element to get its inner resources
     """
     all_inner: Set[_Element] = set()
-    to_process = set([resource_el])
+    to_process = {resource_el}
     while to_process:
         new_inner = get_inner_resources(to_process.pop())
         to_process.update(set(new_inner) - all_inner)
@@ -233,6 +221,18 @@ def disable(resource_el: _Element, id_provider: IdProvider) -> None:
     )
 
 
+def is_disabled(resource_el: _Element) -> bool:
+    """
+    Is the resource disabled by its own meta? (Doesn't check parent resources.)
+    """
+    return (
+        nvpair.get_value(
+            nvpair.META_ATTRIBUTES_TAG, resource_el, "target-role", default=""
+        ).lower()
+        == "stopped"
+    )
+
+
 def find_resources_to_manage(resource_el: _Element) -> List[_Element]:
     """
     Get resources to set to managed for the specified resource to become managed
