@@ -5,6 +5,7 @@ from typing import (
     List,
     Optional,
     Tuple,
+    cast,
 )
 
 from lxml import etree
@@ -319,6 +320,7 @@ def uniquify_operations_intervals(
     new_operations = []
     for operation in operation_list:
         new_interval = get_unique_interval(operation.name, operation.interval)
+        new_operation = operation
         if new_interval != operation.interval:
             report_list.append(
                 ReportItem.warning(
@@ -329,8 +331,8 @@ def uniquify_operations_intervals(
                     )
                 )
             )
-            operation = dt_replace(operation, interval=new_interval)
-        new_operations.append(operation)
+            new_operation = dt_replace(operation, interval=new_interval)
+        new_operations.append(new_operation)
     return report_list, new_operations
 
 
@@ -398,11 +400,11 @@ def append_new_operation(operations_element, id_provider, options):
     IdProvider id_provider -- elements' ids generator
     dict options are attributes of operation
     """
-    attribute_map = dict(
-        (key, value)
+    attribute_map = {
+        key: value
         for key, value in options.items()
         if key not in OPERATION_NVPAIR_ATTRIBUTES
-    )
+    }
     if "id" in attribute_map:
         if does_id_exist(operations_element, attribute_map["id"]):
             raise LibraryError(
@@ -426,11 +428,11 @@ def append_new_operation(operations_element, id_provider, options):
         "op",
         attribute_map,
     )
-    nvpair_attribute_map = dict(
-        (key, value)
+    nvpair_attribute_map = {
+        key: value
         for key, value in options.items()
         if key in OPERATION_NVPAIR_ATTRIBUTES
-    )
+    }
 
     if nvpair_attribute_map:
         append_new_instance_attributes(
@@ -440,15 +442,17 @@ def append_new_operation(operations_element, id_provider, options):
     return op_element
 
 
-def get_resource_operations(resource_el, names=None):
+def get_resource_operations(
+    resource_el: _Element, names: Optional[StringCollection] = None
+) -> list[_Element]:
     """
     Get operations of a given resource, optionally filtered by name
-    etree resource_el -- resource element
-    iterable names -- return only operations of these names if specified
+    resource_el -- resource element
+    names -- return only operations of these names if specified
     """
     return [
         op_el
-        for op_el in resource_el.xpath("./operations/op")
+        for op_el in cast(list[_Element], resource_el.xpath("./operations/op"))
         if not names or op_el.attrib.get("name", "") in names
     ]
 
