@@ -57,6 +57,16 @@ def is_primitive(resource_el: _Element) -> bool:
     return resource_el.tag == TAG
 
 
+def resource_agent_name_from_primitive(
+    primitive_el: _Element,
+) -> ResourceAgentName:
+    return ResourceAgentName(
+        standard=str(primitive_el.attrib["class"]),
+        provider=primitive_el.get("provider"),
+        type=str(primitive_el.attrib["type"]),
+    )
+
+
 def primitive_element_to_dto(
     primitive_element: _Element,
     rule_eval: Optional[rule.RuleInEffectEval] = None,
@@ -96,7 +106,7 @@ def primitive_element_to_dto(
     )
 
 
-def _find_primitives_by_agent(
+def find_primitives_by_agent(
     resources_section: _Element, agent_name: ResourceAgentName
 ) -> List[_Element]:
     """
@@ -121,7 +131,7 @@ def _find_primitives_by_agent(
     )
 
 
-def create(
+def create(  # noqa: PLR0913
     report_processor: reports.ReportProcessor,
     cmd_runner: CommandRunner,
     resources_section: _Element,
@@ -171,11 +181,10 @@ def create(
     if instance_attributes is None:
         instance_attributes = {}
 
-    filtered_raw_operation_list = []
-    for op in raw_operation_list:
-        filtered_raw_operation_list.append(
-            {name: "" if value is None else value for name, value in op.items()}
-        )
+    filtered_raw_operation_list = [
+        {name: "" if value is None else value for name, value in op.items()}
+        for op in raw_operation_list
+    ]
 
     if does_id_exist(resources_section, resource_id):
         raise LibraryError(
@@ -244,7 +253,7 @@ def create(
     )
 
 
-def append_new(
+def append_new(  # noqa: PLR0913
     resources_section,
     id_provider,
     resource_id,
@@ -309,7 +318,7 @@ def _validate_unique_instance_attributes(
         return []
 
     report_list = []
-    same_agent_resources = _find_primitives_by_agent(
+    same_agent_resources = find_primitives_by_agent(
         resources_section, resource_agent.name
     )
 
