@@ -86,7 +86,7 @@ def _validate_add_remove_duplicate_reference_ids(
     add_or_not_remove -- flag for add/remove action
     """
     duplicate_ids_list = [
-        id for id, count in Counter(idref_list).items() if count > 1
+        id_ for id_, count in Counter(idref_list).items() if count > 1
     ]
     if duplicate_ids_list:
         return [
@@ -541,8 +541,9 @@ def find_tag_elements_by_ids(
     report_list: ReportItemList = []
     for tag_id in tag_id_list:
         searcher = ElementSearcher(TAG_TAG, tag_id, tags_section)
-        if searcher.element_found():
-            element_list.append(searcher.get_element())
+        found_element = searcher.get_element()
+        if found_element is not None:
+            element_list.append(found_element)
         else:
             report_list.extend(searcher.get_errors())
 
@@ -695,8 +696,9 @@ def expand_tag(
             searcher = ElementSearcher(
                 only_expand_types, element_id, conf_section
             )
-            if searcher.element_found():
-                expanded_elements.append(searcher.get_element())
+            found_element = searcher.get_element()
+            if found_element is not None:
+                expanded_elements.append(found_element)
         else:
             expanded_elements.extend(
                 get_configuration_elements_by_id(conf_section, element_id)
