@@ -1,7 +1,16 @@
 from contextlib import contextmanager
+from typing import TYPE_CHECKING
 
 from pcs.lib.cib import acl
-from pcs.lib.cib.tools import get_acls
+from pcs.lib.cib.tools import (
+    IdProvider,
+    get_acls,
+)
+from pcs.lib.env import LibraryEnvironment
+from pcs.lib.errors import LibraryError
+
+if TYPE_CHECKING:
+    from pcs.common import reports
 
 
 @contextmanager
@@ -10,7 +19,12 @@ def cib_acl_section(env):
     env.push_cib()
 
 
-def create_role(lib_env, role_id, permission_info_list, description):
+def create_role(
+    lib_env: LibraryEnvironment,
+    role_id: str,
+    permission_info_list: acl.PermissionInfoList,
+    description: str,
+) -> None:
     """
     Create new acl role.
     Raises LibraryError on any failure.
@@ -22,11 +36,22 @@ def create_role(lib_env, role_id, permission_info_list, description):
     description -- text description for role
     """
     with cib_acl_section(lib_env) as acl_section:
+        id_provider = IdProvider(acl_section)
+        report_list = acl.validate_create_role(
+            id_provider, role_id, description
+        )
         if permission_info_list:
-            acl.validate_permissions(acl_section, permission_info_list)
+            report_list += acl.validate_permissions(
+                acl_section, permission_info_list
+            )
+        if lib_env.report_processor.report_list(report_list).has_errors:
+            raise LibraryError()
+
         role_el = acl.create_role(acl_section, role_id, description)
         if permission_info_list:
-            acl.add_permissions_to_role(role_el, permission_info_list)
+            acl.add_permissions_to_role(
+                role_el, permission_info_list, id_provider
+            )
 
 
 def remove_role(lib_env, role_id, autodelete_users_groups=False):
@@ -215,7 +240,11 @@ def remove_group(lib_env, group_id):
         acl.remove_group(acl_section, group_id)
 
 
-def add_permission(lib_env, role_id, permission_info_list):
+def add_permission(
+    lib_env: LibraryEnvironment,
+    role_id: str,
+    permission_info_list: acl.PermissionInfoList,
+) -> None:
     """
     Add permissions to a role with id role_id. If role doesn't exist it will be
     created.
@@ -227,10 +256,21 @@ def add_permission(lib_env, role_id, permission_info_list):
         (<read|write|deny>, <xpath|id>, <any string>)
     """
     with cib_acl_section(lib_env) as acl_section:
-        acl.validate_permissions(acl_section, permission_info_list)
-        acl.add_permissions_to_role(
-            acl.provide_role(acl_section, role_id), permission_info_list
+        report_list: reports.ReportItemList = []
+        id_provider = IdProvider(acl_section)
+
+        role_el = acl.find_role(acl_section, role_id, none_if_id_unused=True)
+        if role_el is None:
+            report_list += acl.validate_create_role(id_provider, role_id)
+        report_list += acl.validate_permissions(
+            acl_section, permission_info_list
         )
+        if lib_env.report_processor.report_list(report_list).has_errors:
+            raise LibraryError()
+
+        if role_el is None:
+            role_el = acl.create_role(acl_section, role_id)
+        acl.add_permissions_to_role(role_el, permission_info_list, id_provider)
 
 
 def remove_permission(lib_env, permission_id):
