@@ -1,12 +1,7 @@
 import base64
 import os.path
 from functools import partial
-from typing import (
-    Collection,
-    Mapping,
-    Optional,
-    cast,
-)
+from typing import Mapping, Optional, cast
 
 from lxml.etree import _Element
 
@@ -169,7 +164,7 @@ def config_setup(
         raise LibraryError()
 
 
-def config_destroy(
+def config_destroy(  # noqa: PLR0912
     env: LibraryEnvironment,
     instance_name: Optional[str] = None,
     ignore_config_load_problems: bool = False,
@@ -556,7 +551,7 @@ def create_in_cluster(
 def remove_from_cluster(
     env: LibraryEnvironment,
     instance_name: Optional[str] = None,
-    force_flags: Collection[reports.types.ForceCode] = (),
+    force_flags: reports.types.ForceFlags = (),
 ) -> None:
     """
     Remove group with ip resource and booth resource
