@@ -2,15 +2,9 @@
 import math
 import os.path
 import time
-from typing import (
-    Any,
-    Collection,
-    Mapping,
-    Optional,
-    Sequence,
-    Tuple,
-    cast,
-)
+from typing import Any, Mapping, Optional, Sequence, Tuple, cast
+
+from lxml.etree import _Element
 
 from pcs import settings
 from pcs.common import (
@@ -43,8 +37,10 @@ from pcs.lib import (
 )
 from pcs.lib.booth import sync as booth_sync
 from pcs.lib.cib import fencing_topology
+from pcs.lib.cib.nvpair_multi import NVSET_INSTANCE, find_nvsets
 from pcs.lib.cib.resource.bundle import verify as verify_bundles
 from pcs.lib.cib.resource.guest_node import find_node_list as get_guest_nodes
+from pcs.lib.cib.resource.primitive import find_primitives_by_agent
 from pcs.lib.cib.resource.remote_node import find_node_list as get_remote_nodes
 from pcs.lib.cib.tools import get_resources
 from pcs.lib.communication import cluster
@@ -71,16 +67,20 @@ from pcs.lib.communication.sbd import (
     EnableSbdService,
     SetSbdConfig,
 )
-from pcs.lib.communication.tools import AllSameDataMixin
+from pcs.lib.communication.tools import (
+    AllSameDataMixin,
+    CommunicationCommandInterface,
+    run,
+    run_and_raise,
+)
 from pcs.lib.communication.tools import run as run_com
-from pcs.lib.communication.tools import run_and_raise
 from pcs.lib.corosync import (
     config_facade,
     config_parser,
     config_validators,
+    qdevice_net,
 )
 from pcs.lib.corosync import constants as corosync_constants
-from pcs.lib.corosync import qdevice_net
 from pcs.lib.env import (
     LibraryEnvironment,
     WaitType,
@@ -91,13 +91,16 @@ from pcs.lib.interface.config import ParserErrorException
 from pcs.lib.node import get_existing_nodes_names
 from pcs.lib.pacemaker.live import (
     get_cib,
+    get_cib_file_runner_env,
     get_cib_xml,
     get_cib_xml_cmd_results,
+    has_cib_xml,
     remove_node,
 )
 from pcs.lib.pacemaker.live import verify as verify_cmd
 from pcs.lib.pacemaker.state import ClusterState
 from pcs.lib.pacemaker.values import get_valid_timeout_seconds
+from pcs.lib.resource_agent.types import ResourceAgentName
 from pcs.lib.tools import (
     environment_file_to_dict,
     generate_binary_key,
@@ -127,7 +130,7 @@ def node_clear(
         raise LibraryError()
 
     if node_name in current_nodes:
-        if env.report_processor.report(
+        env.report_processor.report(
             ReportItem(
                 severity=reports.item.get_severity(
                     report_codes.FORCE,
@@ -135,7 +138,8 @@ def node_clear(
                 ),
                 message=reports.messages.NodeToClearIsStillInCluster(node_name),
             )
-        ).has_errors:
+        )
+        if env.report_processor.has_errors:
             raise LibraryError()
 
     remove_node(env.cmd_runner(), node_name)
@@ -186,7 +190,7 @@ def verify(env: LibraryEnvironment, verbose=False):
         raise LibraryError()
 
 
-def setup(
+def setup(  # noqa:  PLR0913, PLR0915
     env: LibraryEnvironment,
     cluster_name: str,
     nodes: Sequence[Mapping[str, Any]],
@@ -202,7 +206,7 @@ def setup(
     enable: bool = False,
     no_keys_sync: bool = False,
     no_cluster_uuid: bool = False,
-    force_flags: Collection[reports.types.ForceCode] = (),
+    force_flags: reports.types.ForceFlags = (),
 ):
     # pylint: disable=too-many-arguments
     # pylint: disable=too-many-positional-arguments
@@ -448,7 +452,7 @@ def setup(
         )
 
 
-def setup_local(
+def setup_local(  # noqa: PLR0913
     env: LibraryEnvironment,
     cluster_name: str,
     nodes: Sequence[Mapping[str, Any]],
@@ -460,7 +464,7 @@ def setup_local(
     totem_options: Mapping[str, str],
     quorum_options: Mapping[str, str],
     no_cluster_uuid: bool = False,
-    force_flags: Collection[reports.types.ForceCode] = (),
+    force_flags: reports.types.ForceFlags = (),
 ) -> bytes:
     """
     Return corosync.conf text based on specified parameters.
@@ -574,7 +578,7 @@ def setup_local(
     )
 
 
-def _validate_create_corosync_conf(
+def _validate_create_corosync_conf(  # noqa: PLR0913
     cluster_name: str,
     nodes: Sequence[Mapping[str, Any]],
     transport_type: str,
@@ -635,7 +639,7 @@ def _validate_create_corosync_conf(
     )
 
 
-def _create_corosync_conf(
+def _create_corosync_conf(  # noqa: PLR0913
     cluster_name: str,
     nodes: Sequence[Mapping[str, Any]],
     transport_type: str,
@@ -838,14 +842,14 @@ def get_corosync_conf_struct(env: LibraryEnvironment) -> CorosyncConfDto:
         ) from e
 
 
-def add_nodes(
+def add_nodes(  # noqa: PLR0912, PLR0915
     env: LibraryEnvironment,
     nodes,
     wait=False,
     start=False,
     enable=False,
     no_watchdog_validation=False,
-    force_flags: Collection[reports.types.ForceCode] = (),
+    force_flags: reports.types.ForceFlags = (),
 ):
     # pylint: disable=too-many-branches
     # pylint: disable=too-many-locals
@@ -1380,6 +1384,7 @@ def add_nodes(
     if atb_has_to_be_enabled:
         corosync_conf.set_quorum_options(dict(auto_tie_breaker="1"))
 
+    # TODO why this does not use push_corosync_conf?
     _verify_corosync_conf(corosync_conf)  # raises if corosync not valid
     com_cmd = DistributeCorosyncConf(
         env.report_processor,
@@ -1442,7 +1447,7 @@ def _start_cluster(
         communicator_factory.get_communicator(request_timeout=timeout), com_cmd
     )
     if wait_timeout is not False:
-        if report_processor.report_list(
+        report_processor.report_list(
             _wait_for_pacemaker_to_start(
                 communicator_factory.get_communicator(),
                 report_processor,
@@ -1450,7 +1455,8 @@ def _start_cluster(
                 # wait_timeout is either None or a timeout
                 timeout=wait_timeout,
             )
-        ).has_errors:
+        )
+        if report_processor.has_errors:
             raise LibraryError()
 
 
@@ -1717,10 +1723,10 @@ def _verify_corosync_conf(corosync_conf_facade):
         )
 
 
-def remove_nodes(
+def remove_nodes(  # noqa: PLR0912, PLR0915
     env: LibraryEnvironment,
     node_list,
-    force_flags: Collection[reports.types.ForceCode] = (),
+    force_flags: reports.types.ForceFlags = (),
 ):
     # pylint: disable=too-many-branches
     # pylint: disable=too-many-locals
@@ -1962,7 +1968,7 @@ def remove_nodes_from_cib(env: LibraryEnvironment, node_list):
                 "--force",
                 f"--xpath=/cib/configuration/nodes/node[@uname='{node}']",
             ],
-            env_extend={"CIB_file": os.path.join(settings.cib_dir, "cib.xml")},
+            env_extend=get_cib_file_runner_env(),
         )
         if retval != 0:
             raise LibraryError(
@@ -1979,7 +1985,7 @@ def add_link(
     env: LibraryEnvironment,
     node_addr_map,
     link_options=None,
-    force_flags: Collection[reports.types.ForceCode] = (),
+    force_flags: reports.types.ForceFlags = (),
 ):
     """
     Add a corosync link to a cluster
@@ -2046,7 +2052,7 @@ def add_link(
 def remove_links(
     env: LibraryEnvironment,
     linknumber_list,
-    force_flags: Collection[reports.types.ForceCode] = (),
+    force_flags: reports.types.ForceFlags = (),
 ):
     """
     Remove corosync links from a cluster
@@ -2089,7 +2095,7 @@ def update_link(
     linknumber,
     node_addr_map=None,
     link_options=None,
-    force_flags: Collection[reports.types.ForceCode] = (),
+    force_flags: reports.types.ForceFlags = (),
 ):
     """
     Change an existing corosync link
@@ -2153,7 +2159,7 @@ def update_link(
 def corosync_authkey_change(
     env: LibraryEnvironment,
     corosync_authkey: Optional[bytes] = None,
-    force_flags: Collection[reports.types.ForceCode] = (),
+    force_flags: reports.types.ForceFlags = (),
 ) -> None:
     """
     Distribute new corosync authkey to all cluster nodes.
@@ -2211,11 +2217,12 @@ def corosync_authkey_change(
     )
 
     if not online_cluster_target_list:
-        if report_processor.report(
+        report_processor.report(
             ReportItem.error(
                 reports.messages.UnableToPerformOperationOnAnyNode()
             )
-        ).has_errors:
+        )
+        if report_processor.has_errors:
             raise LibraryError()
 
     com_cmd = DistributeFilesWithoutForces(
@@ -2252,7 +2259,7 @@ def _generate_cluster_uuid(
 
 def generate_cluster_uuid(
     env: LibraryEnvironment,
-    force_flags: Collection[reports.types.ForceCode] = (),
+    force_flags: reports.types.ForceFlags = (),
 ) -> None:
     """
     Add or update cluster UUID in live cluster
@@ -2272,7 +2279,7 @@ def generate_cluster_uuid(
 def generate_cluster_uuid_local(
     env: LibraryEnvironment,
     corosync_conf_content: bytes,
-    force_flags: Collection[reports.types.ForceCode] = (),
+    force_flags: reports.types.ForceFlags = (),
 ) -> bytes:
     """
     Add or update cluster UUID in corosync.conf passed as an argument and return
@@ -2318,3 +2325,99 @@ def wait_for_pcmk_idle(env: LibraryEnvironment, wait_value: WaitType) -> None:
     """
     timeout = env.ensure_wait_satisfiable(wait_value)
     env.wait_for_idle(timeout)
+
+
+def rename(
+    env: LibraryEnvironment,
+    new_name: str,
+    force_flags: reports.types.ForceFlags = (),
+) -> None:
+    """
+    Change the name of the local cluster
+
+    new_name -- new name for the cluster
+    """
+
+    def warn_dlm_resources(resources: _Element) -> reports.ReportItemList:
+        if find_primitives_by_agent(
+            resources, ResourceAgentName("ocf", "pacemaker", "controld")
+        ):
+            return [
+                reports.ReportItem.warning(
+                    reports.messages.DlmClusterRenameNeeded()
+                )
+            ]
+        return []
+
+    def warn_gfs2_resources(resources: _Element) -> reports.ReportItemList:
+        for resource in find_primitives_by_agent(
+            resources, ResourceAgentName("ocf", "heartbeat", "Filesystem")
+        ):
+            for nvset in find_nvsets(resource, NVSET_INSTANCE):
+                if any(
+                    (
+                        nvpair.get("name") == "fstype"
+                        and nvpair.get("value") == "gfs2"
+                    )
+                    for nvpair in nvset
+                ):
+                    return [
+                        reports.ReportItem.warning(
+                            reports.messages.Gfs2LockTableRenameNeeded()
+                        )
+                    ]
+        return []
+
+    _ensure_live_env(env)
+
+    if env.report_processor.report_list(
+        config_validators.rename_cluster(
+            new_name, force_cluster_name=reports.codes.FORCE in force_flags
+        )
+    ).has_errors:
+        raise LibraryError()
+
+    cib = None
+    if has_cib_xml():
+        cib = get_cib(get_cib_xml(env.cmd_runner(get_cib_file_runner_env())))
+        resources = get_resources(cib)
+        env.report_processor.report_list(warn_dlm_resources(resources))
+        env.report_processor.report_list(warn_gfs2_resources(resources))
+
+    corosync_conf = env.get_corosync_conf()
+    skip_offline = report_codes.SKIP_OFFLINE_NODES in force_flags
+
+    corosync_nodes, report_list = get_existing_nodes_names(corosync_conf, None)
+    if env.report_processor.report_list(report_list).has_errors:
+        raise LibraryError()
+    target_list = env.get_node_target_factory().get_target_list(
+        corosync_nodes,
+        allow_skip=skip_offline,
+    )
+
+    node_communicator = env.get_node_communicator()
+    com_cmd: CommunicationCommandInterface
+
+    com_cmd = CheckCorosyncOffline(env.report_processor, skip_offline)
+    com_cmd.set_targets(target_list)
+    running_targets = run(node_communicator, com_cmd)
+    if running_targets:
+        env.report_processor.report(
+            reports.ReportItem.error(
+                reports.messages.CorosyncNotRunningCheckFinishedRunning(
+                    [target.label for target in running_targets]
+                )
+            )
+        )
+    if env.report_processor.has_errors:
+        raise LibraryError()
+
+    # The 'cluster-name' property has to be removed from CIB on all nodes, so
+    # that it is initialized with the new cluster name from corosync after the
+    # cluster is started
+    com_cmd = cluster.RemoveCibClusterName(env.report_processor, skip_offline)
+    com_cmd.set_targets(target_list)
+    run_and_raise(node_communicator, com_cmd)
+
+    corosync_conf.set_cluster_name(new_name)
+    env.push_corosync_conf(corosync_conf, skip_offline)
