@@ -7,6 +7,6 @@ from . import common
 # configure common constraint command
 create_with_set = partial(
     common.create_with_set,
-    order.TAG_NAME,
+    order.TAG,
     order.prepare_options_with_set,
 )
