@@ -1,3 +1,4 @@
+import contextlib
 import os.path
 from typing import (
     Iterable,
@@ -46,6 +47,8 @@ from pcs.lib.external import CommandRunner
 from pcs.lib.node import get_existing_nodes_names
 from pcs.lib.node_communication import NodeTargetLibFactory
 from pcs.lib.pacemaker.live import (
+    BadApiResultFormat,
+    get_cib_verification_errors,
     get_cluster_status_text,
     get_cluster_status_xml_raw,
     get_ticket_status_text,
@@ -95,7 +98,7 @@ def resources_status(env: LibraryEnvironment) -> ResourcesStatusDto:
     return dto
 
 
-def full_cluster_status_plaintext(
+def full_cluster_status_plaintext(  # noqa: PLR0912, PLR0915
     env: LibraryEnvironment,
     hide_inactive_resources: bool = False,
     verbose: bool = False,
@@ -147,6 +150,20 @@ def full_cluster_status_plaintext(
     if not live or os.path.exists(settings.corosync_conf_file):
         corosync_conf = env.get_corosync_conf()
     cib = env.get_cib()
+    # get messages from crm_verify
+    crm_verify_messages = []
+    try:
+        crm_verify_messages = get_cib_verification_errors(runner)
+    except BadApiResultFormat as e:
+        # do not fail the whole command just because we cannot load this
+        report_processor.report(
+            reports.ReportItem.debug(
+                reports.messages.BadPcmkApiResponseFormat(
+                    str(e.original_exception), e.pacemaker_response
+                )
+            )
+        )
+    # get extra info for verbose output
     if verbose:
         (
             ticket_status_text,
@@ -156,12 +173,10 @@ def full_cluster_status_plaintext(
     # get extra info if live
     if live:
         service_manager = env.service_manager
-        try:
+        with contextlib.suppress(LibraryError):
             is_sbd_running = service_manager.is_running(
                 get_sbd_service_name(service_manager)
             )
-        except LibraryError:
-            pass
         local_services_status = _get_local_services_status(service_manager)
         if verbose and corosync_conf:
             node_name_list, node_names_report_list = get_existing_nodes_names(
@@ -185,6 +200,7 @@ def full_cluster_status_plaintext(
         _booth_authfile_warning(env.report_processor, env.get_booth_env(None))
     )
     warning_list.extend(_bundle_warnings(cib))
+    warning_list.extend(crm_verify_messages)
 
     # put it all together
     if report_processor.has_errors:
@@ -281,7 +297,7 @@ def _move_constraints_warnings(
 
     location_constraints, _ = get_all_as_dtos(constraint_el, rule_evaluator)
 
-    resource_ids = set(
+    resource_ids = {
         constraint_dto.resource_id
         for constraint_dto in location_constraints
         if constraint_dto.resource_id
@@ -293,7 +309,7 @@ def _move_constraints_warnings(
                 for rule in constraint_dto.attributes.rules
             )
         )
-    )
+    }
 
     if resource_ids:
         warning_list.append(
@@ -351,7 +367,7 @@ def _get_local_services_status(
     ]
     service_status_list = []
     for service, display_always in service_def:
-        try:
+        with contextlib.suppress(LibraryError):
             service_status_list.append(
                 _ServiceStatus(
                     service,
@@ -360,8 +376,6 @@ def _get_local_services_status(
                     service_manager.is_running(service),
                 )
             )
-        except LibraryError:
-            pass
     return service_status_list
 
 
