@@ -1,11 +1,4 @@
-from typing import (
-    Collection,
-    Container,
-    List,
-    Mapping,
-    Optional,
-    Tuple,
-)
+from typing import Collection, List, Mapping, Optional, Tuple
 
 from lxml.etree import _Element
 
@@ -20,6 +13,7 @@ from pcs.lib.cib.nvpair import (
 )
 from pcs.lib.cib.tools import IdProvider
 from pcs.lib.commands.resource import (
+    _are_meta_disabled,
     _ensure_disabled_after_wait,
     resource_environment,
 )
@@ -96,7 +90,7 @@ def _get_agent_facade(
         raise LibraryError() from e
 
 
-def create(
+def create(  # noqa: PLR0913
     env: LibraryEnvironment,
     stonith_id: str,
     stonith_agent_name: str,
@@ -161,8 +155,7 @@ def create(
         wait,
         [stonith_id],
         _ensure_disabled_after_wait(
-            ensure_disabled
-            or resource.common.are_meta_disabled(meta_attributes),
+            ensure_disabled or _are_meta_disabled(meta_attributes)
         ),
     ) as resources_section:
         id_provider = IdProvider(resources_section)
@@ -303,7 +296,7 @@ def _unfencing_scsi_devices(
     stonith_el: _Element,
     original_devices: StringCollection,
     updated_devices: StringCollection,
-    force_flags: Container[reports.types.ForceCode] = (),
+    force_flags: reports.types.ForceFlags = (),
 ) -> None:
     """
     Unfence scsi devices provided in device_list if it is possible to connect
@@ -364,7 +357,7 @@ def update_scsi_devices(
     env: LibraryEnvironment,
     stonith_id: str,
     set_device_list: StringCollection,
-    force_flags: Container[reports.types.ForceCode] = (),
+    force_flags: reports.types.ForceFlags = (),
 ) -> None:
     """
     Update scsi fencing devices without restart and affecting other resources.
@@ -410,7 +403,7 @@ def update_scsi_devices_add_remove(
     stonith_id: str,
     add_device_list: StringCollection,
     remove_device_list: StringCollection,
-    force_flags: Container[reports.types.ForceCode] = (),
+    force_flags: reports.types.ForceFlags = (),
 ) -> None:
     """
     Update scsi fencing devices without restart and affecting other resources.
