@@ -2,14 +2,14 @@ import base64
 import json
 
 from pcs.common import reports
-from pcs.common.reports.item import ReportItem
 from pcs.common.node_communicator import RequestData
+from pcs.common.reports.item import ReportItem
 from pcs.lib.communication.tools import (
     AllAtOnceStrategyMixin,
     AllSameDataMixin,
     RunRemotelyBase,
-    SkipOfflineMixin,
     SimpleResponseProcessingMixin,
+    SkipOfflineMixin,
 )
 
 
@@ -40,7 +40,7 @@ class BoothSendConfig(
     def _get_request_data(self):
         data = {
             "config": {
-                "name": "{0}.conf".format(self._booth_name),
+                "name": f"{self._booth_name}.conf",
                 "data": self._config_data,
             }
         }
@@ -149,7 +149,7 @@ class BoothSaveFiles(
                 self._report(
                     ReportItem(
                         severity=reports.item.get_severity(
-                            reports.codes.FORCE_FILE_OVERWRITE,
+                            reports.codes.FORCE,
                             self._rewrite_existing,
                         ),
                         message=reports.messages.FileAlreadyExists(
