@@ -234,7 +234,7 @@ class RunActionBase(
             self._start_report(
                 [
                     self._action_key_to_report(key)
-                    for key in self._action_definition.keys()
+                    for key in self._action_definition
                 ],
                 [target.label for target in self._target_list],
             )
@@ -441,12 +441,11 @@ class CheckPacemakerStarted(
                     reports.messages.InvalidResponseFormat(target.label)
                 )
 
-        else:
-            if not response.was_connected:
-                self._not_yet_started_target_list.append(target)
-                report = response_to_report_item(
-                    response, severity=ReportItemSeverity.WARNING
-                )
+        elif not response.was_connected:
+            self._not_yet_started_target_list.append(target)
+            report = response_to_report_item(
+                response, severity=ReportItemSeverity.WARNING
+            )
         self._report(report)
 
     def before(self):
