@@ -105,6 +105,19 @@ class ConfigFacade(FacadeInterface):
     def get_cluster_name(self) -> str:
         return self._get_option_value("totem", "cluster_name", "")
 
+    def set_cluster_name(self, new_name: str) -> None:
+        """
+        Updates or adds cluster name
+
+        new_name -- new name for the cluster
+        """
+        self._need_stopped_cluster = True
+        totem_section_list = self.__ensure_section(self.config, "totem")
+        self.__set_section_options(
+            totem_section_list, {"cluster_name": new_name}
+        )
+        self.__remove_empty_sections(self.config)
+
     def get_cluster_uuid(self) -> Optional[str]:
         return self._get_option_value("totem", "cluster_uuid")
 
@@ -202,7 +215,9 @@ class ConfigFacade(FacadeInterface):
         link_ids: Sequence[int],
     ) -> Section:
         node_section = Section("node")
-        for link_id, link_addr in zip(link_ids, node_options["addrs"]):
+        for link_id, link_addr in zip(
+            link_ids, node_options["addrs"], strict=False
+        ):
             node_section.add_attribute(f"ring{link_id}_addr", link_addr)
         node_section.add_attribute("name", str(node_options["name"]))
         node_section.add_attribute("nodeid", str(node_id))
@@ -262,8 +277,8 @@ class ConfigFacade(FacadeInterface):
             else:
                 linknumber_missing.append(link)
 
-        for link in linknumber_missing:
-            link = dict(link)
+        for link_missing_linknumber in linknumber_missing:
+            link = dict(link_missing_linknumber)
             try:
                 link["linknumber"] = str(available_link_numbers.pop(0))
             except IndexError as e:
@@ -398,18 +413,17 @@ class ConfigFacade(FacadeInterface):
             del options_without_linknumber["linknumber"]
         # change options
         if options_without_linknumber:
-            target_interface_section_list = []
-            for totem_section in self.config.get_sections("totem"):
-                for interface_section in totem_section.get_sections(
-                    "interface"
-                ):
-                    if (
-                        linknumber
-                        ==
-                        # if no linknumber is set, corosync treats it as 0
-                        interface_section.get_attribute_value("linknumber", "0")
-                    ):
-                        target_interface_section_list.append(interface_section)
+            target_interface_section_list = [
+                interface_section
+                for totem_section in self.config.get_sections("totem")
+                for interface_section in totem_section.get_sections("interface")
+                if (
+                    linknumber
+                    ==
+                    # if no linknumber is set, corosync treats it as 0
+                    interface_section.get_attribute_value("linknumber", "0")
+                )
+            ]
             self._set_link_options(
                 options_without_linknumber,
                 interface_section_list=target_interface_section_list,
@@ -680,9 +694,13 @@ class ConfigFacade(FacadeInterface):
         heuristics_options: dict[str, str] = {}
         for quorum in self.config.get_sections("quorum"):
             for device in quorum.get_sections("device"):
-                for name, value in device.get_attributes():
-                    if name != "model":
-                        generic_options[name] = value
+                generic_options.update(
+                    {
+                        name: value
+                        for name, value in device.get_attributes()
+                        if name != "model"
+                    }
+                )
                 for subsection in device.get_sections():
                     if subsection.name == "heuristics":
                         heuristics_options.update(subsection.get_attributes())
@@ -952,13 +970,12 @@ class ConfigFacade(FacadeInterface):
                     result["broadcast"] = ""
                 else:
                     del result["broadcast"]
+            # When displaying config to users, do the opposite
+            # transformation: only "yes" is allowed.
+            elif result["broadcast"] == "yes":
+                result["broadcast"] = "1"
             else:
-                # When displaying config to users, do the opposite
-                # transformation: only "yes" is allowed.
-                if result["broadcast"] == "yes":
-                    result["broadcast"] = "1"
-                else:
-                    del result["broadcast"]
+                del result["broadcast"]
 
         return result
 
