@@ -92,7 +92,7 @@ class _ClusterNameGfs2Validator(validate.ValueValidator):
         return []
 
 
-def create(
+def create(  # noqa: PLR0912, PLR0915
     cluster_name: str,
     # TODO change to DTO, needs new validator
     node_list: Iterable[Mapping[str, Any]],
@@ -117,20 +117,7 @@ def create(
         warnings instead of errors
     """
     # cluster name and transport validation
-    validators = [
-        validate.ValueNotEmpty(
-            "name", None, option_name_for_report="cluster name"
-        ),
-        _ClusterNameGfs2Validator(
-            "name",
-            option_name_for_report="cluster name",
-            severity=reports.item.get_severity(
-                reports.codes.FORCE, force_cluster_name
-            ),
-        ),
-        validate.ValueCorosyncValue(
-            "name", option_name_for_report="cluster name"
-        ),
+    validators = _get_cluster_name_validators(force_cluster_name) + [
         validate.ValueIn("transport", constants.TRANSPORTS_ALL),
         validate.ValueCorosyncValue("transport"),
     ]
@@ -286,6 +273,26 @@ def create(
     return report_items
 
 
+def _get_cluster_name_validators(
+    force_cluster_name: bool,
+) -> list[validate.ValidatorInterface]:
+    return [
+        validate.ValueNotEmpty(
+            "name", None, option_name_for_report="cluster name"
+        ),
+        _ClusterNameGfs2Validator(
+            "name",
+            option_name_for_report="cluster name",
+            severity=reports.item.get_severity(
+                reports.codes.FORCE, force_cluster_name
+            ),
+        ),
+        validate.ValueCorosyncValue(
+            "name", option_name_for_report="cluster name"
+        ),
+    ]
+
+
 def _get_node_name_validators(
     node_index: int,
 ) -> list[validate.ValidatorInterface]:
@@ -402,7 +409,7 @@ def _report_unresolvable_addresses_if_any(
     ]
 
 
-def add_nodes(
+def add_nodes(  # noqa: PLR0912, PLR0915
     # TODO change to DTO, needs new validator
     node_list: Iterable[Mapping[str, Any]],
     coro_existing_nodes: Iterable[CorosyncNode],
@@ -622,11 +629,11 @@ def remove_nodes(
     quorum_device_settings -- model, generic and heuristic qdevice options
     """
     existing_node_names = [node.name for node in existing_nodes]
-    report_items = []
-    for not_found_node in set(nodes_names_to_remove) - set(existing_node_names):
-        report_items.append(
-            ReportItem.error(reports.messages.NodeNotFound(not_found_node))
-        )
+    report_items = [
+        ReportItem.error(reports.messages.NodeNotFound(not_found_node))
+        for not_found_node in set(nodes_names_to_remove)
+        - set(existing_node_names)
+    ]
 
     if not set(existing_node_names) - set(nodes_names_to_remove):
         report_items.append(
@@ -637,20 +644,20 @@ def remove_nodes(
         qdevice_model_options, _, _ = quorum_device_settings
         tie_breaker_nodeid = qdevice_model_options.get("tie_breaker")
         if tie_breaker_nodeid not in [None, "lowest", "highest"]:
-            for node in existing_nodes:
+            report_items.extend(
+                ReportItem.error(
+                    reports.messages.NodeUsedAsTieBreaker(
+                        node.name, node.nodeid
+                    )
+                )
+                for node in existing_nodes
                 if (
                     node.name in nodes_names_to_remove
                     and
                     # "4" != 4, convert ids to string to detect a match for sure
                     str(node.nodeid) == str(tie_breaker_nodeid)
-                ):
-                    report_items.append(
-                        ReportItem.error(
-                            reports.messages.NodeUsedAsTieBreaker(
-                                node.name, node.nodeid
-                            )
-                        )
-                    )
+                )
+            )
 
     return report_items
 
@@ -785,21 +792,23 @@ def create_link_list_knet(
     for options in link_list:
         if "linknumber" in options:
             used_link_number[options["linknumber"]] += 1
-            if validate.is_integer(
-                options["linknumber"], 0, constants.LINKS_KNET_MAX - 1
+            if (
+                validate.is_integer(
+                    options["linknumber"], 0, constants.LINKS_KNET_MAX - 1
+                )
+                and int(options["linknumber"]) >= max_allowed_link_count
             ):
-                if int(options["linknumber"]) >= max_allowed_link_count:
-                    # first link is link0, hence >=
-                    report_items.append(
-                        # Links are defined by node addresses. Therefore we
-                        # update link options here, we do not create links.
-                        ReportItem.error(
-                            reports.messages.CorosyncLinkDoesNotExistCannotUpdate(
-                                options["linknumber"],
-                                [str(x) for x in range(max_allowed_link_count)],
-                            )
+                # first link is link0, hence >=
+                report_items.append(
+                    # Links are defined by node addresses. Therefore we
+                    # update link options here, we do not create links.
+                    ReportItem.error(
+                        reports.messages.CorosyncLinkDoesNotExistCannotUpdate(
+                            options["linknumber"],
+                            [str(x) for x in range(max_allowed_link_count)],
                         )
                     )
+                )
         report_items += _add_link_options_knet(options)
     non_unique_linknumbers = [
         number for number, count in used_link_number.items() if count > 1
@@ -861,9 +870,9 @@ def _get_link_options_validators_knet(
     )
 
 
-def _get_link_options_validators_knet_relations() -> (
-    list[validate.ValidatorInterface]
-):
+def _get_link_options_validators_knet_relations() -> list[
+    validate.ValidatorInterface
+]:
     return [
         validate.DependsOnOption(
             ["ping_interval"],
@@ -912,9 +921,7 @@ def _update_link_options_knet(
         )
     ).validate(new_options) + validate.ValidatorAll(
         _get_link_options_validators_knet_relations()
-    ).validate(
-        after_update
-    )
+    ).validate(after_update)
 
 
 def add_link(
@@ -1140,7 +1147,7 @@ def remove_links(
     return report_items
 
 
-def update_link(
+def update_link(  # noqa: PLR0912, PLR0913
     linknumber: str,
     node_addr_map: Mapping[str, str],
     link_options: Mapping[str, str],
@@ -2039,7 +2046,7 @@ def _get_qdevice_generic_options_validators(
 
 
 def _split_heuristics_exec_options(
-    options: Mapping[str, str]
+    options: Mapping[str, str],
 ) -> tuple[dict[str, str], dict[str, str]]:
     options_exec = {}
     options_nonexec = {}
@@ -2163,3 +2170,11 @@ def _mixes_ipv4_ipv6(addr_types: Collection[CorosyncNodeAddressType]) -> bool:
     return {CorosyncNodeAddressType.IPV4, CorosyncNodeAddressType.IPV6} <= set(
         addr_types
     )
+
+
+def rename_cluster(
+    cluster_name: str, force_cluster_name: bool = False
+) -> ReportItemList:
+    return validate.ValidatorAll(
+        _get_cluster_name_validators(force_cluster_name)
+    ).validate({"name": cluster_name})
