@@ -14,8 +14,8 @@ from pcs.common.file import (
 from pcs.lib.file import (
     metadata,
     raw_file,
-    toolbox,
 )
+from pcs.lib.file import toolbox as file_toolbox
 from pcs.lib.interface.config import (
     FacadeInterface,
     ParserErrorException,
@@ -78,7 +78,7 @@ class FileInstance:
                 ghost_file,
                 ghost_data,
             ),
-            toolbox.for_file_type(file_type_code),
+            file_toolbox.for_file_type(file_type_code),
         )
 
     @classmethod
@@ -86,58 +86,62 @@ class FileInstance:
         """
         Factory for known-hosts file
         """
-        return cls._for_common(file_type_codes.PCS_KNOWN_HOSTS)
+        return cls.for_common(file_type_codes.PCS_KNOWN_HOSTS)
 
     @classmethod
     def for_pacemaker_key(cls) -> "FileInstance":
         """
         Factory for pacemaker key file
         """
-        return cls._for_common(file_type_codes.PACEMAKER_AUTHKEY)
+        return cls.for_common(file_type_codes.PACEMAKER_AUTHKEY)
 
     @classmethod
     def for_dr_config(cls) -> "FileInstance":
         """
         Factory for disaster-recovery config file
         """
-        return cls._for_common(file_type_codes.PCS_DR_CONFIG)
+        return cls.for_common(file_type_codes.PCS_DR_CONFIG)
 
     @classmethod
     def for_corosync_conf(cls) -> "FileInstance":
         """
         Factory for corosync config file
         """
-        return cls._for_common(file_type_codes.COROSYNC_CONF)
+        return cls.for_common(file_type_codes.COROSYNC_CONF)
 
     @classmethod
     def for_qnetd_ca_cert(cls) -> "FileInstance":
         """
         Factory for corosync qnetd CA certificate
         """
-        return cls._for_common(file_type_codes.COROSYNC_QNETD_CA_CERT)
+        return cls.for_common(file_type_codes.COROSYNC_QNETD_CA_CERT)
 
     @classmethod
     def for_pcs_users_config(cls) -> "FileInstance":
-        return cls._for_common(file_type_codes.PCS_USERS_CONF)
+        return cls.for_common(file_type_codes.PCS_USERS_CONF)
 
     @classmethod
     def for_pcs_settings_config(cls) -> "FileInstance":
-        return cls._for_common(file_type_codes.PCS_SETTINGS_CONF)
+        return cls.for_common(file_type_codes.PCS_SETTINGS_CONF)
 
     @classmethod
-    def _for_common(
+    def for_cfgsync_ctl(cls) -> "FileInstance":
+        return cls.for_common(file_type_codes.CFGSYNC_CTL)
+
+    @classmethod
+    def for_common(
         cls,
         file_type_code: file_type_codes.FileTypeCode,
     ) -> "FileInstance":
         return cls(
             raw_file.RealFile(metadata.for_file_type(file_type_code)),
-            toolbox.for_file_type(file_type_code),
+            file_toolbox.for_file_type(file_type_code),
         )
 
     def __init__(
         self,
         raw_file_interface: RawFileInterface,
-        file_toolbox: toolbox.FileToolbox,
+        file_toolbox: file_toolbox.FileToolbox,
     ):
         """
         Factories should be used instead
@@ -156,7 +160,7 @@ class FileInstance:
         return self._raw_file
 
     @property
-    def toolbox(self) -> toolbox.FileToolbox:
+    def toolbox(self) -> file_toolbox.FileToolbox:
         """
         Get the underlying FileToolbox instance
         """
