@@ -32,6 +32,17 @@ def _for_booth_key(filename: str) -> FileMetadata:
     )
 
 
+def _for_cfgsync_ctl() -> FileMetadata:
+    return FileMetadata(
+        file_type_code=code.CFGSYNC_CTL,
+        path=settings.cfgsync_ctl_location,
+        owner_user_name="root",
+        owner_group_name="root",
+        permissions=0o600,
+        is_binary=False,
+    )
+
+
 def _for_corosync_conf() -> FileMetadata:
     return FileMetadata(
         file_type_code=code.COROSYNC_CONF,
@@ -112,7 +123,7 @@ def _for_pcs_settings_conf() -> FileMetadata:
     )
 
 
-def for_file_type(
+def for_file_type(  # noqa: PLR0911
     file_type_code: code.FileTypeCode, filename: Optional[str] = None
 ) -> FileMetadata:
     # pylint: disable=too-many-return-statements
@@ -124,6 +135,8 @@ def for_file_type(
         if not filename:
             raise AssertionError("filename must be set")
         return _for_booth_key(filename)
+    if file_type_code == code.CFGSYNC_CTL:
+        return _for_cfgsync_ctl()
     if file_type_code == code.COROSYNC_CONF:
         return _for_corosync_conf()
     if file_type_code == code.COROSYNC_QNETD_CA_CERT:
