@@ -1,5 +1,3 @@
-import sys
-
 from pcs.cli.common.errors import CmdLineInputError
 
 
@@ -14,7 +12,7 @@ def qdevice_status_cmd(lib, argv, modifiers):
     model = argv[0]
     cluster = None if len(argv) < 2 else argv[1]
     print(
-        lib.qdevice.status(
+        lib.qdevice.qdevice_status_text(
             model,
             verbose=modifiers.get("--full"),
             cluster=cluster,
@@ -34,7 +32,7 @@ def qdevice_setup_cmd(lib, argv, modifiers):
     if argv[0] != "model":
         raise CmdLineInputError()
     model = argv[1]
-    lib.qdevice.setup(
+    lib.qdevice.qdevice_setup(
         model, modifiers.get("--enable"), modifiers.get("--start")
     )
 
@@ -48,7 +46,7 @@ def qdevice_destroy_cmd(lib, argv, modifiers):
     if len(argv) != 1:
         raise CmdLineInputError()
     model = argv[0]
-    lib.qdevice.destroy(model, proceed_if_used=modifiers.get("--force"))
+    lib.qdevice.qdevice_destroy(model, proceed_if_used=modifiers.get("--force"))
 
 
 def qdevice_start_cmd(lib, argv, modifiers):
@@ -59,7 +57,7 @@ def qdevice_start_cmd(lib, argv, modifiers):
     if len(argv) != 1:
         raise CmdLineInputError()
     model = argv[0]
-    lib.qdevice.start(model)
+    lib.qdevice.qdevice_start(model)
 
 
 def qdevice_stop_cmd(lib, argv, modifiers):
@@ -71,7 +69,7 @@ def qdevice_stop_cmd(lib, argv, modifiers):
     if len(argv) != 1:
         raise CmdLineInputError()
     model = argv[0]
-    lib.qdevice.stop(model, proceed_if_used=modifiers.get("--force"))
+    lib.qdevice.qdevice_stop(model, proceed_if_used=modifiers.get("--force"))
 
 
 def qdevice_kill_cmd(lib, argv, modifiers):
@@ -82,7 +80,7 @@ def qdevice_kill_cmd(lib, argv, modifiers):
     if len(argv) != 1:
         raise CmdLineInputError()
     model = argv[0]
-    lib.qdevice.kill(model)
+    lib.qdevice.qdevice_kill(model)
 
 
 def qdevice_enable_cmd(lib, argv, modifiers):
@@ -93,7 +91,7 @@ def qdevice_enable_cmd(lib, argv, modifiers):
     if len(argv) != 1:
         raise CmdLineInputError()
     model = argv[0]
-    lib.qdevice.enable(model)
+    lib.qdevice.qdevice_enable(model)
 
 
 def qdevice_disable_cmd(lib, argv, modifiers):
@@ -104,64 +102,4 @@ def qdevice_disable_cmd(lib, argv, modifiers):
     if len(argv) != 1:
         raise CmdLineInputError()
     model = argv[0]
-    lib.qdevice.disable(model)
-
-
-# following commands are internal use only, called from pcsd
-
-
-def qdevice_net_client_setup_cmd(lib, argv, modifiers):
-    """
-    Options: no options
-    """
-    modifiers.ensure_only_supported()
-    if argv:
-        raise CmdLineInputError()
-    ca_certificate = _read_stdin()
-    lib.qdevice.client_net_setup(ca_certificate)
-
-
-def qdevice_net_client_import_certificate_cmd(lib, argv, modifiers):
-    """
-    Options: no options
-    """
-    modifiers.ensure_only_supported()
-    if argv:
-        raise CmdLineInputError()
-    certificate = _read_stdin()
-    lib.qdevice.client_net_import_certificate(certificate)
-
-
-def qdevice_net_client_destroy(lib, argv, modifiers):
-    """
-    Options: no options
-    """
-    modifiers.ensure_only_supported()
-    if argv:
-        raise CmdLineInputError()
-    lib.qdevice.client_net_destroy()
-
-
-def qdevice_sign_net_cert_request_cmd(lib, argv, modifiers):
-    """
-    Options:
-      * --name - cluster name
-    """
-    modifiers.ensure_only_supported("--name")
-    if argv:
-        raise CmdLineInputError()
-    certificate_request = _read_stdin()
-    signed = lib.qdevice.sign_net_cert_request(
-        certificate_request, modifiers.get("--name")
-    )
-    # In python3 base64.b64encode returns bytes.
-    # Bytes is printed like this: b'bytes content'
-    # and we need to get rid of that b'', so we change bytes to string.
-    # Since it's base64encoded, it's safe to use ascii.
-    signed = signed.decode("ascii")
-    print(signed)
-
-
-def _read_stdin():
-    # in python3 stdin returns str so we need to use buffer
-    return sys.stdin.buffer.read()
+    lib.qdevice.qdevice_disable(model)
