@@ -19,13 +19,13 @@ from pcs.cli.common.parse_args import (
 )
 from pcs.cli.fencing_topology import target_type_map_cli_to_lib
 from pcs.cli.reports.output import (
-    error,
     print_to_stderr,
 )
 from pcs.cli.resource.output import resource_agent_metadata_to_text
 from pcs.cli.resource.parse_args import (
     parse_primitive as parse_primitive_resource,
 )
+from pcs.cli.stonith.common import check_is_stonith
 from pcs.cli.stonith.levels.output import stonith_level_config_to_text
 from pcs.common import reports
 from pcs.common.fencing_topology import TARGET_TYPE_ATTRIBUTE
@@ -36,7 +36,6 @@ from pcs.common.pacemaker.resource.list import (
 from pcs.common.resource_agent.dto import ResourceAgentNameDto
 from pcs.common.str_tools import (
     format_list,
-    format_optional,
     format_plural,
     indent,
 )
@@ -76,8 +75,7 @@ def stonith_list_available(
         if search:
             utils.err("No stonith agents matching the filter.")
         utils.err(
-            "No stonith agents available. "
-            "Do you have fence agents installed?"
+            "No stonith agents available. Do you have fence agents installed?"
         )
 
     for agent_info in agent_list:
@@ -88,7 +86,7 @@ def stonith_list_available(
                 "{0} - {1}".format(
                     name,
                     # pylint: disable=protected-access
-                    resource._format_desc(
+                    resource._format_desc(  # noqa: SLF001
                         len(name + " - "), shortdesc.replace("\n", " ")
                     ),
                 )
@@ -123,18 +121,6 @@ def stonith_list_options(
     )
 
 
-def _check_is_stonith(
-    lib: Any,
-    resource_id_list: list[str],
-    cmd_to_use: Optional[str] = None,
-) -> None:
-    if lib.resource.is_any_resource_except_stonith(resource_id_list):
-        raise error(
-            reports.messages.CommandArgumentTypeMismatch("resources").message
-            + format_optional(cmd_to_use, " Please use '{}' instead.")
-        )
-
-
 def stonith_create(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     Options:
@@ -254,7 +240,7 @@ def stonith_level_add_cmd(
     level_id = parser.get_unique().get("id")
     target_type, target_value = _stonith_level_parse_node(argv[1])
     stonith_devices = argv[2:]
-    _check_is_stonith(lib, stonith_devices)
+    check_is_stonith(lib, stonith_devices)
 
     lib.fencing_topology.add_level(
         level,
@@ -416,9 +402,18 @@ def sbd_watchdog_list(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     available_watchdogs = lib.sbd.get_local_available_watchdogs()
 
     if available_watchdogs:
-        print("Available watchdog(s):")
+        key_label = {
+            "identity": "Identity",
+            "driver": "Driver",
+        }
+        lines = []
         for watchdog in sorted(available_watchdogs.keys()):
-            print(f"  {watchdog}")
+            lines += [watchdog]
+            for key, label in key_label.items():
+                value = available_watchdogs[watchdog].get(key)
+                if value:
+                    lines += indent([f"{label}: {value}"])
+        print("Available watchdog(s):\n" + "\n".join(indent(lines)))
     else:
         print_to_stderr("No available watchdog")
 
@@ -549,12 +544,21 @@ def sbd_disable(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     Options:
       * --request-timeout - HTTP request timeout
       * --skip-offline - skip offline cluster nodes
+      * --force - override validation errors
     """
-    modifiers.ensure_only_supported("--request-timeout", "--skip-offline")
+    modifiers.ensure_only_supported(
+        "--request-timeout", "--skip-offline", "--force"
+    )
     if argv:
         raise CmdLineInputError()
 
-    lib.sbd.disable_sbd(modifiers.get("--skip-offline"))
+    force_flags = set()
+    if modifiers.is_specified("--force"):
+        force_flags.add(reports.codes.FORCE)
+    if modifiers.is_specified("--skip-offline"):
+        force_flags.add(reports.codes.SKIP_OFFLINE_NODES)
+
+    lib.sbd.disable_sbd(modifiers.get("--skip-offline"), force_flags)
 
 
 def sbd_status(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
@@ -852,7 +856,7 @@ def enable_cmd(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
             "You must specify stonith resource(s) to enable"
         )
     resources = argv
-    _check_is_stonith(lib, resources, "pcs resource enable")
+    check_is_stonith(lib, resources, "pcs resource enable")
     lib.resource.enable(resources, modifiers.get("--wait"))
 
 
@@ -860,14 +864,17 @@ def disable_cmd(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     Options:
       * -f - CIB file
+      * --force
       * --wait
     """
     if not argv:
         raise CmdLineInputError(
             "You must specify stonith resource(s) to disable"
         )
-    _check_is_stonith(lib, argv, "pcs resource disable")
-    modifiers.ensure_only_supported("-f", "--wait", hint_syntax_changed="0.12")
+    check_is_stonith(lib, argv, "pcs resource disable")
+    modifiers.ensure_only_supported(
+        "-f", "--force", "--wait", hint_syntax_changed="0.12"
+    )
     resource.resource_disable_common(lib, argv, modifiers)
 
 
@@ -881,7 +888,7 @@ def update_cmd(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     if not argv:
         raise CmdLineInputError()
-    _check_is_stonith(lib, [argv[0]], "pcs resource update")
+    check_is_stonith(lib, [argv[0]], "pcs resource update")
     resource.resource_update(argv, modifiers)
 
 
@@ -893,7 +900,7 @@ def op_add_cmd(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     if not argv:
         raise CmdLineInputError()
-    _check_is_stonith(lib, [argv[0]], "pcs resource op add")
+    check_is_stonith(lib, [argv[0]], "pcs resource op add")
     resource.resource_op_add(argv, modifiers)
 
 
@@ -905,18 +912,5 @@ def op_delete_cmd(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     modifiers.ensure_only_supported("-f")
     if not argv:
         raise CmdLineInputError()
-    _check_is_stonith(lib, [argv[0]], "pcs resource op delete")
+    check_is_stonith(lib, [argv[0]], "pcs resource op delete")
     resource.resource_operation_remove(argv[0], argv[1:])
-
-
-def meta_cmd(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
-    """
-    Options:
-      * --force - allow not suitable command
-      * --wait
-      * -f - CIB file
-    """
-    if not argv:
-        raise CmdLineInputError()
-    _check_is_stonith(lib, [argv[0]], "pcs resource meta")
-    resource.resource_meta(argv, modifiers)
