@@ -13,15 +13,16 @@ import tempfile
 import threading
 import time
 import xml.dom.minidom
-import xml.etree.ElementTree as ET
 from functools import lru_cache
 from io import BytesIO
 from textwrap import dedent
 from typing import (
+    TYPE_CHECKING,
     Any,
     Dict,
     Optional,
     Tuple,
+    cast,
 )
 from urllib.parse import urlencode
 from xml.dom.minidom import Document as DomDocument
@@ -44,12 +45,10 @@ from pcs.cli.common.tools import (
     timeout_to_seconds_legacy,
 )
 from pcs.cli.file import metadata as cli_file_metadata
-from pcs.cli.reports import ReportProcessorToConsole
+from pcs.cli.reports import ReportProcessorToConsole, process_library_reports
 from pcs.cli.reports import output as reports_output
-from pcs.cli.reports import process_library_reports
-from pcs.common import const
+from pcs.common import const, file_type_codes
 from pcs.common import file as pcs_file
-from pcs.common import file_type_codes
 from pcs.common import pacemaker as common_pacemaker
 from pcs.common import pcs_pycurl as pycurl
 from pcs.common.host import PcsKnownHost
@@ -57,7 +56,6 @@ from pcs.common.pacemaker.resource.operations import (
     OCF_CHECK_LEVEL_INSTANCE_ATTRIBUTE_NAME,
 )
 from pcs.common.reports import ReportProcessor
-from pcs.common.reports.item import ReportItemList
 from pcs.common.reports.messages import CibUpgradeFailedToMinimalRequiredVersion
 from pcs.common.services.errors import ManageServiceError
 from pcs.common.services.interfaces import ServiceManagerInterface
@@ -75,6 +73,7 @@ from pcs.lib.external import (
     is_proxy_set,
 )
 from pcs.lib.file.instance import FileInstance as LibFileInstance
+from pcs.lib.host.config.facade import Facade as KnownHostsFacade
 from pcs.lib.interface.config import ParserErrorException
 from pcs.lib.pacemaker.live import get_cluster_status_dom
 from pcs.lib.pacemaker.state import ClusterState
@@ -83,6 +82,9 @@ from pcs.lib.pacemaker.values import validate_id
 from pcs.lib.services import get_service_manager as _get_service_manager
 from pcs.lib.services import service_exception_to_report
 
+if TYPE_CHECKING:
+    from pcs.common.reports.item import ReportItemList
+
 # pylint: disable=invalid-name
 # pylint: disable=too-many-branches
 
@@ -205,8 +207,8 @@ def read_uid_gid_file(uidgid_filename):
     ) as myfile:
         data = myfile.read().split("\n")
     in_uidgid = False
-    for line in data:
-        line = re.sub(r"#.*", "", line)
+    for data_line in data:
+        line = re.sub(r"#.*", "", data_line)
         if not in_uidgid:
             if re.search(r"uidgid.*{", line):
                 in_uidgid = True
@@ -313,15 +315,14 @@ def remove_uid_gid_file(uid, gid):
 
 
 @lru_cache()
-def read_known_hosts_file():
+def read_known_hosts_file() -> dict[str, PcsKnownHost]:
     return read_known_hosts_file_not_cached()
 
 
-def read_known_hosts_file_not_cached():
+def read_known_hosts_file_not_cached() -> dict[str, PcsKnownHost]:
     """
     Commandline options: no options
     """
-    data = {}
     try:
         if os.getuid() != 0:
             known_hosts_raw_file = pcs_file.RawFile(
@@ -329,26 +330,28 @@ def read_known_hosts_file_not_cached():
             )
             # json.loads handles bytes, it expects utf-8, 16 or 32 encoding
             known_hosts_struct = json.loads(known_hosts_raw_file.read())
-        else:
-            # TODO remove
-            # This is here to provide known-hosts to functions not yet
-            # overhauled to pcs.lib. Cli should never read known hosts from
-            # /var/lib/pcsd/.
-            known_hosts_instance = LibFileInstance.for_known_hosts()
-            known_hosts_struct = known_hosts_instance.read_to_structure()
+            # TODO use known hosts facade for getting info from json struct once the
+            # facade exists
+            return {
+                name: PcsKnownHost.from_known_host_file_dict(name, host)
+                for name, host in known_hosts_struct["known_hosts"].items()
+            }
+        # TODO remove
+        # This is here to provide known-hosts to functions not yet
+        # overhauled to pcs.lib. Cli should never read known hosts from
+        # /var/lib/pcsd/.
+        known_hosts_instance = LibFileInstance.for_known_hosts()
+        known_hosts_facade = cast(
+            KnownHostsFacade, known_hosts_instance.read_to_facade()
+        )
+        return known_hosts_facade.known_hosts
 
-        # TODO use known hosts facade for getting info from json struct once the
-        # facade exists
-        data = {
-            name: PcsKnownHost.from_known_host_file_dict(name, host)
-            for name, host in known_hosts_struct["known_hosts"].items()
-        }
     except LibraryError as e:
         # TODO remove
         # This is here to provide known-hosts to functions not yet
         # overhauled to pcs.lib. Cli should never read known hosts from
         # /var/lib/pcsd/.
-        process_library_reports(e.args)
+        process_library_reports(list(e.args))
     except ParserErrorException as e:
         # TODO remove
         # This is here to provide known-hosts to functions not yet
@@ -363,7 +366,7 @@ def read_known_hosts_file_not_cached():
         reports_output.warn(f"Unable to parse the known-hosts file: {e}")
     except (TypeError, KeyError):
         reports_output.warn("Warning: Unable to parse the known-hosts file.")
-    return data
+    return {}
 
 
 def repeat_if_timeout(send_http_request_function, repeat_count=15):
@@ -523,15 +526,6 @@ def pauseConfigSyncing(node, delay_seconds=300):
     return sendHTTPRequest(node, "remote/set_sync_options", data, False, False)
 
 
-def resumeConfigSyncing(node):
-    """
-    Commandline options:
-      * --request-timeout - timeout for HTTP requests
-    """
-    data = urlencode({"sync_thread_resume": 1})
-    return sendHTTPRequest(node, "remote/set_sync_options", data, False, False)
-
-
 # Send an HTTP request to a node return a tuple with status, data
 # If status is 0 then data contains server response
 # Otherwise if non-zero then data contains error message
@@ -541,7 +535,7 @@ def resumeConfigSyncing(node):
 # 2 = No response,
 # 3 = Auth Error
 # 4 = Permission denied
-def sendHTTPRequest(
+def sendHTTPRequest(  # noqa: PLR0912, PLR0915
     host, request, data=None, printResult=True, printSuccess=True, timeout=None
 ):
     """
@@ -902,7 +896,7 @@ def run(
             stdin=stdin_pipe,
             stdout=subprocess.PIPE,
             stderr=(subprocess.PIPE if ignore_stderr else subprocess.STDOUT),
-            preexec_fn=subprocess_setup,
+            preexec_fn=subprocess_setup,  # noqa: PLW1509
             close_fds=True,
             env=env_var,
             # decodes newlines and in python3 also converts bytes to str
@@ -927,8 +921,7 @@ def run(
     return output, retval
 
 
-@lru_cache()
-def cmd_runner():
+def cmd_runner(cib_file_override=None):
     """
     Commandline options:
       * -f - CIB file
@@ -936,6 +929,8 @@ def cmd_runner():
     env_vars = {}
     if usefile:
         env_vars["CIB_file"] = filename
+    if cib_file_override:
+        env_vars["CIB_file"] = cib_file_override
     env_vars.update(os.environ)
     env_vars["LC_ALL"] = "C"
     return CommandRunner(
@@ -1054,7 +1049,7 @@ def auth_hosts(host_dict):
     err("Unable to communicate with pcsd")
 
 
-def call_local_pcsd(argv, options, std_in=None):
+def call_local_pcsd(argv, options, std_in=None):  # noqa: PLR0911
     """
     Commandline options:
       * --request-timeout - timeout of call to local pcsd
@@ -1376,7 +1371,7 @@ def dom_get_resource_masterslave(dom, resource_id):
 # returns tuple (is_valid, error_message, correct_resource_id_if_exists)
 # there is a duplicate code in pcs/lib/cib/constraint/constraint.py
 # please use function in pcs/lib/cib/constraint/constraint.py
-def validate_constraint_resource(dom, resource_id):
+def validate_constraint_resource(dom, resource_id):  # noqa: PLR0911
     """
     Commandline options:
       * --force - allow constraint on any resource
@@ -1509,6 +1504,10 @@ def get_resource_for_running_check(cluster_state, resource_id, stopped=False):
     """
     Commandline options: no options
     """
+
+    def _isnum(value):
+        return all(char in list("0123456789") for char in value)
+
     # pylint: disable=too-many-nested-blocks
     for clone in cluster_state.getElementsByTagName("clone"):
         if clone.getAttribute("id") == resource_id:
@@ -1518,10 +1517,10 @@ def get_resource_for_running_check(cluster_state, resource_id, stopped=False):
                     "group",
                 ]:
                     resource_id = child.getAttribute("id")
-                    # in a clone a resource can have an id of '<name>:N'
+                    # in a clone, a resource can have an id of '<name>:N'
                     if ":" in resource_id:
                         parts = resource_id.rsplit(":", 1)
-                        if parts[1].isdigit():
+                        if _isnum(parts[1]):
                             resource_id = parts[0]
                     break
     for group in cluster_state.getElementsByTagName("group"):
@@ -1654,54 +1653,21 @@ def get_cib_dom(cib_xml=None):
     Commandline options:
       * -f - CIB file
     """
-    # pylint: disable=bare-except
     if cib_xml is None:
         cib_xml = get_cib()
     try:
-        dom = parseString(cib_xml)
-        return dom
-    except:
+        return parseString(cib_xml)
+    except xml.parsers.expat.ExpatError:
         return err("unable to get cib")
 
 
-def get_cib_etree(cib_xml=None):
-    """
-    Commandline options:
-      * -f - CIB file
-    """
-    # pylint: disable=bare-except
-    if cib_xml is None:
-        cib_xml = get_cib()
-    try:
-        root = ET.fromstring(cib_xml)
-        return root
-    except:
-        return err("unable to get cib")
-
-
-def is_etree(var):
-    """
-    Commandline options: no options
-    """
-    return var.__class__ == xml.etree.ElementTree.Element
-
-
 # Replace only configuration section of cib with dom passed
 def replace_cib_configuration(dom):
     """
     Commandline options:
       * -f - CIB file
     """
-    if is_etree(dom):
-        # etree returns string in bytes: b'xml'
-        # python 3 removed .encode() from byte strings
-        # run(...) calls subprocess.Popen.communicate which calls encode...
-        # so there is bytes to str conversion
-        new_dom = ET.tostring(dom).decode()
-    elif hasattr(dom, "toxml"):
-        new_dom = dom.toxml()
-    else:
-        new_dom = dom
+    new_dom = dom.toxml() if hasattr(dom, "toxml") else dom
     cmd = ["cibadmin", "--replace", "-V", "--xml-pipe", "-o", "configuration"]
     output, retval = run(cmd, False, new_dom)
     if retval != 0:
@@ -1729,39 +1695,30 @@ def is_valid_cib_scope(scope):
 
 # Checks to see if id exists in the xml dom passed
 # DEPRECATED use lxml version available in pcs.lib.cib.tools
-def does_id_exist(dom, check_id):
+def does_id_exist(dom, check_id):  # noqa: PLR0912
     """
     Commandline options: no options
     """
     # do not search in /cib/status, it may contain references to previously
     # existing and deleted resources and thus preventing creating them again
-    if is_etree(dom):
-        for elem in dom.findall(
-            str('(/cib/*[name()!="status"]|/*[name()!="cib"])/*')
-        ):
-            if elem.get("id") == check_id:
-                return True
-    else:
-        document = (
-            dom
-            if isinstance(dom, xml.dom.minidom.Document)
-            else dom.ownerDocument
-        )
-        cib_found = False
-        for cib in _dom_get_children_by_tag_name(document, "cib"):
-            cib_found = True
-            for section in cib.childNodes:
-                if section.nodeType != xml.dom.minidom.Node.ELEMENT_NODE:
-                    continue
-                if section.tagName == "status":
-                    continue
-                for elem in section.getElementsByTagName("*"):
-                    if elem.getAttribute("id") == check_id:
-                        return True
-        if not cib_found:
-            for elem in document.getElementsByTagName("*"):
+    document = (
+        dom if isinstance(dom, xml.dom.minidom.Document) else dom.ownerDocument
+    )
+    cib_found = False
+    for cib in _dom_get_children_by_tag_name(document, "cib"):
+        cib_found = True
+        for section in cib.childNodes:
+            if section.nodeType != xml.dom.minidom.Node.ELEMENT_NODE:
+                continue
+            if section.tagName == "status":
+                continue
+            for elem in section.getElementsByTagName("*"):
                 if elem.getAttribute("id") == check_id:
                     return True
+    if not cib_found:
+        for elem in document.getElementsByTagName("*"):
+            if elem.getAttribute("id") == check_id:
+                return True
     return False
 
 
@@ -1787,17 +1744,17 @@ def operation_exists(operations_el, op_el):
     """
     Commandline options: no options
     """
-    existing = []
     op_name = op_el.getAttribute("name")
     op_interval = timeout_to_seconds_legacy(op_el.getAttribute("interval"))
-    for op in operations_el.getElementsByTagName("op"):
+    return [
+        op
+        for op in operations_el.getElementsByTagName("op")
         if (
             op.getAttribute("name") == op_name
             and timeout_to_seconds_legacy(op.getAttribute("interval"))
             == op_interval
-        ):
-            existing.append(op)
-    return existing
+        )
+    ]
 
 
 def operation_exists_by_name(operations_el, op_el):
@@ -1823,12 +1780,10 @@ def operation_exists_by_name(operations_el, op_el):
 
     for op in operations_el.getElementsByTagName("op"):
         if op.getAttribute("name") == op_name:
-            if op_name != "monitor":
-                existing.append(op)
-            elif get_role(
-                op, new_roles_supported
-            ) == op_role and ocf_check_level == get_operation_ocf_check_level(
-                op
+            if (
+                op_name != "monitor"
+                or get_role(op, new_roles_supported) == op_role
+                and ocf_check_level == get_operation_ocf_check_level(op)
             ):
                 existing.append(op)
     return existing
@@ -1848,34 +1803,6 @@ def get_operation_ocf_check_level(operation_el):
     return None
 
 
-def get_node_attributes(filter_node=None, filter_attr=None):
-    """
-    Commandline options:
-      * -f - CIB file
-    """
-    node_config = get_cib_xpath("//nodes")
-    if node_config == "":
-        err("unable to get crm_config, is pacemaker running?")
-    dom = parseString(node_config).documentElement
-    nas = {}
-    for node in dom.getElementsByTagName("node"):
-        nodename = node.getAttribute("uname")
-        if filter_node is not None and nodename != filter_node:
-            continue
-        for attributes in node.getElementsByTagName("instance_attributes"):
-            for nvp in attributes.getElementsByTagName("nvpair"):
-                attr_name = nvp.getAttribute("name")
-                if filter_attr is not None and attr_name != filter_attr:
-                    continue
-                if nodename not in nas:
-                    nas[nodename] = {}
-                nas[nodename][attr_name] = nvp.getAttribute("value")
-            # Use just first element of attributes. We don't support
-            # attributes with rules just yet.
-            break
-    return nas
-
-
 def set_node_attribute(prop, value, node):
     """
     Commandline options:
@@ -1943,7 +1870,6 @@ def getTerminalSize(fd=1):
 
     Commandline options: no options
     """
-    # pylint: disable=bare-except
     try:
         # pylint: disable=import-outside-toplevel
         import fcntl
@@ -1953,10 +1879,10 @@ def getTerminalSize(fd=1):
         hw = struct.unpack(
             str("hh"), fcntl.ioctl(fd, termios.TIOCGWINSZ, "1234")
         )
-    except:
+    except OSError:
         try:
             hw = (os.environ["LINES"], os.environ["COLUMNS"])
-        except:
+        except KeyError:
             hw = (25, 80)
     return hw
 
@@ -2096,9 +2022,7 @@ def is_score_or_opt(var):
     """
     if is_score(var):
         return True
-    if var.find("=") != -1:
-        return True
-    return False
+    return var.find("=") != -1
 
 
 def is_score(var):
@@ -2119,16 +2043,6 @@ def validate_xml_id(var: str, description: str = "id") -> Tuple[bool, str]:
     return True, ""
 
 
-# deprecated, moved to pcs.lib.pacemaker.live
-def is_iso8601_date(var):
-    """
-    Commandline options: no options
-    """
-    # using pacemaker tool to check if a value is a valid pacemaker iso8601 date
-    dummy_output, retVal = run(["iso8601", "-d", var])
-    return retVal == 0
-
-
 def err(errorText: str, exit_after_error: bool = True) -> None:
     retval = reports_output.error(errorText)
     if exit_after_error:
@@ -2227,7 +2141,7 @@ def write_file(path, data, permissions=0o644, binary=False):
     return True, ""
 
 
-def tar_add_file_data(
+def tar_add_file_data(  # noqa: PLR0913
     tarball,
     data,
     name,
@@ -2338,8 +2252,7 @@ def get_operations_from_transitions(transitions_dom):
                 )
             )
     operation_list.sort(key=lambda x: x[0])
-    op_list = [op[1] for op in operation_list]
-    return op_list
+    return [op[1] for op in operation_list]
 
 
 def get_resources_location_from_operations(cib_dom, resources_operations):
@@ -2374,12 +2287,11 @@ def get_resources_location_from_operations(cib_dom, resources_operations):
             locations[long_id]["start_on_node"] = res_op["on_node"]
         if operation == "promote":
             locations[long_id]["promote_on_node"] = res_op["on_node"]
-    locations_clean = {
+    return {
         key: val
         for key, val in locations.items()
         if "start_on_node" in val or "promote_on_node" in val
     }
-    return locations_clean
 
 
 def get_remote_quorumtool_output(node):
@@ -2402,10 +2314,11 @@ def dom_prepare_child_element(dom_element, tag_name, id_candidate):
     """
     Commandline options: no options
     """
-    child_elements = []
-    for child in dom_element.childNodes:
-        if child.nodeType == child.ELEMENT_NODE and child.tagName == tag_name:
-            child_elements.append(child)
+    child_elements = [
+        child
+        for child in dom_element.childNodes
+        if child.nodeType == child.ELEMENT_NODE and child.tagName == tag_name
+    ]
 
     if not child_elements:
         dom = dom_element.ownerDocument
@@ -2433,7 +2346,7 @@ def dom_update_nvset(dom_element, nvpair_tuples, tag_name, id_candidate):
         return
 
     only_removing = True
-    for name, value in nvpair_tuples:
+    for _, value in nvpair_tuples:
         if value != "":
             only_removing = False
             break
@@ -2670,11 +2583,11 @@ def get_middleware_factory():
     return middleware.create_middleware_factory(
         cib=middleware.cib(filename if usefile else None, touch_cib_file),
         corosync_conf_existing=middleware.corosync_conf_existing(
-            pcs_options.get("--corosync_conf", None)
+            pcs_options.get("--corosync_conf")
         ),
         booth_conf=pcs.cli.booth.env.middleware_config(
-            pcs_options.get("--booth-conf", None),
-            pcs_options.get("--booth-key", None),
+            pcs_options.get("--booth-conf"),
+            pcs_options.get("--booth-key"),
         ),
     )
 
@@ -2748,7 +2661,7 @@ def get_token_from_file(file_name: str) -> str:
 
 def print_warning_if_utilization_attrs_has_no_effect(
     properties_facade: PropertyConfigurationFacade,
-):
+) -> None:
     PLACEMENT_STRATEGIES_USING_UTILIZATION_ATTRS = [
         "balanced",
         "minimal",
