@@ -1,9 +1,9 @@
+import multiprocessing as mp
 import os
 import sys
 import time
 import unittest
 from importlib import import_module
-from multiprocessing import Pool
 from threading import Thread
 from typing import (
     Callable,
@@ -40,7 +40,7 @@ def prepare_test_name(test_name):
 
 
 def tests_from_suite(
-    test_candidate: Union[unittest.TestCase, unittest.TestSuite]
+    test_candidate: Union[unittest.TestCase, unittest.TestSuite],
 ) -> list[str]:
     if isinstance(test_candidate, unittest.TestCase):
         return [test_candidate.id()]
@@ -88,13 +88,11 @@ def discover_tests(
 
 
 def tier1_fixtures_needed(test_list: list[str]) -> set[str]:
-    fixture_modules = set(
-        [
-            "pcs_test.tier1.legacy.test_constraints",
-            "pcs_test.tier1.legacy.test_resource",
-            "pcs_test.tier1.legacy.test_stonith",
-        ]
-    )
+    fixture_modules = {
+        "pcs_test.tier1.legacy.test_constraints",
+        "pcs_test.tier1.legacy.test_resource",
+        "pcs_test.tier1.legacy.test_stonith",
+    }
     fixtures_needed = set()
     for test_name in test_list:
         for module in fixture_modules:
@@ -163,7 +161,7 @@ def parallel_run(tests: list[str], result_class, verbosity: int) -> bool:
 
     manager = ParallelTestManager(result_class, verbosity=verbosity)
 
-    with Pool() as pool:
+    with mp.Pool() as pool:
         start_time = time.perf_counter()
         results = pool.map(
             manager.run_test, tests, 10 if len(tests) > 99 else 1
@@ -194,6 +192,10 @@ def non_parallel_run(tests: list[str], result_class, verbosity: int) -> bool:
 def main() -> None:
     # pylint: disable=import-outside-toplevel
     # pylint: disable=too-many-locals
+
+    # explicitly set start method for multiprocessing to "fork"
+    # https://docs.python.org/3.14/whatsnew/3.14.html#incompatible-changes
+    mp.set_start_method(method="fork")
     if "BUNDLED_LIB_LOCATION" in os.environ:
         sys.path.insert(0, os.environ["BUNDLED_LIB_LOCATION"])
 
