@@ -47,7 +47,7 @@ class AddTest(TestCase):
             "ticket",
             "resource_id",
             "resource_role",
-            {"rsc-role": "master"},
+            {"rsc-role": "promoted"},
         )
         self.assertRaises(
             CmdLineInputError,
