@@ -7,7 +7,6 @@ from pcs.cli.booth import command as booth_cmd
 from pcs.cli.common.errors import CmdLineInputError
 from pcs.common.reports import codes as report_codes
 
-from pcs_test.tools.assertions import AssertPcsMixin
 from pcs_test.tools.misc import dict_to_modifiers
 
 
@@ -108,9 +107,7 @@ class AddTicketTest(TestCase):
         )
 
 
-class DeleteRemoveTicketMixin:
-    command = None
-
+class RemoveTicketTest(TestCase):
     def setUp(self):
         self.lib = mock.Mock(spec_set=["booth"])
         self.lib.booth = mock.Mock(spec_set=["config_ticket_remove"])
@@ -142,15 +139,7 @@ class DeleteRemoveTicketMixin:
         )
 
 
-class DeleteTicketTest(DeleteRemoveTicketMixin, TestCase):
-    command = "delete"
-
-
-class RemoveTicketTest(DeleteRemoveTicketMixin, TestCase):
-    command = "remove"
-
-
-class CreateTest(AssertPcsMixin, TestCase):
+class CreateTest(TestCase):
     def setUp(self):
         self.lib = mock.Mock(spec_set=["booth"])
         self.lib.booth = mock.Mock(spec_set=["create_in_cluster"])
@@ -467,20 +456,24 @@ class Status(TestCase):
 class TicketCleanup(TestCase):
     def setUp(self):
         self.lib = mock.Mock(spec_set=["booth"])
-        self.lib.booth = mock.Mock(spec_set=["ticket_cleanup"])
+        self.lib.booth = mock.Mock(
+            spec_set=["ticket_cleanup", "ticket_cleanup_auto"]
+        )
 
-    def test_no_args(self):
-        with self.assertRaises(CmdLineInputError) as cm:
-            booth_cmd.ticket_unstandby(self.lib, [], dict_to_modifiers({}))
-        self.assertIsNone(cm.exception.message)
+    def test_auto_minimal(self):
+        booth_cmd.ticket_cleanup(self.lib, [], dict_to_modifiers({}))
+        self.lib.booth.ticket_cleanup_auto.assert_called_once_with(
+            instance_name=None
+        )
         self.lib.booth.ticket_cleanup.assert_not_called()
 
-    def test_too_many_args(self):
-        with self.assertRaises(CmdLineInputError) as cm:
-            booth_cmd.ticket_unstandby(
-                self.lib, ["a", "b"], dict_to_modifiers({})
-            )
-        self.assertIsNone(cm.exception.message)
+    def test_auto_full(self):
+        booth_cmd.ticket_cleanup(
+            self.lib, [], dict_to_modifiers(dict(name="my_booth"))
+        )
+        self.lib.booth.ticket_cleanup_auto.assert_called_once_with(
+            instance_name="my_booth"
+        )
         self.lib.booth.ticket_cleanup.assert_not_called()
 
     def test_with_ticket_minimal(self):
@@ -490,6 +483,7 @@ class TicketCleanup(TestCase):
             dict_to_modifiers({}),
         )
         self.lib.booth.ticket_cleanup.assert_called_once_with("ticketA")
+        self.lib.booth.ticket_cleanup_auto.assert_not_called()
 
 
 class TicketUnstandby(TestCase):
