@@ -37,7 +37,6 @@ def create_http_request():
         uri="/pcsd/uri",
         headers=HTTPHeaders({"Cookie": "cookie1=first;cookie2=second"}),
         body=str.encode(urlencode({"post-key": "post-value"})),
-        host="pcsd-host:2224",
     )
 
 
@@ -80,20 +79,6 @@ class RunRuby(AsyncTestCase):
         with self.assertRaises(HTTPError):
             yield self.wrapper.run_ruby(ruby_pcsd.SYNC_CONFIGS)
 
-    @gen_test
-    def test_sync_config_shortcut_success(self):
-        _next = 10
-        self.set_run_result({"next": _next})
-        result = yield self.wrapper.sync_configs()
-        self.assertEqual(result, _next)
-
-    @patch_ruby_pcsd("now", return_value=0)
-    @gen_test
-    def test_sync_config_shorcut_fail(self, now):
-        del now
-        result = yield self.wrapper.sync_configs()
-        self.assertEqual(result, ruby_pcsd.DEFAULT_SYNC_CONFIG_DELAY)
-
     @gen_test
     def test_request(self):
         headers = {"some": "header"}
