@@ -2,6 +2,7 @@ from unittest import TestCase
 
 from lxml import etree
 
+from pcs.common.interface import dto
 from pcs.common.pacemaker.resource.relations import (
     RelationEntityDto,
     ResourceRelationDto,
@@ -11,7 +12,8 @@ from pcs.lib.cib.resource import relations as lib
 
 
 def fixture_cib(resources, constraints):
-    return etree.fromstring(f"""
+    return etree.fromstring(
+        f"""
         <cib>
           <configuration>
             <resources>
@@ -22,7 +24,8 @@ def fixture_cib(resources, constraints):
             </constraints>
           </configuration>
         </cib>
-    """)
+    """
+    )
 
 
 def fixture_dummy_metadata(_id):
@@ -37,24 +40,27 @@ def fixture_dummy_metadata(_id):
 class ResourceRelationNode(TestCase):
     @staticmethod
     def entity_fixture(index):
-        return RelationEntityDto.from_dict(dict(
-            id=f"ent_id{index}",
-            type="ent_type",
-            members=[f"{index}m1", f"{index}m2", f"{index}m0"],
-            metadata=dict(
+        return dto.from_dict(
+            RelationEntityDto,
+            dict(
                 id=f"ent_id{index}",
-                k0="val0",
-                k1="val1",
-            )
-        ))
+                type=str(ResourceRelationType.INNER_RESOURCES.value),
+                members=[f"{index}m1", f"{index}m2", f"{index}m0"],
+                metadata=dict(
+                    id=f"ent_id{index}",
+                    k0="val0",
+                    k1="val1",
+                ),
+            ),
+        )
+
+    def assert_dto_equal(self, expected, actual):
+        self.assertEqual(dto.to_dict(expected), dto.to_dict(actual))
 
     def test_no_members(self):
         ent = self.entity_fixture("0")
         obj = lib.ResourceRelationNode(ent)
-        self.assertEqual(
-            ResourceRelationDto(ent, [], False).to_dict(),
-            obj.to_dto().to_dict(),
-        )
+        self.assert_dto_equal(ResourceRelationDto(ent, [], False), obj.to_dto())
 
     def test_with_members(self):
         ent0 = self.entity_fixture("0")
@@ -66,7 +72,7 @@ class ResourceRelationNode(TestCase):
         member = lib.ResourceRelationNode(ent2)
         member.add_member(lib.ResourceRelationNode(ent3))
         obj.add_member(member)
-        self.assertEqual(
+        self.assert_dto_equal(
             ResourceRelationDto(
                 ent0,
                 [
@@ -80,17 +86,17 @@ class ResourceRelationNode(TestCase):
                     ),
                 ],
                 False,
-            ).to_dict(),
-            obj.to_dto().to_dict(),
+            ),
+            obj.to_dto(),
         )
 
     def test_stop(self):
         ent = self.entity_fixture("0")
         obj = lib.ResourceRelationNode(ent)
         obj.stop()
-        self.assertEqual(
-            ResourceRelationDto(ent, [], True).to_dict(),
-            obj.to_dto().to_dict(),
+        self.assert_dto_equal(
+            ResourceRelationDto(ent, [], True),
+            obj.to_dto(),
         )
 
     def test_add_member(self):
@@ -98,20 +104,22 @@ class ResourceRelationNode(TestCase):
         ent1 = self.entity_fixture("1")
         obj = lib.ResourceRelationNode(ent0)
         obj.add_member(lib.ResourceRelationNode(ent1))
-        self.assertEqual(
+        self.assert_dto_equal(
             ResourceRelationDto(
-                ent0, [ResourceRelationDto(ent1, [], False)], False,
-            ).to_dict(),
-            obj.to_dto().to_dict(),
+                ent0,
+                [ResourceRelationDto(ent1, [], False)],
+                False,
+            ),
+            obj.to_dto(),
         )
 
     def test_add_member_itself(self):
         ent = self.entity_fixture("0")
         obj = lib.ResourceRelationNode(ent)
         obj.add_member(obj)
-        self.assertEqual(
-            ResourceRelationDto(ent, [], False).to_dict(),
-            obj.to_dto().to_dict(),
+        self.assert_dto_equal(
+            ResourceRelationDto(ent, [], False),
+            obj.to_dto(),
         )
 
     def test_add_member_already_have_parent(self):
@@ -129,11 +137,11 @@ class ResourceRelationNode(TestCase):
         obj1 = lib.ResourceRelationNode(ent1)
         obj0.add_member(obj1)
         obj1.add_member(obj0)
-        self.assertEqual(
+        self.assert_dto_equal(
             ResourceRelationDto(
                 ent0, [ResourceRelationDto(ent1, [], False)], False
-            ).to_dict(),
-            obj0.to_dto().to_dict(),
+            ),
+            obj0.to_dto(),
         )
 
     def test_add_member_already_in_different_branch(self):
@@ -142,42 +150,45 @@ class ResourceRelationNode(TestCase):
         obj0 = lib.ResourceRelationNode(ent0)
         obj0.add_member(lib.ResourceRelationNode(ent1))
         obj0.add_member(lib.ResourceRelationNode(ent1))
-        self.assertEqual(
+        self.assert_dto_equal(
             ResourceRelationDto(
-                ent0, [
+                ent0,
+                [
                     ResourceRelationDto(ent1, [], False),
                     ResourceRelationDto(ent1, [], False),
                 ],
                 False,
-            ).to_dict(),
-            obj0.to_dto().to_dict(),
+            ),
+            obj0.to_dto(),
         )
 
 
 class ResourceRelationsFetcher(TestCase):
     def test_ordering_constraint(self):
-        obj = lib.ResourceRelationsFetcher(fixture_cib(
-            """
+        obj = lib.ResourceRelationsFetcher(
+            fixture_cib(
+                """
             <primitive id="d1" class="c" provider="pcmk" type="Dummy"/>
             <primitive id="d2" class="c" provider="pcmk" type="Dummy"/>
             """,
-            """
+                """
             <rsc_order first="d1" first-action="start"
                 id="order-d1-d2-mandatory" then="d2" then-action="start"
                 kind="Mandatory"/>
-            """
-        ))
+            """,
+            )
+        )
         expected = (
             {
                 "d1": RelationEntityDto(
                     "d1",
-                    "primitive",
+                    ResourceRelationType.RSC_PRIMITIVE,
                     ["order-d1-d2-mandatory"],
                     fixture_dummy_metadata("d1"),
                 ),
                 "d2": RelationEntityDto(
                     "d2",
-                    "primitive",
+                    ResourceRelationType.RSC_PRIMITIVE,
                     ["order-d1-d2-mandatory"],
                     fixture_dummy_metadata("d2"),
                 ),
@@ -203,8 +214,9 @@ class ResourceRelationsFetcher(TestCase):
                 self.assertEqual(expected, obj.get_relations(res))
 
     def test_ordering_set_constraint(self):
-        obj = lib.ResourceRelationsFetcher(fixture_cib(
-            """
+        obj = lib.ResourceRelationsFetcher(
+            fixture_cib(
+                """
             <primitive id="d1" class="c" provider="pcmk" type="Dummy"/>
             <primitive id="d2" class="c" provider="pcmk" type="Dummy"/>
             <primitive id="d3" class="c" provider="pcmk" type="Dummy"/>
@@ -212,7 +224,7 @@ class ResourceRelationsFetcher(TestCase):
             <primitive id="d5" class="c" provider="pcmk" type="Dummy"/>
             <primitive id="d6" class="c" provider="pcmk" type="Dummy"/>
             """,
-            """
+                """
             <rsc_order kind="Serialize" symmetrical="true"
                 id="pcs_rsc_order_set_1">
               <resource_set sequential="true" require-all="true" action="start"
@@ -228,14 +240,18 @@ class ResourceRelationsFetcher(TestCase):
                 <resource_ref id="d4"/>
               </resource_set>
             </rsc_order>
-            """
-        ))
-        rsc_entity = lambda _id: RelationEntityDto(
-            _id,
-            "primitive",
-            ["pcs_rsc_order_set_1"],
-            fixture_dummy_metadata(_id),
+            """,
+            )
         )
+
+        def rsc_entity(_id):
+            return RelationEntityDto(
+                _id,
+                ResourceRelationType.RSC_PRIMITIVE,
+                ["pcs_rsc_order_set_1"],
+                fixture_dummy_metadata(_id),
+            )
+
         res_list = ("d1", "d2", "d3", "d4", "d5", "d6")
         expected = (
             {_id: rsc_entity(_id) for _id in res_list},
@@ -279,31 +295,36 @@ class ResourceRelationsFetcher(TestCase):
                 self.assertEqual(expected, obj.get_relations(res))
 
     def test_group(self):
-        obj = lib.ResourceRelationsFetcher(fixture_cib(
-            """
+        obj = lib.ResourceRelationsFetcher(
+            fixture_cib(
+                """
             <group id="g1">
               <primitive id="d1" class="c" provider="pcmk" type="Dummy"/>
               <primitive id="d2" class="c" provider="pcmk" type="Dummy"/>
             </group>
             """,
-            ""
-        ))
+                "",
+            )
+        )
         expected = (
             {
                 "d1": RelationEntityDto(
                     "d1",
-                    "primitive",
+                    ResourceRelationType.RSC_PRIMITIVE,
                     ["outer:g1"],
                     fixture_dummy_metadata("d1"),
                 ),
                 "d2": RelationEntityDto(
                     "d2",
-                    "primitive",
+                    ResourceRelationType.RSC_PRIMITIVE,
                     ["outer:g1"],
                     fixture_dummy_metadata("d2"),
                 ),
                 "g1": RelationEntityDto(
-                    "g1", "group", ["inner:g1"], {"id": "g1"}
+                    "g1",
+                    ResourceRelationType.RSC_GROUP,
+                    ["inner:g1"],
+                    {"id": "g1"},
                 ),
             },
             {
@@ -325,25 +346,27 @@ class ResourceRelationsFetcher(TestCase):
             with self.subTest(resource=res):
                 self.assertEqual(expected, obj.get_relations(res))
 
-    def _test_wrapper(self, wrapper_tag):
-        obj = lib.ResourceRelationsFetcher(fixture_cib(
-            f"""
+    def _test_wrapper(self, wrapper_tag, rel_type):
+        obj = lib.ResourceRelationsFetcher(
+            fixture_cib(
+                f"""
             <{wrapper_tag} id="w1">
               <primitive id="d1" class="c" provider="pcmk" type="Dummy"/>
             </{wrapper_tag}>
             """,
-            ""
-        ))
+                "",
+            )
+        )
         expected = (
             {
                 "d1": RelationEntityDto(
                     "d1",
-                    "primitive",
+                    ResourceRelationType.RSC_PRIMITIVE,
                     ["outer:w1"],
                     fixture_dummy_metadata("d1"),
                 ),
                 "w1": RelationEntityDto(
-                    "w1", wrapper_tag, ["inner:w1"], {"id": "w1"}
+                    "w1", rel_type, ["inner:w1"], {"id": "w1"}
                 ),
             },
             {
@@ -366,14 +389,18 @@ class ResourceRelationsFetcher(TestCase):
                 self.assertEqual(expected, obj.get_relations(res))
 
     def test_clone(self):
-        self._test_wrapper("clone")
+        self._test_wrapper("clone", ResourceRelationType.RSC_CLONE)
+
+    def test_master(self):
+        self._test_wrapper("master", ResourceRelationType.RSC_CLONE)
 
     def test_bundle(self):
-        self._test_wrapper("bundle")
+        self._test_wrapper("bundle", ResourceRelationType.RSC_BUNDLE)
 
     def test_cloned_group(self):
-        obj = lib.ResourceRelationsFetcher(fixture_cib(
-            """
+        obj = lib.ResourceRelationsFetcher(
+            fixture_cib(
+                """
             <clone id="c1">
                 <group id="g1">
                   <primitive id="d1" class="c" provider="pcmk" type="Dummy"/>
@@ -381,28 +408,35 @@ class ResourceRelationsFetcher(TestCase):
                 </group>
             </clone>
             """,
-            ""
-        ))
+                "",
+            )
+        )
         expected = (
             {
                 "d1": RelationEntityDto(
                     "d1",
-                    "primitive",
+                    ResourceRelationType.RSC_PRIMITIVE,
                     ["outer:g1"],
                     fixture_dummy_metadata("d1"),
                 ),
                 "d2": RelationEntityDto(
                     "d2",
-                    "primitive",
+                    ResourceRelationType.RSC_PRIMITIVE,
                     ["outer:g1"],
                     fixture_dummy_metadata("d2"),
                 ),
                 "g1": RelationEntityDto(
-                    "g1", "group", ["inner:g1", "outer:c1"], {"id": "g1"}
+                    "g1",
+                    ResourceRelationType.RSC_GROUP,
+                    ["inner:g1", "outer:c1"],
+                    {"id": "g1"},
                 ),
                 "c1": RelationEntityDto(
-                    "c1", "clone", ["inner:c1"], {"id": "c1"}
-                )
+                    "c1",
+                    ResourceRelationType.RSC_CLONE,
+                    ["inner:c1"],
+                    {"id": "c1"},
+                ),
             },
             {
                 "inner:g1": RelationEntityDto(
@@ -421,13 +455,13 @@ class ResourceRelationsFetcher(TestCase):
                     "inner:c1",
                     ResourceRelationType.INNER_RESOURCES,
                     ["g1"],
-                    {"id": "c1"}
+                    {"id": "c1"},
                 ),
                 "outer:c1": RelationEntityDto(
                     "outer:c1",
                     ResourceRelationType.OUTER_RESOURCE,
                     ["c1"],
-                    {"id": "c1"}
+                    {"id": "c1"},
                 ),
             },
         )
@@ -440,7 +474,10 @@ class ResourceRelationTreeBuilder(TestCase):
     @staticmethod
     def primitive_fixture(_id, members):
         return RelationEntityDto(
-            _id, "primitive", members, fixture_dummy_metadata(_id)
+            _id,
+            ResourceRelationType.RSC_PRIMITIVE,
+            members,
+            fixture_dummy_metadata(_id),
         )
 
     def test_resource_not_present(self):
@@ -469,29 +506,31 @@ class ResourceRelationTreeBuilder(TestCase):
             ),
         }
         expected = dict(
-            relation_entity=resources["d2"].to_dict(),
+            relation_entity=dto.to_dict(resources["d2"]),
             is_leaf=False,
             members=[
                 dict(
-                    relation_entity=(
-                        relations["order-d1-d2-mandatory"].to_dict()
+                    relation_entity=dto.to_dict(
+                        relations["order-d1-d2-mandatory"]
                     ),
                     is_leaf=False,
                     members=[
                         dict(
-                            relation_entity=resources["d1"].to_dict(),
+                            relation_entity=dto.to_dict(resources["d1"]),
                             is_leaf=False,
                             members=[],
                         )
-                    ]
+                    ],
                 )
             ],
         )
         self.assertEqual(
             expected,
-            lib.ResourceRelationTreeBuilder(
-                resources, relations
-            ).get_tree("d2").to_dto().to_dict()
+            dto.to_dict(
+                lib.ResourceRelationTreeBuilder(resources, relations)
+                .get_tree("d2")
+                .to_dto()
+            ),
         )
 
     def test_simple_order_set(self):
@@ -535,29 +574,36 @@ class ResourceRelationTreeBuilder(TestCase):
                 },
             ),
         }
-        get_res = lambda _id: dict(
-            relation_entity=resources[_id].to_dict(),
-            is_leaf=False,
-            members=[],
-        )
+
+        def get_res(_id):
+            return dict(
+                relation_entity=dto.to_dict(resources[_id]),
+                is_leaf=False,
+                members=[],
+            )
+
         expected = dict(
-            relation_entity=resources["d5"].to_dict(),
+            relation_entity=dto.to_dict(resources["d5"]),
             is_leaf=False,
             members=[
                 dict(
-                    relation_entity=relations["pcs_rsc_order_set_1"].to_dict(),
+                    relation_entity=dto.to_dict(
+                        relations["pcs_rsc_order_set_1"]
+                    ),
                     is_leaf=False,
                     members=[
                         get_res(_id) for _id in ("d1", "d2", "d3", "d4", "d6")
-                    ]
+                    ],
                 )
             ],
         )
         self.assertEqual(
             expected,
-            lib.ResourceRelationTreeBuilder(
-                resources, relations
-            ).get_tree("d5").to_dto().to_dict()
+            dto.to_dict(
+                lib.ResourceRelationTreeBuilder(resources, relations)
+                .get_tree("d5")
+                .to_dto()
+            ),
         )
 
     def test_simple_in_group(self):
@@ -565,9 +611,7 @@ class ResourceRelationTreeBuilder(TestCase):
         resources = {
             "d1": self.primitive_fixture("d1", resources_members),
             "d2": self.primitive_fixture("d2", resources_members),
-            "g1": RelationEntityDto(
-                "g1", "group", ["inner:g1"], {"id": "g1"}
-            ),
+            "g1": RelationEntityDto("g1", "group", ["inner:g1"], {"id": "g1"}),
         }
         relations = {
             "inner:g1": RelationEntityDto(
@@ -584,26 +628,26 @@ class ResourceRelationTreeBuilder(TestCase):
             ),
         }
         expected = dict(
-            relation_entity=resources["d1"].to_dict(),
+            relation_entity=dto.to_dict(resources["d1"]),
             is_leaf=False,
             members=[
                 dict(
-                    relation_entity=relations["outer:g1"].to_dict(),
+                    relation_entity=dto.to_dict(relations["outer:g1"]),
                     is_leaf=False,
                     members=[
                         dict(
-                            relation_entity=resources["g1"].to_dict(),
+                            relation_entity=dto.to_dict(resources["g1"]),
                             is_leaf=False,
                             members=[
                                 dict(
-                                    relation_entity=(
-                                        relations["inner:g1"].to_dict()
+                                    relation_entity=dto.to_dict(
+                                        relations["inner:g1"]
                                     ),
                                     is_leaf=False,
                                     members=[
                                         dict(
-                                            relation_entity=(
-                                                resources["d2"].to_dict()
+                                            relation_entity=dto.to_dict(
+                                                resources["d2"]
                                             ),
                                             is_leaf=False,
                                             members=[],
@@ -618,52 +662,57 @@ class ResourceRelationTreeBuilder(TestCase):
         )
         self.assertEqual(
             expected,
-            lib.ResourceRelationTreeBuilder(
-                resources, relations
-            ).get_tree("d1").to_dto().to_dict()
+            dto.to_dict(
+                lib.ResourceRelationTreeBuilder(resources, relations)
+                .get_tree("d1")
+                .to_dto()
+            ),
         )
 
     def test_order_loop(self):
+        def order_fixture(res1, res2):
+            return RelationEntityDto(
+                f"order-{res1}-{res2}-mandatory",
+                ResourceRelationType.ORDER,
+                members=[res1, res2],
+                metadata={
+                    "id": f"order-{res1}-{res2}-mandatory",
+                    "first": res1,
+                    "first-action": "start",
+                    "then": res2,
+                    "then-action": "start",
+                    "kind": "Mandatory",
+                },
+            )
+
         resources_members = ["order-d1-d2-mandatory", "order-d2-d1-mandatory"]
         resources = {
             "d1": self.primitive_fixture("d1", resources_members),
             "d2": self.primitive_fixture("d2", resources_members),
         }
-        order_fixture = lambda r1, r2: RelationEntityDto(
-            f"order-{r1}-{r2}-mandatory",
-            ResourceRelationType.ORDER,
-            members=[r1, r2],
-            metadata={
-                "id": f"order-{r1}-{r2}-mandatory",
-                "first": r1,
-                "first-action": "start",
-                "then": r2,
-                "then-action": "start",
-                "kind": "Mandatory",
-            },
-        )
+
         relations = {
             "order-d1-d2-mandatory": order_fixture("d1", "d2"),
             "order-d2-d1-mandatory": order_fixture("d2", "d1"),
         }
         expected = dict(
-            relation_entity=resources["d1"].to_dict(),
+            relation_entity=dto.to_dict(resources["d1"]),
             is_leaf=False,
             members=[
                 dict(
-                    relation_entity=(
-                        relations["order-d1-d2-mandatory"].to_dict()
+                    relation_entity=dto.to_dict(
+                        relations["order-d1-d2-mandatory"]
                     ),
                     is_leaf=False,
                     members=[
                         dict(
-                            relation_entity=resources["d2"].to_dict(),
+                            relation_entity=dto.to_dict(resources["d2"]),
                             is_leaf=False,
                             members=[
                                 dict(
-                                    relation_entity=relations[
-                                        "order-d2-d1-mandatory"
-                                    ].to_dict(),
+                                    relation_entity=dto.to_dict(
+                                        relations["order-d2-d1-mandatory"]
+                                    ),
                                     is_leaf=True,
                                     members=[],
                                 ),
@@ -672,13 +721,13 @@ class ResourceRelationTreeBuilder(TestCase):
                     ],
                 ),
                 dict(
-                    relation_entity=(
-                        relations["order-d2-d1-mandatory"].to_dict()
+                    relation_entity=dto.to_dict(
+                        relations["order-d2-d1-mandatory"]
                     ),
                     is_leaf=False,
                     members=[
                         dict(
-                            relation_entity=resources["d2"].to_dict(),
+                            relation_entity=dto.to_dict(resources["d2"]),
                             is_leaf=True,
                             members=[],
                         ),
@@ -688,7 +737,9 @@ class ResourceRelationTreeBuilder(TestCase):
         )
         self.assertEqual(
             expected,
-            lib.ResourceRelationTreeBuilder(
-                resources, relations
-            ).get_tree("d1").to_dto().to_dict()
+            dto.to_dict(
+                lib.ResourceRelationTreeBuilder(resources, relations)
+                .get_tree("d1")
+                .to_dto()
+            ),
         )
