@@ -8,12 +8,16 @@ from lxml import etree
 from pcs.common.reports import ReportItemSeverity as severities
 from pcs.common.reports import codes as report_codes
 from pcs.lib.cib import acl as lib
-from pcs.lib.cib.tools import get_acls
+from pcs.lib.cib.tools import (
+    IdProvider,
+    get_acls,
+)
 from pcs.lib.errors import LibraryError
 
 from pcs_test.tools.assertions import (
     ExtendedAssertionsMixin,
     assert_raise_library_error,
+    assert_report_item_list_equal,
     assert_xml_equal,
 )
 from pcs_test.tools.misc import get_test_resource as rc
@@ -74,32 +78,34 @@ class ValidatePermissionsTest(LibraryAclTest):
             ("write", "xpath", "my xpath"),
             ("allow", "xpath", "xpath"),
         ]
-        assert_raise_library_error(
-            lambda: lib.validate_permissions(self.tree, permissions),
-            (
-                severities.ERROR,
-                report_codes.INVALID_OPTION_VALUE,
-                {
-                    "option_value": "unknown",
-                    "option_name": "permission",
-                    "allowed_values": self.allowed_permissions,
-                    "cannot_be_empty": False,
-                    "forbidden_characters": None,
-                },
-                None,
-            ),
-            (
-                severities.ERROR,
-                report_codes.INVALID_OPTION_VALUE,
-                {
-                    "option_value": "allow",
-                    "option_name": "permission",
-                    "allowed_values": self.allowed_permissions,
-                    "cannot_be_empty": False,
-                    "forbidden_characters": None,
-                },
-                None,
-            ),
+        assert_report_item_list_equal(
+            lib.validate_permissions(self.tree, permissions),
+            [
+                (
+                    severities.ERROR,
+                    report_codes.INVALID_OPTION_VALUE,
+                    {
+                        "option_value": "unknown",
+                        "option_name": "permission",
+                        "allowed_values": self.allowed_permissions,
+                        "cannot_be_empty": False,
+                        "forbidden_characters": None,
+                    },
+                    None,
+                ),
+                (
+                    severities.ERROR,
+                    report_codes.INVALID_OPTION_VALUE,
+                    {
+                        "option_value": "allow",
+                        "option_name": "permission",
+                        "allowed_values": self.allowed_permissions,
+                        "cannot_be_empty": False,
+                        "forbidden_characters": None,
+                    },
+                    None,
+                ),
+            ],
         )
 
     def test_unknown_scope(self):
@@ -109,32 +115,34 @@ class ValidatePermissionsTest(LibraryAclTest):
             ("deny", "not_xpath", "some xpath"),
             ("read", "xpath", "xpath"),
         ]
-        assert_raise_library_error(
-            lambda: lib.validate_permissions(self.tree, permissions),
-            (
-                severities.ERROR,
-                report_codes.INVALID_OPTION_VALUE,
-                {
-                    "option_value": "not_id",
-                    "option_name": "scope type",
-                    "allowed_values": self.allowed_scopes,
-                    "cannot_be_empty": False,
-                    "forbidden_characters": None,
-                },
-                None,
-            ),
-            (
-                severities.ERROR,
-                report_codes.INVALID_OPTION_VALUE,
-                {
-                    "option_value": "not_xpath",
-                    "option_name": "scope type",
-                    "allowed_values": self.allowed_scopes,
-                    "cannot_be_empty": False,
-                    "forbidden_characters": None,
-                },
-                None,
-            ),
+        assert_report_item_list_equal(
+            lib.validate_permissions(self.tree, permissions),
+            [
+                (
+                    severities.ERROR,
+                    report_codes.INVALID_OPTION_VALUE,
+                    {
+                        "option_value": "not_id",
+                        "option_name": "scope type",
+                        "allowed_values": self.allowed_scopes,
+                        "cannot_be_empty": False,
+                        "forbidden_characters": None,
+                    },
+                    None,
+                ),
+                (
+                    severities.ERROR,
+                    report_codes.INVALID_OPTION_VALUE,
+                    {
+                        "option_value": "not_xpath",
+                        "option_name": "scope type",
+                        "allowed_values": self.allowed_scopes,
+                        "cannot_be_empty": False,
+                        "forbidden_characters": None,
+                    },
+                    None,
+                ),
+            ],
         )
 
     def test_not_existing_id(self):
@@ -144,30 +152,67 @@ class ValidatePermissionsTest(LibraryAclTest):
             ("deny", "id", "last"),
             ("write", "xpath", "maybe xpath"),
         ]
-        assert_raise_library_error(
-            lambda: lib.validate_permissions(self.tree, permissions),
-            (
-                severities.ERROR,
-                report_codes.ID_NOT_FOUND,
-                {
-                    "id": "id",
-                    "expected_types": ["id"],
-                    "context_type": "",
-                    "context_id": "",
-                },
-                None,
-            ),
-            (
-                severities.ERROR,
-                report_codes.ID_NOT_FOUND,
-                {
-                    "id": "last",
-                    "expected_types": ["id"],
-                    "context_type": "",
-                    "context_id": "",
-                },
-                None,
-            ),
+        assert_report_item_list_equal(
+            lib.validate_permissions(self.tree, permissions),
+            [
+                (
+                    severities.ERROR,
+                    report_codes.ID_NOT_FOUND,
+                    {
+                        "id": "id",
+                        "expected_types": ["id"],
+                        "context_type": "",
+                        "context_id": "",
+                    },
+                    None,
+                ),
+                (
+                    severities.ERROR,
+                    report_codes.ID_NOT_FOUND,
+                    {
+                        "id": "last",
+                        "expected_types": ["id"],
+                        "context_type": "",
+                        "context_id": "",
+                    },
+                    None,
+                ),
+            ],
+        )
+
+
+class ValidateCreateRole(LibraryAclTest):
+    def test_refuse_invalid_id(self):
+        assert_report_item_list_equal(
+            lib.validate_create_role(IdProvider(self.cib.tree), "#invalid"),
+            [
+                (
+                    severities.ERROR,
+                    report_codes.INVALID_ID_BAD_CHAR,
+                    {
+                        "id": "#invalid",
+                        "id_description": "ACL role",
+                        "invalid_character": "#",
+                        "is_first_char": True,
+                    },
+                ),
+            ],
+        )
+
+    def test_refuse_existing_non_role_id(self):
+        self.cib.append_to_first_tag_name(
+            "nodes", '<node id="node-id" uname="node-hostname"/>'
+        )
+
+        assert_report_item_list_equal(
+            lib.validate_create_role(IdProvider(self.cib.tree), "node-id"),
+            [
+                (
+                    severities.ERROR,
+                    report_codes.ID_ALREADY_EXISTS,
+                    {"id": "node-id"},
+                ),
+            ],
         )
 
 
@@ -183,35 +228,6 @@ class CreateRoleTest(LibraryAclTest):
             )
         )
 
-    def test_refuse_invalid_id(self):
-        assert_raise_library_error(
-            lambda: lib.create_role(self.cib.tree, "#invalid"),
-            (
-                severities.ERROR,
-                report_codes.INVALID_ID_BAD_CHAR,
-                {
-                    "id": "#invalid",
-                    "id_description": "ACL role",
-                    "invalid_character": "#",
-                    "is_first_char": True,
-                },
-            ),
-        )
-
-    def test_refuse_existing_non_role_id(self):
-        self.cib.append_to_first_tag_name(
-            "nodes", '<node id="node-id" uname="node-hostname"/>'
-        )
-
-        assert_raise_library_error(
-            lambda: lib.create_role(self.cib.tree, "node-id"),
-            (
-                severities.ERROR,
-                report_codes.ID_ALREADY_EXISTS,
-                {"id": "node-id"},
-            ),
-        )
-
 
 class RemoveRoleTest(LibraryAclTest, ExtendedAssertionsMixin):
     def setUp(self):
@@ -508,6 +524,7 @@ class AddPermissionsToRoleTest(LibraryAclTest):
         lib.add_permissions_to_role(
             self.cib.tree.find(".//acl_role[@id='{0}']".format(role_id)),
             [("read", "xpath", "/whatever")],
+            IdProvider(self.cib.tree),
         )
 
         self.assert_cib_equal(
@@ -519,47 +536,7 @@ class AddPermissionsToRoleTest(LibraryAclTest):
                   <acl_permission id="{0}-read" kind="read" xpath="/whatever"/>
                 </acl_role>
               </acls>
-            """.format(
-                    role_id
-                ),
-            )
-        )
-
-
-class ProvideRoleTest(LibraryAclTest):
-    def test_add_role_for_nonexisting_id(self):
-        role_id = "new-id"
-        lib.provide_role(self.acls, role_id)
-
-        self.assert_cib_equal(
-            self.create_cib().append_to_first_tag_name(
-                "configuration",
-                """
-              <acls>
-                <acl_role id="{0}"/>
-              </acls>
-            """.format(
-                    role_id
-                ),
-            )
-        )
-
-    def test_add_role_for_nonexisting_role_id(self):
-        self.fixture_add_role("role1")
-
-        role_id = "role1"
-        lib.provide_role(self.cib.tree, role_id)
-
-        self.assert_cib_equal(
-            self.create_cib().append_to_first_tag_name(
-                "configuration",
-                """
-              <acls>
-                <acl_role id="{0}"/>
-              </acls>
-            """.format(
-                    role_id
-                ),
+            """.format(role_id),
             )
         )
 
