@@ -1,21 +1,22 @@
 import json
-
-from unittest import mock, TestCase
-
-from pcs_test.tools import fixture
-from pcs_test.tools.command_env import get_env_tools
+from unittest import (
+    TestCase,
+    mock,
+)
 
 from pcs.common import reports
 from pcs.lib.commands import cluster
 from pcs.settings import corosync_authkey_bytes
 
+from pcs_test.tools import fixture
+from pcs_test.tools.command_env import get_env_tools
+
 from .common import (
-    get_two_node,
     corosync_conf_fixture,
+    get_two_node,
     node_fixture,
 )
 
-
 TEST_AUTHKEY_DEFAULT_SIZE = corosync_authkey_bytes * b"a"
 TEST_AUTHKEY_LONGER_THAN_DEFAULT = corosync_authkey_bytes * 2 * b"a"
 TEST_AUTHKEY_SHORTER_THAN_DEFAULT = corosync_authkey_bytes // 2 * b"a"
@@ -659,7 +660,7 @@ class MissingNodeNamesInCorosync(TestCase):
         for index, node in enumerate(node_list):
             node_option_list = []
             node_option_list.append(("ring0_addr", node))
-            if not index in skip_name_idx_list:
+            if index not in skip_name_idx_list:
                 node_option_list.append(("name", node))
             node_option_list.append(("nodeid", str(index + 1)))
             result.append(node_option_list)
@@ -692,7 +693,7 @@ class MissingNodeNamesInCorosync(TestCase):
     def test_missing_name_of_all_nodes(self):
         self.assert_command(
             self._get_corosync_nodes_options(
-                self.existing_nodes, range(0, len(self.existing_nodes))
+                self.existing_nodes, range(len(self.existing_nodes))
             )
         )
 
@@ -712,7 +713,7 @@ class HostNotFound(TestCase):
             )
         )
 
-    def test_some_nodes_uknown(self):
+    def test_some_nodes_unknown(self):
         self.config.env.set_known_nodes(self.existing_nodes[1:])
         self.env_assist.assert_raise_library_error(
             lambda: cluster.corosync_authkey_change(self.env_assist.get_env())
@@ -726,7 +727,7 @@ class HostNotFound(TestCase):
             ]
         )
 
-    def test_all_nodes_uknown(self):
+    def test_all_nodes_unknown(self):
         self.config.env.set_known_nodes([])
         self.env_assist.assert_raise_library_error(
             lambda: cluster.corosync_authkey_change(self.env_assist.get_env())
