@@ -1,12 +1,13 @@
+import os.path
 from unittest import TestCase
 
-from pcs_test.tools import fixture
-from pcs_test.tools.command_env import get_env_tools
-
 from pcs import settings
 from pcs.common.reports import codes as report_codes
 from pcs.lib.commands import cluster
 
+from pcs_test.tools import fixture
+from pcs_test.tools.command_env import get_env_tools
+
 
 class SuccessMinimal(TestCase):
     def setUp(self):
@@ -29,8 +30,8 @@ class SuccessMinimal(TestCase):
             expected_in_processor=False,
         )
 
-    def test_sucess_pcmk_running(self):
-        self.config.runner.systemctl.is_active("pacemaker")
+    def test_success_pcmk_running(self):
+        self.config.services.is_running("pacemaker")
         for node in self.nodes:
             self.config.runner.pcmk.remove_node(
                 node,
@@ -40,7 +41,7 @@ class SuccessMinimal(TestCase):
 
     def test_failure_pcmk_running(self):
         err_msg = "an error"
-        self.config.runner.systemctl.is_active("pacemaker")
+        self.config.services.is_running("pacemaker")
         self.config.runner.pcmk.remove_node(
             self.nodes[0],
         )
@@ -66,36 +67,39 @@ class SuccessMinimal(TestCase):
             expected_in_processor=False,
         )
 
-    def test_sucess_pcmk_not_running(self):
-        self.config.runner.systemctl.is_active("pacemaker", is_active=False)
-        # TODO: we do not test environment variables in runner
+    def test_success_pcmk_not_running(self):
+        cmd_env = dict(CIB_file=os.path.join(settings.cib_dir, "cib.xml"))
+        self.config.services.is_running("pacemaker", return_value=False)
         for node in self.nodes:
             self.config.runner.place(
                 [
-                    settings.cibadmin,
+                    settings.cibadmin_exec,
                     "--delete-all",
                     "--force",
                     f"--xpath=/cib/configuration/nodes/node[@uname='{node}']",
                 ],
                 name=f"remove_node.{node}",
+                env=cmd_env,
             )
         cluster.remove_nodes_from_cib(self.env_assist.get_env(), self.nodes)
 
     def test_failure_pcmk_not_running(self):
         err_msg = "an error"
-        cmd = [settings.cibadmin, "--delete-all", "--force"]
+        cmd_env = dict(CIB_file=os.path.join(settings.cib_dir, "cib.xml"))
+        cmd = [settings.cibadmin_exec, "--delete-all", "--force"]
         cmd_xpath = "--xpath=/cib/configuration/nodes/node[@uname='{}']"
-        self.config.runner.systemctl.is_active("pacemaker", is_active=False)
-        # TODO: we do not test environment variables in runner
+        self.config.services.is_running("pacemaker", return_value=False)
         self.config.runner.place(
             cmd + [cmd_xpath.format(self.nodes[0])],
             name="remove_node_success",
+            env=cmd_env,
         )
         self.config.runner.place(
             cmd + [cmd_xpath.format(self.nodes[1])],
             returncode=1,
             stderr=err_msg,
             name="remove_node_failure",
+            env=cmd_env,
         )
         self.env_assist.assert_raise_library_error(
             lambda: cluster.remove_nodes_from_cib(
