@@ -36,9 +36,7 @@ def fixture_resources_minimal(container_type="docker"):
                 <{container_type} image="pcs:test" />
             </bundle>
         </resources>
-    """.format(
-        container_type=container_type
-    )
+    """.format(container_type=container_type)
 
 
 class Basics(TestCase):
@@ -125,9 +123,7 @@ class ContainerParametrized(TestCase):
                     <{container_type} image="pcs:test" extra="option" />
                 </bundle>
             </resources>
-        """.format(
-            container_type=self.container_type
-        )
+        """.format(container_type=self.container_type)
 
     @property
     def fixture_cib_masters(self):
@@ -137,9 +133,7 @@ class ContainerParametrized(TestCase):
                     <{container_type} image="pcs:test" masters="2" />
                 </bundle>
             </resources>
-        """.format(
-            container_type=self.container_type
-        )
+        """.format(container_type=self.container_type)
 
     @property
     def fixture_cib_promoted_max(self):
@@ -149,9 +143,7 @@ class ContainerParametrized(TestCase):
                     <{container_type} image="pcs:test" promoted-max="3" />
                 </bundle>
             </resources>
-        """.format(
-            container_type=self.container_type
-        )
+        """.format(container_type=self.container_type)
 
     def setUp(self):
         self.env_assist, self.config = get_env_tools(test_case=self)
@@ -167,9 +159,7 @@ class ContainerParametrized(TestCase):
                             />
                         </bundle>
                     </resources>
-                """.format(
-                    container_type=self.container_type
-                )
+                """.format(container_type=self.container_type)
             ).env.push_cib(
                 resources="""
                     <resources>
@@ -178,9 +168,7 @@ class ContainerParametrized(TestCase):
                             />
                         </bundle>
                     </resources>
-                """.format(
-                    container_type=self.container_type
-                )
+                """.format(container_type=self.container_type)
             )
         )
         resource.bundle_update(
