@@ -182,7 +182,7 @@ class GroupAdd(TestCase):
     def test_remove_empty_group(self):
         resources_before = """
             <resources>
-                
+
                 <group id="X">
                     <primitive id="RX1" />
                 </group>
@@ -463,6 +463,31 @@ class GroupAdd(TestCase):
             ]
         )
 
+    def test_validation_stonith_is_forbidden(self):
+        resources_before = """
+            <resources>
+                <primitive id="S" class="stonith" />
+                <group id="G">
+                    <primitive id="RG1" />
+                </group>
+            </resources>
+        """
+        (self.config.runner.cib.load(resources=resources_before))
+        self.env_assist.assert_raise_library_error(
+            lambda: resource.group_add(self.env_assist.get_env(), "G", ["S"])
+        )
+        self.env_assist.assert_reports(
+            [
+                fixture.error(
+                    report_codes.CANNOT_GROUP_RESOURCE_WRONG_TYPE,
+                    resource_id="S",
+                    resource_type="stonith",
+                    parent_id=None,
+                    parent_type=None,
+                ),
+            ]
+        )
+
 
 @mock.patch.object(
     settings, "pacemaker_api_result_schema", rc("pcmk_api_rng/api-result.rng")
@@ -514,6 +539,7 @@ class GroupAddWait(TestCase):
         self.env_assist.assert_reports(
             [
                 fixture.report_resource_running("G", {"Started": ["node1"]}),
+                fixture.deprecation(report_codes.RESOURCE_WAIT_DEPRECATED),
             ]
         )
 
@@ -539,5 +565,6 @@ class GroupAddWait(TestCase):
         self.env_assist.assert_reports(
             [
                 fixture.report_resource_not_running("G"),
+                fixture.deprecation(report_codes.RESOURCE_WAIT_DEPRECATED),
             ]
         )
