@@ -381,7 +381,7 @@ fixture_master_cib_unmanaged_primitive_op_disabled = """
 """
 
 
-def get_fixture_clone_group_cib(
+def get_fixture_clone_group_cib(  # noqa: PLR0913
     *,
     clone_unmanaged=False,
     clone_meta=False,
