@@ -41,6 +41,11 @@ resources_primitive = """
         <primitive id="A" />
     </resources>
 """
+resources_stonith = """
+    <resources>
+        <primitive id="S" class="stonith" />
+    </resources>
+"""
 resources_promotable = """
     <resources>
         <clone id="A-clone">
@@ -79,7 +84,22 @@ class MoveBanClearBaseMixin:
             ]
         )
 
-    def test_master_of_nonpromotable_resource(self):
+    def test_resource_is_stonith(self):
+        self.config.runner.cib.load(resources=resources_stonith)
+        self.env_assist.assert_raise_library_error(
+            lambda: self.lib_action(self.env_assist.get_env(), "S")
+        )
+        self.env_assist.assert_reports(
+            [
+                fixture.error(
+                    report_codes.COMMAND_ARGUMENT_TYPE_MISMATCH,
+                    not_accepted_type="stonith resource",
+                    command_to_use_instead=None,
+                ),
+            ]
+        )
+
+    def test_promoted_of_nonpromotable_resource(self):
         # This is a basic test which checks validation is being done. It
         # utilizes the fact all three commands (move, ban, unmove_unban) share
         # a common situation to check. Detailed validation tests are in
@@ -91,7 +111,7 @@ class MoveBanClearBaseMixin:
         self.env_assist.assert_reports(
             [
                 fixture.error(
-                    self.report_code_bad_master,
+                    self.report_code_bad_promoted,
                     resource_id="A",
                     promotable_id="",
                 ),
@@ -172,7 +192,7 @@ class MoveBanBaseMixin(MoveBanClearBaseMixin):
         )
         self.config_pcmk_action(
             resource="A-clone",
-            master=True,
+            promoted=True,
             node="node",
             lifetime="1h",
         )
@@ -216,7 +236,7 @@ class MoveBanBaseMixin(MoveBanClearBaseMixin):
 
 class MoveMixin:
     lib_action = staticmethod(resource.move)
-    report_code_bad_master = (
+    report_code_bad_promoted = (
         report_codes.CANNOT_MOVE_RESOURCE_MASTER_RESOURCE_NOT_PROMOTABLE
     )
     report_code_pcmk_error = report_codes.RESOURCE_MOVE_PCMK_ERROR
@@ -265,7 +285,7 @@ class Move(MoveMixin, MoveBanBaseMixin, TestCase):
 
 class BanMixin:
     lib_action = staticmethod(resource.ban)
-    report_code_bad_master = (
+    report_code_bad_promoted = (
         report_codes.CANNOT_BAN_RESOURCE_MASTER_RESOURCE_NOT_PROMOTABLE
     )
     report_code_pcmk_error = report_codes.RESOURCE_BAN_PCMK_ERROR
@@ -287,7 +307,7 @@ class Ban(BanMixin, MoveBanBaseMixin, TestCase):
 
 class UnmoveUnbanMixin:
     lib_action = staticmethod(resource.unmove_unban)
-    report_code_bad_master = (
+    report_code_bad_promoted = (
         report_codes.CANNOT_UNMOVE_UNBAN_RESOURCE_MASTER_RESOURCE_NOT_PROMOTABLE
     )
     report_code_pcmk_error = report_codes.RESOURCE_UNMOVE_UNBAN_PCMK_ERROR
@@ -302,7 +322,7 @@ class UnmoveUnban(UnmoveUnbanMixin, MoveBanClearBaseMixin, TestCase):
         self.config.runner.cib.load(resources=resources_promotable)
         self.config.runner.pcmk.can_clear_expired()
         self.config_pcmk_action(
-            resource="A-clone", master=True, node="node", expired=True
+            resource="A-clone", promoted=True, node="node", expired=True
         )
         self.lib_action(
             self.env_assist.get_env(),
@@ -387,6 +407,9 @@ class MoveBanWaitMixin:
             ],
             expected_in_processor=False,
         )
+        self.env_assist.assert_reports(
+            [fixture.deprecation(report_codes.RESOURCE_WAIT_DEPRECATED)]
+        )
 
     @mock.patch.object(
         settings,
@@ -406,6 +429,9 @@ class MoveBanWaitMixin:
             ],
             expected_in_processor=False,
         )
+        self.env_assist.assert_reports(
+            [fixture.deprecation(report_codes.RESOURCE_WAIT_DEPRECATED)]
+        )
 
     @mock.patch.object(
         settings,
@@ -429,6 +455,9 @@ class MoveBanWaitMixin:
             ],
             expected_in_processor=False,
         )
+        self.env_assist.assert_reports(
+            [fixture.deprecation(report_codes.RESOURCE_WAIT_DEPRECATED)]
+        )
 
     @mock.patch.object(
         settings,
@@ -466,6 +495,7 @@ class MoveBanWaitMixin:
                     report_codes.WAIT_FOR_IDLE_STARTED,
                     timeout=self.timeout,
                 ),
+                fixture.deprecation(report_codes.RESOURCE_WAIT_DEPRECATED),
             ]
         )
 
@@ -508,6 +538,7 @@ class MoveBanWaitMixin:
                     report_codes.WAIT_FOR_IDLE_STARTED,
                     timeout=self.timeout,
                 ),
+                fixture.deprecation(report_codes.RESOURCE_WAIT_DEPRECATED),
             ]
         )
 
@@ -546,6 +577,7 @@ class MoveBanWaitMixin:
                     report_codes.WAIT_FOR_IDLE_STARTED,
                     timeout=self.timeout,
                 ),
+                fixture.deprecation(report_codes.RESOURCE_WAIT_DEPRECATED),
             ]
         )
 
@@ -571,6 +603,7 @@ class MoveBanWaitMixin:
                 fixture.report_resource_not_running(
                     "A", severity=severities.ERROR
                 ),
+                fixture.deprecation(report_codes.RESOURCE_WAIT_DEPRECATED),
             ]
         )
 
@@ -592,6 +625,7 @@ class MoveBanWaitMixin:
                 fixture.report_resource_not_running(
                     "A",
                 ),
+                fixture.deprecation(report_codes.RESOURCE_WAIT_DEPRECATED),
             ]
         )
 
@@ -617,6 +651,7 @@ class MoveBanWaitMixin:
                 fixture.report_resource_running(
                     "A", {"Started": ["node1"]}, severity=severities.ERROR
                 ),
+                fixture.deprecation(report_codes.RESOURCE_WAIT_DEPRECATED),
             ]
         )
 
@@ -639,6 +674,7 @@ class MoveBanWaitMixin:
                     "A",
                     {"Started": ["node2"]},
                 ),
+                fixture.deprecation(report_codes.RESOURCE_WAIT_DEPRECATED),
             ]
         )
 
@@ -681,6 +717,7 @@ class MoveWait(MoveMixin, MoveBanWaitMixin, TestCase):
                     "A",
                     {"Started": ["node2"]},
                 ),
+                fixture.deprecation(report_codes.RESOURCE_WAIT_DEPRECATED),
             ]
         )
 
@@ -710,6 +747,7 @@ class MoveWait(MoveMixin, MoveBanWaitMixin, TestCase):
                 fixture.report_resource_running(
                     "A", {"Started": ["node1"]}, severity=severities.ERROR
                 ),
+                fixture.deprecation(report_codes.RESOURCE_WAIT_DEPRECATED),
             ]
         )
 
@@ -744,6 +782,7 @@ class BanWait(BanMixin, MoveBanWaitMixin, TestCase):
                 fixture.report_resource_running(
                     "A", {"Started": ["node1"]}, severity=severities.ERROR
                 ),
+                fixture.deprecation(report_codes.RESOURCE_WAIT_DEPRECATED),
             ]
         )
 
@@ -772,6 +811,7 @@ class BanWait(BanMixin, MoveBanWaitMixin, TestCase):
                     "A",
                     {"Started": ["node2"]},
                 ),
+                fixture.deprecation(report_codes.RESOURCE_WAIT_DEPRECATED),
             ]
         )
 
@@ -811,6 +851,7 @@ class UnmoveUnbanWait(UnmoveUnbanMixin, TestCase):
                     timeout=self.timeout,
                 ),
                 fixture.report_resource_running("A", {"Started": ["node1"]}),
+                fixture.deprecation(report_codes.RESOURCE_WAIT_DEPRECATED),
             ]
         )
 
@@ -843,6 +884,7 @@ class UnmoveUnbanWait(UnmoveUnbanMixin, TestCase):
                     report_codes.WAIT_FOR_IDLE_STARTED,
                     timeout=self.timeout,
                 ),
+                fixture.deprecation(report_codes.RESOURCE_WAIT_DEPRECATED),
             ]
         )
 
@@ -872,6 +914,7 @@ class UnmoveUnbanWait(UnmoveUnbanMixin, TestCase):
                     report_codes.WAIT_FOR_IDLE_STARTED,
                     timeout=self.timeout,
                 ),
+                fixture.deprecation(report_codes.RESOURCE_WAIT_DEPRECATED),
             ]
         )
 
@@ -904,5 +947,6 @@ class UnmoveUnbanWait(UnmoveUnbanMixin, TestCase):
                     report_codes.WAIT_FOR_IDLE_STARTED,
                     timeout=self.timeout,
                 ),
+                fixture.deprecation(report_codes.RESOURCE_WAIT_DEPRECATED),
             ]
         )
