@@ -1,22 +1,26 @@
 import logging
-from functools import partial
-from unittest import (
-    TestCase,
-    mock,
-)
+from unittest import TestCase, mock
 
 import pcs.lib.commands.alert as cmd_alert
+from pcs.common.pacemaker.alert import (
+    CibAlertDto,
+    CibAlertListDto,
+    CibAlertRecipientDto,
+    CibAlertSelectDto,
+)
+from pcs.common.pacemaker.nvset import CibNvpairDto, CibNvsetDto
+from pcs.common.pacemaker.rule import CibRuleExpressionDto
 from pcs.common.reports import ReportItemSeverity as Severities
 from pcs.common.reports import codes as report_codes
+from pcs.common.types import CibRuleExpressionType, CibRuleInEffectStatus
+from pcs.lib.cib.rule.in_effect import RuleInEffectEval
 from pcs.lib.env import LibraryEnvironment
 
 from pcs_test.tools import fixture
 from pcs_test.tools.command_env import get_env_tools
-from pcs_test.tools.custom_mock import MockLibraryReportProcessor
-
-get_env_tools = partial(
-    get_env_tools,
-    exception_reports_in_processor_by_default=False,
+from pcs_test.tools.custom_mock import (
+    MockLibraryReportProcessor,
+    RuleInEffectEvalMock,
 )
 
 
@@ -212,6 +216,7 @@ class UpdateAlertTest(TestCase):
                     None,
                 ),
             ],
+            expected_in_processor=False,
         )
 
 
@@ -313,6 +318,7 @@ class AddRecipientTest(TestCase):
                     expected_types=["alert"],
                 )
             ],
+            expected_in_processor=False,
         )
 
     def test_value_not_defined(self):
@@ -541,6 +547,7 @@ class UpdateRecipientTest(TestCase):
                     context_type="alerts",
                 )
             ],
+            expected_in_processor=False,
         )
 
     def test_update_duplicity_allowed(self):
@@ -726,8 +733,288 @@ class RemoveRecipientTest(TestCase):
         cmd_alert.remove_recipient(self.env_assist.get_env(), [])
 
 
+class GetConfigDto(TestCase):
+    fixture_alerts = """
+        <alerts>
+            <alert id="alert-all" path="/path/all" description="all options">
+                <recipient id="alert-all-recipient" value="value-all"
+                    description="all options recipient"
+                >
+                    <instance_attributes>
+                        <nvpair id="alert-all-recipient-ia"
+                            name="all-iar1-name" value="all-iar1-value"
+                        />
+                        <rule id="alert-all-recipient-ia-rule">
+                            <date_expression
+                                id="alert-all-recipient-ia-rule-de"
+                                operation="gt" end="2000-01-01"
+                            />
+                        </rule>
+                    </instance_attributes>
+                    <meta_attributes>
+                        <nvpair id="alert-all-recipient-ma"
+                            name="all-mar1-name" value="all-mar1-value"
+                        />
+                        <rule id="alert-all-recipient-ma-rule" boolean-op="and">
+                            <date_expression id="alert-all-recipient-ma-rule-de"
+                            operation="lt" end="2000-01-01" />
+                        </rule>
+                    </meta_attributes>
+                </recipient>
+                <instance_attributes>
+                    <nvpair id="alert-all-ia"
+                        name="all-iaa1-name" value="all-iaa1-value"
+                    />
+                    <rule id="alert-all-ia-rule">
+                        <date_expression id="alert-all-ia-rule-de"
+                            operation="gt" end="2000-01-01"
+                        />
+                    </rule>
+                </instance_attributes>
+                <meta_attributes>
+                    <nvpair id="alert-all-ma"
+                        name="all-maa1-name" value="all-maa1-value"
+                    />
+                    <rule id="alert-all-ma-rule" boolean-op="and">
+                        <date_expression id="alert-all-ma-rule-de"
+                        operation="lt" end="2000-01-01" />
+                    </rule>
+                </meta_attributes>
+                <select>
+                    <select_nodes />
+                    <select_attributes />
+                </select>
+            </alert>
+        </alerts>
+    """
+
+    def setUp(self):
+        self.env_assist, self.config = get_env_tools(self)
+
+    def get_alerts_dto(self, rule_eval: RuleInEffectEval) -> CibAlertListDto:
+        return CibAlertListDto(
+            [
+                CibAlertDto(
+                    id="alert-all",
+                    path="/path/all",
+                    description="all options",
+                    recipients=[
+                        CibAlertRecipientDto(
+                            id="alert-all-recipient",
+                            value="value-all",
+                            description="all options recipient",
+                            meta_attributes=[
+                                CibNvsetDto(
+                                    id="",
+                                    options={},
+                                    rule=CibRuleExpressionDto(
+                                        id="alert-all-recipient-ma-rule",
+                                        type=CibRuleExpressionType.RULE,
+                                        in_effect=rule_eval.get_rule_status(
+                                            "alert-all-recipient-ma-rule"
+                                        ),
+                                        options={"boolean-op": "and"},
+                                        date_spec=None,
+                                        duration=None,
+                                        expressions=[
+                                            CibRuleExpressionDto(
+                                                id="alert-all-recipient-ma-rule-de",
+                                                type=CibRuleExpressionType.DATE_EXPRESSION,
+                                                in_effect=CibRuleInEffectStatus.UNKNOWN,
+                                                options={
+                                                    "operation": "lt",
+                                                    "end": "2000-01-01",
+                                                },
+                                                date_spec=None,
+                                                duration=None,
+                                                expressions=[],
+                                                as_string="date lt 2000-01-01",
+                                            )
+                                        ],
+                                        as_string="date lt 2000-01-01",
+                                    ),
+                                    nvpairs=[
+                                        CibNvpairDto(
+                                            id="alert-all-recipient-ma",
+                                            name="all-mar1-name",
+                                            value="all-mar1-value",
+                                        )
+                                    ],
+                                )
+                            ],
+                            instance_attributes=[
+                                CibNvsetDto(
+                                    id="",
+                                    options={},
+                                    rule=CibRuleExpressionDto(
+                                        id="alert-all-recipient-ia-rule",
+                                        type=CibRuleExpressionType.RULE,
+                                        in_effect=rule_eval.get_rule_status(
+                                            "alert-all-recipient-ia-rule"
+                                        ),
+                                        options={},
+                                        date_spec=None,
+                                        duration=None,
+                                        expressions=[
+                                            CibRuleExpressionDto(
+                                                id="alert-all-recipient-ia-rule-de",
+                                                type=CibRuleExpressionType.DATE_EXPRESSION,
+                                                in_effect=CibRuleInEffectStatus.UNKNOWN,
+                                                options={
+                                                    "operation": "gt",
+                                                    "end": "2000-01-01",
+                                                },
+                                                date_spec=None,
+                                                duration=None,
+                                                expressions=[],
+                                                as_string="date gt 2000-01-01",
+                                            )
+                                        ],
+                                        as_string="date gt 2000-01-01",
+                                    ),
+                                    nvpairs=[
+                                        CibNvpairDto(
+                                            id="alert-all-recipient-ia",
+                                            name="all-iar1-name",
+                                            value="all-iar1-value",
+                                        )
+                                    ],
+                                )
+                            ],
+                        )
+                    ],
+                    select=CibAlertSelectDto(
+                        nodes=True,
+                        fencing=False,
+                        resources=False,
+                        attributes=True,
+                        attributes_select=[],
+                    ),
+                    meta_attributes=[
+                        CibNvsetDto(
+                            id="",
+                            options={},
+                            rule=CibRuleExpressionDto(
+                                id="alert-all-ma-rule",
+                                type=CibRuleExpressionType.RULE,
+                                in_effect=rule_eval.get_rule_status(
+                                    "alert-all-ma-rule"
+                                ),
+                                options={"boolean-op": "and"},
+                                date_spec=None,
+                                duration=None,
+                                expressions=[
+                                    CibRuleExpressionDto(
+                                        id="alert-all-ma-rule-de",
+                                        type=CibRuleExpressionType.DATE_EXPRESSION,
+                                        in_effect=CibRuleInEffectStatus.UNKNOWN,
+                                        options={
+                                            "operation": "lt",
+                                            "end": "2000-01-01",
+                                        },
+                                        date_spec=None,
+                                        duration=None,
+                                        expressions=[],
+                                        as_string="date lt 2000-01-01",
+                                    )
+                                ],
+                                as_string="date lt 2000-01-01",
+                            ),
+                            nvpairs=[
+                                CibNvpairDto(
+                                    id="alert-all-ma",
+                                    name="all-maa1-name",
+                                    value="all-maa1-value",
+                                )
+                            ],
+                        )
+                    ],
+                    instance_attributes=[
+                        CibNvsetDto(
+                            id="",
+                            options={},
+                            rule=CibRuleExpressionDto(
+                                id="alert-all-ia-rule",
+                                type=CibRuleExpressionType.RULE,
+                                in_effect=rule_eval.get_rule_status(
+                                    "alert-all-ia-rule"
+                                ),
+                                options={},
+                                date_spec=None,
+                                duration=None,
+                                expressions=[
+                                    CibRuleExpressionDto(
+                                        id="alert-all-ia-rule-de",
+                                        type=CibRuleExpressionType.DATE_EXPRESSION,
+                                        in_effect=CibRuleInEffectStatus.UNKNOWN,
+                                        options={
+                                            "operation": "gt",
+                                            "end": "2000-01-01",
+                                        },
+                                        date_spec=None,
+                                        duration=None,
+                                        expressions=[],
+                                        as_string="date gt 2000-01-01",
+                                    )
+                                ],
+                                as_string="date gt 2000-01-01",
+                            ),
+                            nvpairs=[
+                                CibNvpairDto(
+                                    id="alert-all-ia",
+                                    name="all-iaa1-name",
+                                    value="all-iaa1-value",
+                                )
+                            ],
+                        )
+                    ],
+                ),
+            ]
+        )
+
+    def test_success_no_alerts(self):
+        self.config.runner.cib.load()
+        self.assertEqual(
+            cmd_alert.get_config_dto(self.env_assist.get_env()),
+            CibAlertListDto([]),
+        )
+
+    @mock.patch("pcs.lib.commands.alert.get_rule_evaluator")
+    def test_success(self, mock_get_rule_evaluator):
+        self.config.runner.cib.load(optional_in_conf=self.fixture_alerts)
+        rule_evaluator = RuleInEffectEvalMock(
+            {
+                "alert-all-recipient-ia-rule": CibRuleInEffectStatus.IN_EFFECT,
+                "alert-all-recipient-ma-rule": CibRuleInEffectStatus.EXPIRED,
+                "alert-all-ma-rule": CibRuleInEffectStatus.EXPIRED,
+                "alert-all-ia-rule": CibRuleInEffectStatus.IN_EFFECT,
+            }
+        )
+        mock_get_rule_evaluator.return_value = rule_evaluator
+        self.assertEqual(
+            cmd_alert.get_config_dto(
+                self.env_assist.get_env(), evaluate_expired=True
+            ),
+            self.get_alerts_dto(rule_evaluator),
+        )
+        mock_get_rule_evaluator.assert_called_once()
+
+    @mock.patch("pcs.lib.cib.rule.in_effect.has_rule_in_effect_status_tool")
+    def test_success_no_rule_evaluation(self, mock_has_rule_tool):
+        mock_has_rule_tool.side_effect = AssertionError(
+            "has_rule_in_effect_status_tool should not be called"
+        )
+        self.config.runner.cib.load(optional_in_conf=self.fixture_alerts)
+        self.assertEqual(
+            cmd_alert.get_config_dto(
+                self.env_assist.get_env(), evaluate_expired=False
+            ),
+            self.get_alerts_dto(RuleInEffectEvalMock({})),
+        )
+
+
 @mock.patch.object(LibraryEnvironment, "get_cib")
-@mock.patch("pcs.lib.cib.alert.get_all_alerts")
+@mock.patch("pcs.lib.cib.alert.get_all_alerts_dict")
 class GetAllAlertsTest(TestCase):
     def setUp(self):
         self.mock_log = mock.MagicMock(spec_set=logging.Logger)
