@@ -1,4 +1,15 @@
-from unittest import mock, TestCase
+from unittest import (
+    TestCase,
+    mock,
+)
+
+import pcs.lib.commands.sbd as cmd_sbd
+from pcs import settings
+from pcs.common import reports
+from pcs.common.node_communicator import RequestTarget
+from pcs.common.reports import ReportItem
+from pcs.common.reports import ReportItemSeverity as Severities
+from pcs.lib.errors import LibraryError
 
 from pcs_test.tools import fixture
 from pcs_test.tools.assertions import (
@@ -8,18 +19,6 @@ from pcs_test.tools.assertions import (
 from pcs_test.tools.command_env import get_env_tools
 from pcs_test.tools.misc import outdent
 
-from pcs import settings
-from pcs.common import reports
-from pcs.common.node_communicator import RequestTarget
-from pcs.common.reports import (
-    ReportItem,
-    ReportItemSeverity as Severities,
-)
-from pcs.lib.errors import LibraryError
-import pcs.lib.commands.sbd as cmd_sbd
-
-# pylint: disable=protected-access
-
 
 def _assert_equal_list_of_dictionaries_without_order(expected, actual):
     for item in actual:
@@ -31,6 +30,7 @@ def _assert_equal_list_of_dictionaries_without_order(expected, actual):
 
 
 class ValidateSbdOptionsTest(TestCase):
+    # pylint: disable=protected-access
     def setUp(self):
         self.allowed_sbd_options = sorted(
             [
@@ -313,6 +313,7 @@ class ValidateSbdOptionsTest(TestCase):
 
 
 class ValidateWatchdogDictTest(TestCase):
+    # pylint: disable=protected-access
     def test_all_ok(self):
         watchdog_dict = {
             "node1": "/dev/watchdog1",
@@ -341,6 +342,7 @@ class ValidateWatchdogDictTest(TestCase):
 
 
 class GetFullTargetDictTest(TestCase):
+    # pylint: disable=protected-access
     def setUp(self):
         self.target_list = [
             RequestTarget("node{0}".format(i)) for i in range(1, 4)
