@@ -2,11 +2,11 @@
 from textwrap import dedent
 from unittest import TestCase
 
-from pcs_test.tools.assertions import ac
-
 import pcs.lib.corosync.config_facade as lib
 from pcs.lib.corosync.config_parser import Parser
 
+from pcs_test.tools.assertions import ac
+
 
 def _get_facade(config_text):
     return lib.ConfigFacade(Parser.parse(config_text.encode("utf-8")))
@@ -900,7 +900,7 @@ class RemoveLinks(TestCase):
         )
         self.assert_remove(["0", "2"], before, after)
 
-    def test_more_occurences(self):
+    def test_more_occurrences(self):
         before = dedent(
             """\
             totem {
