@@ -2,17 +2,18 @@ import re
 from textwrap import dedent
 from unittest import TestCase
 
+import pcs.lib.corosync.config_facade as lib
+from pcs.common.reports import ReportItemSeverity as severity
+from pcs.common.reports import codes as report_codes
+from pcs.lib.corosync.config_parser import Parser
+
 from pcs_test.tools import fixture
 from pcs_test.tools.assertions import (
     ac,
     assert_raise_library_error,
 )
-from pcs_test.tools.misc import get_test_resource as rc, outdent
-
-from pcs.common.reports import ReportItemSeverity as severity
-from pcs.common.reports import codes as report_codes
-import pcs.lib.corosync.config_facade as lib
-from pcs.lib.corosync.config_parser import Parser
+from pcs_test.tools.misc import get_test_resource as rc
+from pcs_test.tools.misc import outdent
 
 
 def _read_file(name):
@@ -24,83 +25,23 @@ def _get_facade(config_text):
     return lib.ConfigFacade(Parser.parse(config_text.encode("utf-8")))
 
 
-class HasQuorumDeviceTest(TestCase):
-    def test_empty_config(self):
-        config = ""
-        facade = _get_facade(config)
-        self.assertFalse(facade.has_quorum_device())
-        self.assertFalse(facade.need_stopped_cluster)
-        self.assertFalse(facade.need_qdevice_reload)
-
-    def test_no_device(self):
-        config = _read_file("corosync.conf")
-        facade = _get_facade(config)
-        self.assertFalse(facade.has_quorum_device())
-        self.assertFalse(facade.need_stopped_cluster)
-        self.assertFalse(facade.need_qdevice_reload)
-
-    def test_empty_device(self):
-        config = dedent(
-            """\
-            quorum {
-                device {
-                }
-            }
-        """
-        )
-        facade = _get_facade(config)
-        self.assertFalse(facade.has_quorum_device())
-        self.assertFalse(facade.need_stopped_cluster)
-        self.assertFalse(facade.need_qdevice_reload)
-
-    def test_device_set(self):
-        config = dedent(
-            """\
-            quorum {
-                device {
-                    model: net
-                }
-            }
-        """
-        )
-        facade = _get_facade(config)
-        self.assertTrue(facade.has_quorum_device())
-        self.assertFalse(facade.need_stopped_cluster)
-        self.assertFalse(facade.need_qdevice_reload)
-
-    def test_no_model(self):
-        config = dedent(
-            """\
-            quorum {
-                device {
-                    option: value
-                    net {
-                        host: 127.0.0.1
-                    }
-                }
-            }
-        """
-        )
-        facade = _get_facade(config)
-        self.assertFalse(facade.has_quorum_device())
-        self.assertFalse(facade.need_stopped_cluster)
-        self.assertFalse(facade.need_qdevice_reload)
-
-
-class GetQuorumDeviceModel(TestCase):
-    def assert_model(self, config, expected_model):
+class GetQuorumDeviceModelAndSettingsTest(TestCase):
+    def assert_model_and_settings(
+        self, config, expected_model, expected_settings
+    ):
         facade = _get_facade(config)
         self.assertEqual(expected_model, facade.get_quorum_device_model())
+        self.assertEqual(expected_settings, facade.get_quorum_device_settings())
         self.assertFalse(facade.need_stopped_cluster)
         self.assertFalse(facade.need_qdevice_reload)
 
     def test_empty_config(self):
         config = ""
-        self.assert_model(config, None)
+        self.assert_model_and_settings(config, None, ({}, {}, {}))
 
     def test_no_device(self):
         config = _read_file("corosync.conf")
-        self.assert_model(config, None)
+        self.assert_model_and_settings(config, None, ({}, {}, {}))
 
     def test_empty_device(self):
         config = dedent(
@@ -111,7 +52,7 @@ class GetQuorumDeviceModel(TestCase):
             }
         """
         )
-        self.assert_model(config, None)
+        self.assert_model_and_settings(config, None, ({}, {}, {}))
 
     def test_no_model(self):
         config = dedent(
@@ -126,7 +67,7 @@ class GetQuorumDeviceModel(TestCase):
             }
         """
         )
-        self.assert_model(config, None)
+        self.assert_model_and_settings(config, None, ({}, {}, {}))
 
     def test_configured_properly(self):
         config = dedent(
@@ -142,158 +83,11 @@ class GetQuorumDeviceModel(TestCase):
             }
         """
         )
-        self.assert_model(config, "net")
-
-    def test_more_devices_one_quorum(self):
-        config = dedent(
-            """\
-            quorum {
-                device {
-                    option0: valueX
-                    option1: value1
-                    model: disk
-                    net {
-                        host: 127.0.0.1
-                    }
-                    heuristics {
-                        mode: sync
-                        exec_ls: test -f /tmp/test
-                    }
-                }
-                device {
-                    option0: valueY
-                    option2: value2
-                    model: net
-                    disk {
-                        path: /dev/quorum_disk
-                    }
-                    heuristics {
-                        mode: on
-                    }
-                    heuristics {
-                        timeout: 5
-                    }
-                }
-            }
-        """
+        self.assert_model_and_settings(
+            config,
+            "net",
+            ({"host": "127.0.0.1"}, {"option": "value"}, {}),
         )
-        self.assert_model(config, "net")
-
-    def test_more_devices_more_quorum(self):
-        config = dedent(
-            """\
-            quorum {
-                device {
-                    option0: valueX
-                    option1: value1
-                    model: disk
-                    net {
-                        host: 127.0.0.1
-                    }
-                    heuristics {
-                        mode: sync
-                        exec_ls: test -f /tmp/test
-                    }
-                }
-            }
-            quorum {
-                device {
-                    option0: valueY
-                    option2: value2
-                    model: net
-                    disk {
-                        path: /dev/quorum_disk
-                    }
-                    heuristics {
-                        mode: on
-                    }
-                    heuristics {
-                        timeout: 5
-                    }
-                }
-            }
-        """
-        )
-        self.assert_model(config, "net")
-
-
-class GetQuorumDeviceSettingsTest(TestCase):
-    def test_empty_config(self):
-        config = ""
-        facade = _get_facade(config)
-        self.assertEqual(
-            (None, {}, {}, {}), facade.get_quorum_device_settings()
-        )
-        self.assertFalse(facade.need_stopped_cluster)
-        self.assertFalse(facade.need_qdevice_reload)
-
-    def test_no_device(self):
-        config = _read_file("corosync.conf")
-        facade = _get_facade(config)
-        self.assertEqual(
-            (None, {}, {}, {}), facade.get_quorum_device_settings()
-        )
-        self.assertFalse(facade.need_stopped_cluster)
-        self.assertFalse(facade.need_qdevice_reload)
-
-    def test_empty_device(self):
-        config = dedent(
-            """\
-            quorum {
-                device {
-                }
-            }
-        """
-        )
-        facade = _get_facade(config)
-        self.assertEqual(
-            (None, {}, {}, {}), facade.get_quorum_device_settings()
-        )
-        self.assertFalse(facade.need_stopped_cluster)
-        self.assertFalse(facade.need_qdevice_reload)
-
-    def test_no_model(self):
-        config = dedent(
-            """\
-            quorum {
-                device {
-                    option: value
-                    net {
-                        host: 127.0.0.1
-                    }
-                }
-            }
-        """
-        )
-        facade = _get_facade(config)
-        self.assertEqual(
-            (None, {}, {"option": "value"}, {}),
-            facade.get_quorum_device_settings(),
-        )
-        self.assertFalse(facade.need_stopped_cluster)
-        self.assertFalse(facade.need_qdevice_reload)
-
-    def test_configured_properly(self):
-        config = dedent(
-            """\
-            quorum {
-                device {
-                    option: value
-                    model: net
-                    net {
-                        host: 127.0.0.1
-                    }
-                }
-            }
-        """
-        )
-        facade = _get_facade(config)
-        self.assertEqual(
-            ("net", {"host": "127.0.0.1"}, {"option": "value"}, {}),
-            facade.get_quorum_device_settings(),
-        )
-        self.assertFalse(facade.need_stopped_cluster)
-        self.assertFalse(facade.need_qdevice_reload)
 
     def test_configured_properly_heuristics(self):
         config = dedent(
@@ -313,18 +107,15 @@ class GetQuorumDeviceSettingsTest(TestCase):
             }
         """
         )
-        facade = _get_facade(config)
-        self.assertEqual(
+        self.assert_model_and_settings(
+            config,
+            "net",
             (
-                "net",
                 {"host": "127.0.0.1"},
                 {"option": "value"},
                 {"exec_ls": "test -f /tmp/test", "mode": "on"},
             ),
-            facade.get_quorum_device_settings(),
         )
-        self.assertFalse(facade.need_stopped_cluster)
-        self.assertFalse(facade.need_qdevice_reload)
 
     def test_more_devices_one_quorum(self):
         config = dedent(
@@ -359,18 +150,15 @@ class GetQuorumDeviceSettingsTest(TestCase):
             }
         """
         )
-        facade = _get_facade(config)
-        self.assertEqual(
+        self.assert_model_and_settings(
+            config,
+            "net",
             (
-                "net",
                 {"host": "127.0.0.1"},
                 {"option0": "valueY", "option1": "value1", "option2": "value2"},
                 {"exec_ls": "test -f /tmp/test", "mode": "on", "timeout": "5"},
             ),
-            facade.get_quorum_device_settings(),
         )
-        self.assertFalse(facade.need_stopped_cluster)
-        self.assertFalse(facade.need_qdevice_reload)
 
     def test_more_devices_more_quorum(self):
         config = dedent(
@@ -407,18 +195,15 @@ class GetQuorumDeviceSettingsTest(TestCase):
             }
         """
         )
-        facade = _get_facade(config)
-        self.assertEqual(
+        self.assert_model_and_settings(
+            config,
+            "net",
             (
-                "net",
                 {"host": "127.0.0.1"},
                 {"option0": "valueY", "option1": "value1", "option2": "value2"},
                 {"exec_ls": "test -f /tmp/test", "mode": "on", "timeout": "5"},
             ),
-            facade.get_quorum_device_settings(),
         )
-        self.assertFalse(facade.need_stopped_cluster)
-        self.assertFalse(facade.need_qdevice_reload)
 
 
 class IsQuorumDeviceHeuristicsEnabledWithNoExec(TestCase):
@@ -444,6 +229,7 @@ class IsQuorumDeviceHeuristicsEnabledWithNoExec(TestCase):
             """\
             quorum {
                 device {
+                    model: net
                     heuristics {
                     }
                 }
@@ -457,6 +243,7 @@ class IsQuorumDeviceHeuristicsEnabledWithNoExec(TestCase):
             """\
             quorum {
                 device {
+                    model: net
                     heuristics {
                         mode: off
                     }
@@ -471,6 +258,7 @@ class IsQuorumDeviceHeuristicsEnabledWithNoExec(TestCase):
             """\
             quorum {
                 device {
+                    model: net
                     heuristics {
                         mode: on
                     }
@@ -485,6 +273,7 @@ class IsQuorumDeviceHeuristicsEnabledWithNoExec(TestCase):
             """\
             quorum {
                 device {
+                    model: net
                     heuristics {
                         mode: on
                         exec_ls:
@@ -500,6 +289,7 @@ class IsQuorumDeviceHeuristicsEnabledWithNoExec(TestCase):
             """\
             quorum {
                 device {
+                    model: net
                     heuristics {
                         mode: on
                         exec_ls: test -f /tmp/test
@@ -515,6 +305,7 @@ class IsQuorumDeviceHeuristicsEnabledWithNoExec(TestCase):
             """\
             quorum {
                 device {
+                    model: net
                     heuristics {
                         mode: sync
                         exec_ls: test -f /tmp/test
@@ -530,6 +321,7 @@ class IsQuorumDeviceHeuristicsEnabledWithNoExec(TestCase):
             """\
             quorum {
                 device {
+                    model: net
                     heuristics {
                         mode: unknown
                     }
@@ -544,8 +336,10 @@ class IsQuorumDeviceHeuristicsEnabledWithNoExec(TestCase):
             """\
             quorum {
                 device {
+                    model: net
                     heuristics {
                         mode: unknown
+                        exec_ls: test -f /tmp/test
                     }
                 }
             }
