@@ -318,9 +318,9 @@ class Create(TestCase):
                     min_count=1,
                     max_count=1,
                     node_name=name,
-                    node_index=id,
+                    node_index=id_,
                 )
-                for id, name in enumerate(["node1", "node2", "node3"], 1)
+                for id_, name in enumerate(["node1", "node2", "node3"], 1)
             ],
         )
 
@@ -343,9 +343,9 @@ class Create(TestCase):
                     min_count=1,
                     max_count=8,
                     node_name=name,
-                    node_index=id,
+                    node_index=id_,
                 )
-                for id, name in enumerate(["node1", "node2", "node3"], 1)
+                for id_, name in enumerate(["node1", "node2", "node3"], 1)
             ],
         )
 
@@ -1689,7 +1689,7 @@ class CreateTransportKnet(TransportKnetBase, TestCase):
         crypto_options,
         current_crypto_options=None,
     ):
-        # pylint: disable=unused-argument
+        del current_crypto_options
         return config_validators.create_transport_knet(
             generic_options, compression_options, crypto_options
         )
