@@ -305,13 +305,13 @@ class CreateQuorumOptions(BaseQuorumOptions, TestCase):
 
 
 class QuorumOptionsUpdate(BaseQuorumOptions, TestCase):
-    # pylint: disable=no-self-use
     def setUp(self):
         self.validator = lambda options, has_qdevice: (
             config_validators.update_quorum_options(options, has_qdevice, {})
         )
 
     def test_last_man_standing_required_currently_disabled(self):
+        # pylint: disable=no-self-use
         has_qdevice = False
         assert_report_item_list_equal(
             config_validators.update_quorum_options(
@@ -335,6 +335,7 @@ class QuorumOptionsUpdate(BaseQuorumOptions, TestCase):
         )
 
     def test_last_man_standing_required_currently_enabled(self):
+        # pylint: disable=no-self-use
         has_qdevice = False
         assert_report_item_list_equal(
             config_validators.update_quorum_options(
@@ -365,6 +366,8 @@ class AddQuorumDevice(TestCase):
                     "connect_timeout": "12345",
                     "force_ip_version": "4",
                     "tie_breaker": "2",
+                    "tls": "on",
+                    "keep_active_partition_tie_breaker": "on",
                 },
                 {"timeout": "23456", "sync_timeout": "34567"},
                 {
@@ -516,6 +519,8 @@ class AddQuorumDevice(TestCase):
                     "connect_timeout": "",
                     "force_ip_version": "",
                     "tie_breaker": "",
+                    "tls": "",
+                    "keep_active_partition_tie_breaker": "",
                 },
                 {
                     "timeout": "",
@@ -583,6 +588,24 @@ class AddQuorumDevice(TestCase):
                     cannot_be_empty=False,
                     forbidden_characters=None,
                 ),
+                fixture.error(
+                    report_codes.INVALID_OPTION_VALUE,
+                    force_code=report_codes.FORCE,
+                    option_name="tls",
+                    option_value="",
+                    allowed_values=("on", "off", "required"),
+                    cannot_be_empty=False,
+                    forbidden_characters=None,
+                ),
+                fixture.error(
+                    report_codes.INVALID_OPTION_VALUE,
+                    force_code=report_codes.FORCE,
+                    option_name="keep_active_partition_tie_breaker",
+                    option_value="",
+                    allowed_values=("on", "off"),
+                    cannot_be_empty=False,
+                    forbidden_characters=None,
+                ),
                 fixture.error(
                     report_codes.INVALID_OPTION_VALUE,
                     force_code=report_codes.FORCE,
@@ -659,6 +682,8 @@ class AddQuorumDevice(TestCase):
                     "connect_timeout": "-1",
                     "force_ip_version": "3",
                     "tie_breaker": "125",
+                    "tls": "bad",
+                    "keep_active_partition_tie_breaker": "30",
                     "bad_model_option": "bad model value",
                 },
                 {
@@ -711,8 +736,10 @@ class AddQuorumDevice(TestCase):
                         "connect_timeout",
                         "force_ip_version",
                         "host",
+                        "keep_active_partition_tie_breaker",
                         "port",
                         "tie_breaker",
+                        "tls",
                     ],
                     allowed_patterns=[],
                 ),
@@ -752,6 +779,24 @@ class AddQuorumDevice(TestCase):
                     cannot_be_empty=False,
                     forbidden_characters=None,
                 ),
+                fixture.error(
+                    report_codes.INVALID_OPTION_VALUE,
+                    force_code=report_codes.FORCE,
+                    option_name="tls",
+                    option_value="bad",
+                    allowed_values=("on", "off", "required"),
+                    cannot_be_empty=False,
+                    forbidden_characters=None,
+                ),
+                fixture.error(
+                    report_codes.INVALID_OPTION_VALUE,
+                    force_code=report_codes.FORCE,
+                    option_name="keep_active_partition_tie_breaker",
+                    option_value="30",
+                    allowed_values=("on", "off"),
+                    cannot_be_empty=False,
+                    forbidden_characters=None,
+                ),
                 fixture.error(
                     report_codes.INVALID_OPTIONS,
                     force_code=report_codes.FORCE,
@@ -844,6 +889,8 @@ class AddQuorumDevice(TestCase):
                     "connect_timeout": "-1",
                     "force_ip_version": "3",
                     "tie_breaker": "125",
+                    "tls": "bad",
+                    "keep_active_partition_tie_breaker": "30",
                     "bad_model_option": "bad model value",
                 },
                 {
@@ -879,8 +926,10 @@ class AddQuorumDevice(TestCase):
                         "connect_timeout",
                         "force_ip_version",
                         "host",
+                        "keep_active_partition_tie_breaker",
                         "port",
                         "tie_breaker",
+                        "tls",
                     ],
                     allowed_patterns=[],
                 ),
@@ -916,6 +965,22 @@ class AddQuorumDevice(TestCase):
                     cannot_be_empty=False,
                     forbidden_characters=None,
                 ),
+                fixture.warn(
+                    report_codes.INVALID_OPTION_VALUE,
+                    option_name="tls",
+                    option_value="bad",
+                    allowed_values=("on", "off", "required"),
+                    cannot_be_empty=False,
+                    forbidden_characters=None,
+                ),
+                fixture.warn(
+                    report_codes.INVALID_OPTION_VALUE,
+                    option_name="keep_active_partition_tie_breaker",
+                    option_value="30",
+                    allowed_values=("on", "off"),
+                    cannot_be_empty=False,
+                    forbidden_characters=None,
+                ),
                 fixture.warn(
                     report_codes.INVALID_OPTIONS,
                     option_names=["bad_generic_option"],
@@ -1146,6 +1211,8 @@ class UpdateQuorumDevice(TestCase):
                     "connect_timeout": "12345",
                     "force_ip_version": "4",
                     "tie_breaker": "2",
+                    "tls": "required",
+                    "keep_active_partition_tie_breaker": "on",
                 },
                 {"timeout": "23456", "sync_timeout": "34567"},
                 {
@@ -1170,6 +1237,8 @@ class UpdateQuorumDevice(TestCase):
                     "connect_timeout": "",
                     "force_ip_version": "",
                     "tie_breaker": "",
+                    "tls": "",
+                    "keep_active_partition_tie_breaker": "",
                 },
                 {"timeout": "", "sync_timeout": ""},
                 {
@@ -1274,6 +1343,8 @@ class UpdateQuorumDevice(TestCase):
                     "connect_timeout": "-1",
                     "force_ip_version": "3",
                     "tie_breaker": "125",
+                    "tls": "bad",
+                    "keep_active_partition_tie_breaker": "30",
                     "bad_model_option": "bad model value",
                 },
                 {},
@@ -1300,8 +1371,10 @@ class UpdateQuorumDevice(TestCase):
                         "connect_timeout",
                         "force_ip_version",
                         "host",
+                        "keep_active_partition_tie_breaker",
                         "port",
                         "tie_breaker",
+                        "tls",
                     ],
                     allowed_patterns=[],
                 ),
@@ -1341,6 +1414,24 @@ class UpdateQuorumDevice(TestCase):
                     cannot_be_empty=False,
                     forbidden_characters=None,
                 ),
+                fixture.error(
+                    report_codes.INVALID_OPTION_VALUE,
+                    report_codes.FORCE,
+                    option_name="tls",
+                    option_value="bad",
+                    allowed_values=("on", "off", "required"),
+                    cannot_be_empty=False,
+                    forbidden_characters=None,
+                ),
+                fixture.error(
+                    report_codes.INVALID_OPTION_VALUE,
+                    report_codes.FORCE,
+                    option_name="keep_active_partition_tie_breaker",
+                    option_value="30",
+                    allowed_values=("on", "off"),
+                    cannot_be_empty=False,
+                    forbidden_characters=None,
+                ),
             ],
         )
 
@@ -1354,6 +1445,8 @@ class UpdateQuorumDevice(TestCase):
                     "connect_timeout": "-1",
                     "force_ip_version": "3",
                     "tie_breaker": "125",
+                    "tls": "bad",
+                    "keep_active_partition_tie_breaker": "30",
                     "bad_model_option": "bad model value",
                 },
                 {},
@@ -1379,8 +1472,10 @@ class UpdateQuorumDevice(TestCase):
                         "connect_timeout",
                         "force_ip_version",
                         "host",
+                        "keep_active_partition_tie_breaker",
                         "port",
                         "tie_breaker",
+                        "tls",
                     ],
                     allowed_patterns=[],
                 ),
@@ -1416,6 +1511,22 @@ class UpdateQuorumDevice(TestCase):
                     cannot_be_empty=False,
                     forbidden_characters=None,
                 ),
+                fixture.warn(
+                    report_codes.INVALID_OPTION_VALUE,
+                    option_name="tls",
+                    option_value="bad",
+                    allowed_values=("on", "off", "required"),
+                    cannot_be_empty=False,
+                    forbidden_characters=None,
+                ),
+                fixture.warn(
+                    report_codes.INVALID_OPTION_VALUE,
+                    option_name="keep_active_partition_tie_breaker",
+                    option_value="30",
+                    allowed_values=("on", "off"),
+                    cannot_be_empty=False,
+                    forbidden_characters=None,
+                ),
             ],
         )
 
@@ -1677,8 +1788,10 @@ class UpdateQuorumDevice(TestCase):
                         "connect_timeout",
                         "force_ip_version",
                         "host",
+                        "keep_active_partition_tie_breaker",
                         "port",
                         "tie_breaker",
+                        "tls",
                     ],
                     allowed_patterns=[],
                 ),
