@@ -1,24 +1,17 @@
 # pylint: disable=too-many-lines
-from unittest import (
-    TestCase,
-    mock,
-)
+from unittest import TestCase, mock
 
 from lxml import etree
 
 import pcs.lib.pacemaker.live as lib
 from pcs import settings
-from pcs.common.reports import ReportItemSeverity as Severity
 from pcs.common.reports import codes as report_codes
 from pcs.common.tools import Version
 from pcs.common.types import CibRuleInEffectStatus
 from pcs.lib.external import CommandRunner
 from pcs.lib.resource_agent import ResourceAgentName
 
-from pcs_test.tools import (
-    fixture,
-    fixture_crm_mon,
-)
+from pcs_test.tools import fixture, fixture_crm_mon
 from pcs_test.tools.assertions import (
     assert_raise_library_error,
     assert_report_item_list_equal,
@@ -26,16 +19,10 @@ from pcs_test.tools.assertions import (
     start_tag_error_text,
 )
 from pcs_test.tools.command_env import get_env_tools
-from pcs_test.tools.custom_mock import (
-    TmpFileCall,
-    TmpFileMock,
-)
+from pcs_test.tools.custom_mock import TmpFileCall, TmpFileMock
 from pcs_test.tools.custom_mock import get_runner_mock as get_runner
 from pcs_test.tools.misc import get_test_resource as rc
-from pcs_test.tools.xml import (
-    XmlManipulation,
-    etree_to_str,
-)
+from pcs_test.tools.xml import XmlManipulation, etree_to_str
 
 _EXITCODE_NOT_CONNECTED = 102
 
@@ -354,11 +341,10 @@ class GetCibXmlTest(TestCase):
         assert_raise_library_error(
             lambda: lib.get_cib_xml(mock_runner),
             (
-                Severity.ERROR,
-                report_codes.CIB_LOAD_ERROR,
-                {
-                    "reason": expected_stderr + "\n" + expected_stdout,
-                },
+                fixture.error(
+                    report_codes.CIB_LOAD_ERROR,
+                    reason=expected_stderr + "\n" + expected_stdout,
+                )
             ),
         )
 
@@ -404,12 +390,11 @@ class GetCibXmlTest(TestCase):
         assert_raise_library_error(
             lambda: lib.get_cib_xml(mock_runner, scope=scope),
             (
-                Severity.ERROR,
-                report_codes.CIB_LOAD_ERROR_SCOPE_MISSING,
-                {
-                    "scope": scope,
-                    "reason": expected_stderr + "\n" + expected_stdout,
-                },
+                fixture.error(
+                    report_codes.CIB_LOAD_ERROR_SCOPE_MISSING,
+                    scope=scope,
+                    reason=expected_stderr + "\n" + expected_stdout,
+                )
             ),
         )
 
@@ -499,12 +484,11 @@ class Verify(TestCase):
                 "another output\n",
             ),
         )
-        out_stderr = []
-        for input_lines in in_stderr:
-            out_stderr.append(
-                [line for line in input_lines if "-V" not in line]
-            )
-        return zip(in_stderr, out_stderr)
+        out_stderr = [
+            [line for line in input_lines if "-V" not in line]
+            for input_lines in in_stderr
+        ]
+        return zip(in_stderr, out_stderr, strict=False)
 
     @staticmethod
     def get_in_out_unfiltered_data():
@@ -516,7 +500,7 @@ class Verify(TestCase):
                 "because line missing 'more details'\n",
             ),
         )
-        return zip(in_out_data, in_out_data)
+        return zip(in_out_data, in_out_data, strict=False)
 
     def subtest_filter_stderr_and_can_be_more_verbose(
         self,
@@ -566,6 +550,83 @@ class Verify(TestCase):
         )
 
 
+@mock.patch.object(
+    settings, "pacemaker_api_result_schema", rc("pcmk_api_rng/api-result.rng")
+)
+class GetCibVerificationErrors(TestCase):
+    fixture_ok = """
+        <pacemaker-result api-version="2.38"
+            request="crm_verify --live-check --output-as=xml"
+        >
+          <status code="0" message="OK"/>
+        </pacemaker-result>
+    """
+
+    def test_run_on_live_cib(self):
+        runner = get_runner(self.fixture_ok)
+        self.assertEqual(lib.get_cib_verification_errors(runner), [])
+        runner.run.assert_called_once_with(
+            [settings.crm_verify_exec, "--output-as", "xml", "--live-check"],
+        )
+
+    def test_run_on_mocked_cib(self):
+        fake_tmp_file = "/fake/tmp/file"
+        runner = get_runner(
+            self.fixture_ok, env_vars={"CIB_file": fake_tmp_file}
+        )
+
+        self.assertEqual(lib.get_cib_verification_errors(runner), [])
+        runner.run.assert_called_once_with(
+            [
+                settings.crm_verify_exec,
+                "--output-as",
+                "xml",
+                "--xml-file",
+                fake_tmp_file,
+            ],
+        )
+
+    def test_errors_present(self):
+        fixture_errors = """
+            <pacemaker-result api-version="2.38"
+                request="crm_verify --live-check --output-as=xml"
+            >
+              <status code="78" message="Invalid configuration">
+                <errors>
+                  <error>error: Somewthing wrong with &lt;clone&gt; bad-clone</error>
+                  <error>error: CIB did not pass schema validation</error>
+                  <error>Configuration invalid (with errors)</error>
+                </errors>
+              </status>
+            </pacemaker-result>
+        """
+        runner = get_runner(fixture_errors)
+        self.assertEqual(
+            lib.get_cib_verification_errors(runner),
+            [
+                "error: Somewthing wrong with <clone> bad-clone",
+                "error: CIB did not pass schema validation",
+                "Configuration invalid (with errors)",
+            ],
+        )
+        runner.run.assert_called_once_with(
+            [settings.crm_verify_exec, "--output-as", "xml", "--live-check"],
+        )
+
+    def test_not_xml_response(self):
+        runner = get_runner("not xml output")
+        with self.assertRaises(lib.BadApiResultFormat) as cm:
+            lib.get_cib_verification_errors(runner)
+        self.assertEqual(cm.exception.pacemaker_response, "not xml output")
+        self.assertEqual(
+            type(cm.exception.original_exception), etree.XMLSyntaxError
+        )
+
+        runner.run.assert_called_once_with(
+            [settings.crm_verify_exec, "--output-as", "xml", "--live-check"],
+        )
+
+
 class ReplaceCibConfigurationTest(TestCase):
     # pylint: disable=no-self-use
     def test_success(self):
@@ -607,12 +668,11 @@ class ReplaceCibConfigurationTest(TestCase):
                 mock_runner, XmlManipulation.from_str(xml).tree
             ),
             (
-                Severity.ERROR,
-                report_codes.CIB_PUSH_ERROR,
-                {
-                    "reason": expected_stderr,
-                    "pushed_cib": expected_stdout,
-                },
+                fixture.error(
+                    report_codes.CIB_PUSH_ERROR,
+                    reason=expected_stderr,
+                    pushed_cib=expected_stdout,
+                )
             ),
         )
 
@@ -649,11 +709,10 @@ class UpgradeCibTest(TestCase):
         assert_raise_library_error(
             lambda: lib._upgrade_cib(mock_runner),
             (
-                Severity.ERROR,
-                report_codes.CIB_UPGRADE_FAILED,
-                {
-                    "reason": expected_stderr + "\n" + expected_stdout,
-                },
+                fixture.error(
+                    report_codes.CIB_UPGRADE_FAILED,
+                    reason=expected_stderr + "\n" + expected_stdout,
+                )
             ),
         )
         mock_runner.run.assert_called_once_with(
@@ -715,9 +774,11 @@ class EnsureCibVersionTest(TestCase):
                 self.mock_runner, self.cib, Version(2, 3, 5)
             ),
             (
-                Severity.ERROR,
-                report_codes.CIB_UPGRADE_FAILED_TO_MINIMAL_REQUIRED_VERSION,
-                {"required_version": "2.3.5", "current_version": "2.3.4"},
+                fixture.error(
+                    report_codes.CIB_UPGRADE_FAILED_TO_MINIMAL_REQUIRED_VERSION,
+                    required_version="2.3.5",
+                    current_version="2.3.4",
+                )
             ),
         )
         mock_upgrade.assert_called_once_with(self.mock_runner)
@@ -744,11 +805,10 @@ class EnsureCibVersionTest(TestCase):
                 self.mock_runner, self.cib, Version(2, 3, 5)
             ),
             (
-                Severity.ERROR,
-                report_codes.CIB_UPGRADE_FAILED,
-                {
-                    "reason": start_tag_error_text(),
-                },
+                fixture.error(
+                    report_codes.CIB_UPGRADE_FAILED,
+                    reason=start_tag_error_text(),
+                )
             ),
         )
         mock_upgrade.assert_called_once_with(self.mock_runner)
@@ -1011,11 +1071,10 @@ class GetLocalNodeName(TestCase):
             cm.exception.args,
             [
                 (
-                    Severity.ERROR,
-                    report_codes.PACEMAKER_LOCAL_NODE_NAME_NOT_FOUND,
-                    {
-                        "reason": stderr.strip(),
-                    },
+                    fixture.error(
+                        report_codes.PACEMAKER_LOCAL_NODE_NAME_NOT_FOUND,
+                        reason=stderr.strip(),
+                    )
                 ),
             ],
         )
@@ -1138,13 +1197,12 @@ class RemoveNode(TestCase):
         assert_raise_library_error(
             lambda: lib.remove_node(mock_runner, "NODE_NAME"),
             (
-                Severity.ERROR,
-                report_codes.NODE_REMOVE_IN_PACEMAKER_FAILED,
-                {
-                    "node": "",
-                    "node_list_to_remove": ["NODE_NAME"],
-                    "reason": expected_stderr,
-                },
+                fixture.error(
+                    report_codes.NODE_REMOVE_IN_PACEMAKER_FAILED,
+                    node="",
+                    node_list_to_remove=["NODE_NAME"],
+                    reason=expected_stderr,
+                )
             ),
         )
 
@@ -1498,11 +1556,10 @@ class ResourcesWaitingTest(TestCase):
         assert_raise_library_error(
             lambda: lib.wait_for_idle(mock_runner, 0),
             (
-                Severity.ERROR,
-                report_codes.WAIT_FOR_IDLE_ERROR,
-                {
-                    "reason": expected_stderr + "\n" + expected_stdout,
-                },
+                fixture.error(
+                    report_codes.WAIT_FOR_IDLE_ERROR,
+                    reason=expected_stderr + "\n" + expected_stdout,
+                )
             ),
         )
 
@@ -1521,11 +1578,10 @@ class ResourcesWaitingTest(TestCase):
         assert_raise_library_error(
             lambda: lib.wait_for_idle(mock_runner, 0),
             (
-                Severity.ERROR,
-                report_codes.WAIT_FOR_IDLE_TIMED_OUT,
-                {
-                    "reason": expected_stderr + "\n" + expected_stdout,
-                },
+                fixture.error(
+                    report_codes.WAIT_FOR_IDLE_TIMED_OUT,
+                    reason=expected_stderr + "\n" + expected_stdout,
+                )
             ),
         )
 
@@ -1636,9 +1692,10 @@ class GetResourceDigests(TestCase):
                 self.CRM_ATTRS,
             ),
             (
-                Severity.ERROR,
-                report_codes.UNABLE_TO_GET_RESOURCE_OPERATION_DIGESTS,
-                {"output": report_output},
+                fixture.error(
+                    report_codes.UNABLE_TO_GET_RESOURCE_OPERATION_DIGESTS,
+                    output=report_output,
+                )
             ),
         )
         runner.run.assert_called_once_with(self.CALL_ARGS)
