@@ -194,8 +194,7 @@ FIXTURE_ERROR_REPORTS = [
         option_name="percentage_param",
         option_value="20",
         allowed_values=(
-            "a non-negative integer followed by '%' (e.g. 0%, 50%, "
-            "200%, ...)"
+            "a non-negative integer followed by '%' (e.g. 0%, 50%, 200%, ...)"
         ),
         cannot_be_empty=False,
         forbidden_characters=None,
@@ -341,16 +340,13 @@ class TestValidateSetClusterProperties(TestCase):
             )
             if sbd_enabled:
                 self.mock_sbd_devices.assert_called_once_with()
-                if sbd_devices:
+                if sbd_devices or (
+                    new_properties["stonith-watchdog-timeout"]
+                    in STONITH_WATCHDOG_TIMEOUT_UNSET_VALUES
+                ):
                     self.mock_sbd_timeout.assert_not_called()
                 else:
-                    if (
-                        new_properties["stonith-watchdog-timeout"]
-                        in STONITH_WATCHDOG_TIMEOUT_UNSET_VALUES
-                    ):
-                        self.mock_sbd_timeout.assert_not_called()
-                    else:
-                        self.mock_sbd_timeout.assert_called_once_with()
+                    self.mock_sbd_timeout.assert_called_once_with()
                 self.mock_sbd_devices.reset_mock()
             else:
                 self.mock_sbd_devices.assert_not_called()
