@@ -1,16 +1,18 @@
-from functools import partial
 import logging
-from unittest import mock, TestCase
-
-from pcs_test.tools.assertions import assert_raise_library_error
-from pcs_test.tools.custom_mock import MockLibraryReportProcessor
-from pcs_test.tools.misc import create_patcher
+from functools import partial
+from unittest import (
+    TestCase,
+    mock,
+)
 
 from pcs.common import file_type_codes
 from pcs.common.reports import ReportItemSeverity as severity
 from pcs.common.reports import codes as report_codes
 from pcs.lib.env import LibraryEnvironment
 
+from pcs_test.tools.assertions import assert_raise_library_error
+from pcs_test.tools.custom_mock import MockLibraryReportProcessor
+from pcs_test.tools.misc import create_patcher
 
 patch_env = create_patcher("pcs.lib.env")
 patch_env_object = partial(mock.patch.object, LibraryEnvironment)
