@@ -171,14 +171,13 @@ class ConstraintConfigCmdSpaceInDate(ConstraintConfigCmdMixin, TestCase):
 
     def _get_as_json(self, runner, use_all):
         data = super()._get_as_json(runner, use_all)
-        data = self._replace(
+        return self._replace(
             data,
             [
                 ("2023-01-01 12:00", "2023-01-01T12:00"),
                 ("2023-12-31 12:00", "2023-12-31T12:00"),
             ],
         )
-        return data
 
     def test_commands(self):
         stdout, stderr, retval = self.pcs_runner_orig.run(
@@ -276,7 +275,7 @@ class ConstraintConfigCmdUnsupported(TestCase):
                 f"Warning: Lifetime configuration detected in constraint 'location-lifetime' but {sufix}"
                 f"Warning: Option 'influence' detected in constraint 'colocation-influence' but {sufix}"
                 f"Warning: Lifetime configuration detected in constraint 'colocation-lifetime' but {sufix}"
-                f"Warning: Option 'node_attribute' detected in constraint 'colocation-node-attribute' but {sufix}"
+                f"Warning: Option 'node-attribute' detected in constraint 'colocation-node-attribute' but {sufix}"
                 f"Warning: Option 'ordering' detected in resource set 'colocation-set-ordering-set' but {sufix}"
                 f"Warning: Option 'require-all' detected in constraint 'order-set-require-all' but {sufix}"
                 f"Warning: Option 'ordering' detected in resource set 'order-set-ordering-set' but {sufix}"
