@@ -38,8 +38,8 @@ class StonithConfigJson(AssertPcsMixin, TestCase):
         self.assertEqual(retval, 0)
         expected = CibResourcesDto(
             primitives=[
-                resources_dto.STONITH_S2,
                 resources_dto.STONITH_S1,
+                resources_dto.STONITH_S2,
             ],
             clones=[],
             groups=[],
@@ -65,10 +65,28 @@ class StonithConfigJson(AssertPcsMixin, TestCase):
 
 
 class StonithConfigCmd(ResourceConfigCmdMixin, TestCase):
+    sub_command = "stonith"
+    expected_json_config_stderr = FIXTURE_JSON_WARNING
+
     @staticmethod
     def _get_tmp_file_name():
         return "tier1_stonith_test_config_cib.xml"
 
+    def test_unsupported_stonith(self):
+        self.pcs_runner_orig = PcsRunner(
+            cib_file=get_test_resource("cib-unsupported-stonith-config.xml")
+        )
+        stdout, stderr, retval = self.pcs_runner_orig.run(
+            ["stonith", "config", "--output-format=cmd"]
+        )
+        self.assertEqual(retval, 0)
+        self.assertEqual(stderr, "")
+        self._run_commands(stdout)
+        self.assertEqual(
+            self._get_as_json(self.pcs_runner_new),
+            self._get_as_json(self.pcs_runner_orig),
+        )
+
 
 class StonithConfigWithLevelsCmd(TestCase):
     def setUp(self):
