@@ -2,12 +2,12 @@ from textwrap import dedent
 from unittest import TestCase
 
 from pcs_test.tools.assertions import AssertPcsMixin
-from pcs_test.tools.misc import ParametrizedTestMetaClass
-from pcs_test.tools.misc import get_test_resource as rc
 from pcs_test.tools.misc import (
+    ParametrizedTestMetaClass,
     get_tmp_file,
     write_file_to_tmpfile,
 )
+from pcs_test.tools.misc import get_test_resource as rc
 from pcs_test.tools.pcs_runner import PcsRunner
 
 coro_conf = rc("corosync.conf")
