@@ -1,5 +1,5 @@
 import os
-from typing import Optional
+from typing import Mapping, Optional
 
 from pcs import settings
 
@@ -399,10 +399,7 @@ class PcmkShortcuts:
                 ).format(agent_name, os.path.realpath(__file__), rc(""))
             )
 
-        if env:
-            env = dict(env)
-        else:
-            env = {}
+        env = dict(env) if env else {}
         env["PATH"] = ":".join(
             [
                 settings.fence_agent_execs,
@@ -554,11 +551,7 @@ class PcmkShortcuts:
                 [
                     settings.crm_attribute_exec,
                     "--list-options",
-                    (
-                        name_to_list_options_type[agent_name]
-                        if agent_name in name_to_list_options_type
-                        else agent_name
-                    ),
+                    (name_to_list_options_type.get(agent_name, agent_name)),
                     "--output-as",
                     "xml",
                 ],
@@ -648,7 +641,7 @@ class PcmkShortcuts:
             ),
         )
 
-    def resource_cleanup(
+    def resource_cleanup(  # noqa: PLR0913
         self,
         *,
         name="runner.pcmk.cleanup",
@@ -695,7 +688,7 @@ class PcmkShortcuts:
             instead=instead,
         )
 
-    def resource_refresh(
+    def resource_refresh(  # noqa: PLR0913
         self,
         *,
         name="runner.pcmk.refresh",
@@ -742,7 +735,7 @@ class PcmkShortcuts:
             instead=instead,
         )
 
-    def resource_move(
+    def resource_move(  # noqa: PLR0913
         self,
         *,
         name="runner.pcmk.resource_move",
@@ -781,7 +774,7 @@ class PcmkShortcuts:
         all_args["action"] = "--move"
         self._resource_move_ban_clear(**all_args)
 
-    def resource_ban(
+    def resource_ban(  # noqa: PLR0913
         self,
         *,
         name="runner.pcmk.resource_ban",
@@ -818,7 +811,7 @@ class PcmkShortcuts:
         all_args["action"] = "--ban"
         self._resource_move_ban_clear(**all_args)
 
-    def resource_clear(
+    def resource_clear(  # noqa: PLR0913
         self,
         *,
         name="runner.pcmk.resource_clear",
@@ -857,7 +850,7 @@ class PcmkShortcuts:
         all_args["action"] = "--clear"
         self._resource_move_ban_clear(**all_args)
 
-    def _resource_move_ban_clear(
+    def _resource_move_ban_clear(  # noqa: PLR0913
         self,
         name,
         action,
@@ -1008,18 +1001,20 @@ class PcmkShortcuts:
 
     def verify(
         self,
-        name="runner.pcmk.verify",
-        cib_tempfile=None,
-        stderr=None,
-        verbose=False,
-        env=None,
-    ):
+        name: str = "runner.pcmk.verify",
+        cib_tempfile: Optional[str] = None,
+        stderr: Optional[str] = None,
+        verbose: bool = False,
+        env: Optional[Mapping[str, str]] = None,
+    ) -> None:
         """
-        Create call that checks that wait for idle is supported
+        Create a call for running crm_verify with plaintext output
 
-        string name -- key of the call
-        string before -- key of call before which this new call is to be placed
-        dict env -- CommandRunner environment variables
+        name -- key of the call
+        cib_tempfile -- path to a file with CIB
+        stderr -- output of crm_verify
+        verbose -- run crm_verify in verbose mode
+        env -- CommandRunner environment variables
         """
         cmd = ["crm_verify"]
         if verbose:
@@ -1038,6 +1033,41 @@ class PcmkShortcuts:
             ),
         )
 
+    def verify_xml(
+        self,
+        name="runner.pcmk.verify_xml",
+        cib_tempfile: Optional[str] = None,
+        stdout: str = "",
+        stderr: str = "",
+        returncode: int = 0,
+        env: Optional[Mapping[str, str]] = None,
+    ) -> None:
+        """
+        Create a call for running crm_verify with xml output
+
+        name -- key of the call
+        cib_tempfile -- path to a file with CIB
+        stdout -- usually XML output of crm_verify
+        stderr -- error output of crm_verify, debug_messages
+        returncode -- crm_verify return code
+        env -- CommandRunner environment variables
+        """
+        cmd = ["crm_verify", "--output-as", "xml"]
+        if cib_tempfile:
+            cmd.extend(["--xml-file", cib_tempfile])
+        else:
+            cmd.append("--live-check")
+        self.__calls.place(
+            name,
+            RunnerCall(
+                cmd,
+                stdout=stdout,
+                stderr=stderr,
+                returncode=returncode,
+                env=env,
+            ),
+        )
+
     def remove_node(
         self,
         node_name,
@@ -1056,7 +1086,7 @@ class PcmkShortcuts:
             ),
         )
 
-    def simulate_cib(
+    def simulate_cib(  # noqa: PLR0913
         self,
         new_cib_filepath,
         transitions_filepath,
@@ -1147,7 +1177,7 @@ class PcmkShortcuts:
             ),
         )
 
-    def resource_agent_self_validation(
+    def resource_agent_self_validation(  # noqa: PLR0913
         self,
         attributes,
         standard="ocf",
