@@ -1,8 +1,8 @@
-from pcs_test.tools.assertions import prepare_diff
-
 from pcs.lib.corosync.config_facade import ConfigFacade
 from pcs.lib.errors import LibraryError
 
+from pcs_test.tools.assertions import prepare_diff
+
 CALL_TYPE_PUSH_COROSYNC_CONF = "CALL_TYPE_PUSH_COROSYNC_CONF"
 
 
@@ -31,7 +31,7 @@ def get_push_corosync_conf(call_queue):
     def push_corosync_conf(
         lib_env, corosync_conf_facade, skip_offline_nodes=False
     ):
-        # pylint: disable=unused-argument
+        del lib_env
         i, expected_call = call_queue.take(CALL_TYPE_PUSH_COROSYNC_CONF)
 
         if not isinstance(corosync_conf_facade, ConfigFacade):
