@@ -66,12 +66,10 @@ end
 def add_meta_attr(auth_user, resource, key, value)
   cmd = ["resource", "meta", resource, key.to_s + "=" + value.to_s]
   flags = []
-  if key.to_s == "remote-node"
-    # --force is a workaround for:
-    # 1) Error: this command is not sufficient for create guest node, use 'pcs
-    # cluster node add-guest', use --force to override
-    # 2) Error: this command is not sufficient for remove guest node, use 'pcs
-    # cluster node remove-guest', use --force to override
+  if ["remote-node", "remote-addr"].include?(key.to_s)
+    # --force is a workaround for missing guest node management in the web ui
+    # The reports generated are to prevent adding guest nodes, removing guest
+    # nodes and changing their connection parameters.
     flags << "--force"
   end
   stdout, stderr, retval = run_cmd(auth_user, PCS, *flags, "--", *cmd)
