@@ -17,7 +17,7 @@ module PcsdRemoveFile
     end
 
     def process()
-      unless File.exists? self.full_file_name
+      unless File.exist? self.full_file_name
         return PcsdExchangeFormat::result(:not_found)
       end
       begin
@@ -41,8 +41,15 @@ module PcsdRemoveFile
     end
   end
 
+  class RemovePcsDrConf < RemoveFile
+    def full_file_name
+      @full_file_name ||= PCSD_DR_CONFIG_LOCATION
+    end
+  end
+
   TYPES = {
     "pcmk_remote_authkey" => RemovePcmkRemoteAuthkey,
     "pcsd_settings" => RemovePcsdSettings,
+    "pcs_disaster_recovery_conf" => RemovePcsDrConf,
   }
 end
