@@ -153,9 +153,22 @@ class TestPcsdSettings < Test::Unit::TestCase
     assert_equal(3, cfg.version)
     assert_equal('b35f951a228ac0734d4c1e45fe73c03b18bca380', cfg.hash)
 
+    # rubygem-json shipped with ruby 3.4 changed the way JSON.pretty_generate
+    # works a bit. This results in different strings produced by the gem in
+    # ruby older that 3.4 compared to ruby 3.4+. By examining the output of
+    # JSON.pretty_generate, we can figure out which version of the gem we run
+    # against and use the correct hash for the produced string.
+    # https://bugzilla.redhat.com/show_bug.cgi?id=2331005
+    old_rubygem = JSON.pretty_generate([]) == "[\n\n]"
+    if old_rubygem
+      expected_hash = '50939a7d12d2411020f9fb42b0c411add2db39ca'
+    else
+      expected_hash = '47fdd9bd32d9771f66685664cb0e7d20c4609f25'
+    end
+
     cfg.version = 4
     assert_equal(4, cfg.version)
-    assert_equal('26579b79a27f9f56e1acd398eb761d2eb1872c6d', cfg.hash)
+    assert_equal(expected_hash, cfg.hash)
 
     cfg.text = '{
   "format_version": 2,
@@ -221,7 +234,7 @@ class TestPcsdKnownHosts < Test::Unit::TestCase
 
     cfg.version = 3
     assert_equal(3, cfg.version)
-    assert_equal('146e2be5708980d47bceb531729ba4f6a6e4a4e8', cfg.hash)
+    assert_equal('c55f29f635525d22f2935a2e26998f5ba468bbb0', cfg.hash)
 
     cfg.text = template % 4
     assert_equal(4, cfg.version)
@@ -741,32 +754,32 @@ class TestMergeKnownHosts < Test::Unit::TestCase
   def fixture_old_cfg()
     return (
 '{
-  "format_version": 1,
-  "data_version": 5,
-  "known_hosts": {
-    "node1": {
-      "dest_list": [
-        {
-          "addr": "10.0.1.1",
-          "port": 2224
-        }
-      ],
-      "token": "token1"
-    },
-    "node2": {
-      "dest_list": [
-        {
-          "addr": "10.0.1.2",
-          "port": 2234
+    "data_version": 5,
+    "format_version": 1,
+    "known_hosts": {
+        "node1": {
+            "dest_list": [
+                {
+                    "addr": "10.0.1.1",
+                    "port": 2224
+                }
+            ],
+            "token": "token1"
         },
-        {
-          "addr": "10.0.2.2",
-          "port": 2235
+        "node2": {
+            "dest_list": [
+                {
+                    "addr": "10.0.1.2",
+                    "port": 2234
+                },
+                {
+                    "addr": "10.0.2.2",
+                    "port": 2235
+                }
+            ],
+            "token": "token2"
         }
-      ],
-      "token": "token2"
     }
-  }
 }')
   end
 
@@ -814,37 +827,37 @@ class TestMergeKnownHosts < Test::Unit::TestCase
   def fixture_new_cfg(version=5)
     return (
 '{
-  "format_version": 1,
-  "data_version": %d,
-  "known_hosts": {
-    "node1": {
-      "dest_list": [
-        {
-          "addr": "10.0.1.1",
-          "port": 2224
+    "data_version": %d,
+    "format_version": 1,
+    "known_hosts": {
+        "node1": {
+            "dest_list": [
+                {
+                    "addr": "10.0.1.1",
+                    "port": 2224
+                }
+            ],
+            "token": "token1"
+        },
+        "node2": {
+            "dest_list": [
+                {
+                    "addr": "10.0.1.2",
+                    "port": 2224
+                }
+            ],
+            "token": "token2a"
+        },
+        "node3": {
+            "dest_list": [
+                {
+                    "addr": "10.0.1.3",
+                    "port": 2224
+                }
+            ],
+            "token": "token3"
         }
-      ],
-      "token": "token1"
-    },
-    "node2": {
-      "dest_list": [
-        {
-          "addr": "10.0.1.2",
-          "port": 2224
-        }
-      ],
-      "token": "token2a"
-    },
-    "node3": {
-      "dest_list": [
-        {
-          "addr": "10.0.1.3",
-          "port": 2224
-        }
-      ],
-      "token": "token3"
     }
-  }
 }' % version)
   end
 
@@ -871,18 +884,19 @@ class TestMergeKnownHosts < Test::Unit::TestCase
   def fixture_old_text()
     return (
 '{
-  "format_version": 1,
-  "data_version": 2,
-  "known_hosts": {
-    "node1": {
-      "dest_list": [
-        {
-          "addr": "10.0.1.1",
-          "port": 2224
+    "data_version": 2,
+    "format_version": 1,
+    "known_hosts": {
+        "node1": {
+            "dest_list": [
+                {
+                    "addr": "10.0.1.1",
+                    "port": 2224
+                }
+            ],
+            "token": "token1a"
         }
-      ],
-      "token": "token1a"
-  }
+    }
 }')
   end
 
@@ -1174,4 +1188,3 @@ class TestGetFailedNodesFromSyncResponses < Test::Unit::TestCase
     )
   end
 end
-
