@@ -5,6 +5,14 @@ require 'pcsd_test_utils.rb'
 require 'config.rb'
 require 'permissions.rb'
 
+def assert_equal_json(json1, json2)
+  # https://bugzilla.redhat.com/show_bug.cgi?id=2331005
+  assert_equal(
+    JSON.pretty_generate(JSON.parse(json1)),
+    JSON.pretty_generate(JSON.parse(json2))
+  )
+end
+
 class TestConfig < Test::Unit::TestCase
   def setup
     $logger = MockLogger.new
@@ -14,21 +22,21 @@ class TestConfig < Test::Unit::TestCase
   def fixture_nil_config()
     return (
 '{
-  "format_version": 2,
-  "data_version": 0,
   "clusters": [
 
   ],
+  "data_version": 0,
+  "format_version": 2,
   "permissions": {
     "local_cluster": [
       {
-        "type": "group",
-        "name": "haclient",
         "allow": [
           "grant",
           "read",
           "write"
-        ]
+        ],
+        "name": "haclient",
+        "type": "group"
       }
     ]
   }
@@ -38,11 +46,11 @@ class TestConfig < Test::Unit::TestCase
   def fixture_empty_config()
     return (
 '{
-  "format_version": 2,
-  "data_version": 0,
   "clusters": [
 
   ],
+  "data_version": 0,
+  "format_version": 2,
   "permissions": {
     "local_cluster": [
 
@@ -56,7 +64,7 @@ class TestConfig < Test::Unit::TestCase
     cfg = PCSConfig.new(text)
     assert_equal(0, cfg.clusters.length)
     assert_equal([], $logger.log)
-    assert_equal(fixture_nil_config, cfg.text)
+    assert_equal_json(fixture_nil_config, cfg.text)
   end
 
   def test_parse_empty()
@@ -64,7 +72,7 @@ class TestConfig < Test::Unit::TestCase
     cfg = PCSConfig.new(text)
     assert_equal(0, cfg.clusters.length)
     assert_equal([], $logger.log)
-    assert_equal(fixture_empty_config, cfg.text)
+    assert_equal_json(fixture_empty_config, cfg.text)
   end
 
   def test_parse_whitespace()
@@ -72,7 +80,7 @@ class TestConfig < Test::Unit::TestCase
     cfg = PCSConfig.new(text)
     assert_equal(0, cfg.clusters.length)
     assert_equal([], $logger.log)
-    assert_equal(fixture_empty_config, cfg.text)
+    assert_equal_json(fixture_empty_config, cfg.text)
   end
 
   def test_parse_hash_empty()
@@ -82,7 +90,7 @@ class TestConfig < Test::Unit::TestCase
       [['error', 'Unable to parse pcs_settings file: invalid file format']],
       $logger.log
     )
-    assert_equal(fixture_empty_config, cfg.text)
+    assert_equal_json(fixture_empty_config, cfg.text)
   end
 
   def test_parse_hash_no_version()
@@ -104,7 +112,7 @@ class TestConfig < Test::Unit::TestCase
       [['error', 'Unable to parse pcs_settings file: invalid file format']],
       $logger.log
     )
-    assert_equal(fixture_empty_config, cfg.text)
+    assert_equal_json(fixture_empty_config, cfg.text)
   end
 
   def test_parse_malformed()
@@ -126,33 +134,33 @@ class TestConfig < Test::Unit::TestCase
     assert_equal('error', $logger.log[0][0])
     assert_match(
       # the number is based on JSON gem version
-      /Unable to parse pcs_settings file: (\d+: )?unexpected token/,
+      /Unable to parse pcs_settings file: ((\d+: )?unexpected token|expected )/,
       $logger.log[0][1]
     )
-    assert_equal(fixture_empty_config, cfg.text)
+    assert_equal_json(fixture_empty_config, cfg.text)
   end
 
   def test_parse_format1_empty()
     text = '[]'
     cfg = PCSConfig.new(text)
     assert_equal(0, cfg.clusters.length)
-    assert_equal(
+    assert_equal_json(
 '{
-  "format_version": 2,
-  "data_version": 0,
   "clusters": [
 
   ],
+  "data_version": 0,
+  "format_version": 2,
   "permissions": {
     "local_cluster": [
       {
-        "type": "group",
-        "name": "haclient",
         "allow": [
           "grant",
           "read",
           "write"
-        ]
+        ],
+        "name": "haclient",
+        "type": "group"
       }
     ]
   }
@@ -177,10 +185,8 @@ class TestConfig < Test::Unit::TestCase
     assert_equal(1, cfg.clusters.length)
     assert_equal("cluster71", cfg.clusters[0].name)
     assert_equal(["rh71-node1", "rh71-node2"], cfg.clusters[0].nodes)
-    assert_equal(
+    assert_equal_json(
 '{
-  "format_version": 2,
-  "data_version": 0,
   "clusters": [
     {
       "name": "cluster71",
@@ -190,16 +196,18 @@ class TestConfig < Test::Unit::TestCase
       ]
     }
   ],
+  "data_version": 0,
+  "format_version": 2,
   "permissions": {
     "local_cluster": [
       {
-        "type": "group",
-        "name": "haclient",
         "allow": [
           "grant",
           "read",
           "write"
-        ]
+        ],
+        "name": "haclient",
+        "type": "group"
       }
     ]
   }
@@ -218,14 +226,12 @@ class TestConfig < Test::Unit::TestCase
     assert_equal(2, cfg.format_version)
     assert_equal(0, cfg.data_version)
     assert_equal(0, cfg.clusters.length)
-    assert_equal(fixture_empty_config, cfg.text)
+    assert_equal_json(fixture_empty_config, cfg.text)
   end
 
   def test_parse_format2_one_cluster()
     text =
 '{
-  "format_version": 2,
-  "data_version": 9,
   "clusters": [
     {
       "name": "cluster71",
@@ -235,6 +241,8 @@ class TestConfig < Test::Unit::TestCase
       ]
     }
   ],
+  "data_version": 9,
+  "format_version": 2,
   "permissions": {
     "local_cluster": [
 
@@ -247,7 +255,7 @@ class TestConfig < Test::Unit::TestCase
     assert_equal(1, cfg.clusters.length)
     assert_equal("cluster71", cfg.clusters[0].name)
     assert_equal(["rh71-node1", "rh71-node2"], cfg.clusters[0].nodes)
-    assert_equal(text, cfg.text)
+    assert_equal_json(text, cfg.text)
   end
 
   def test_parse_format2_two_clusters()
@@ -292,8 +300,6 @@ class TestConfig < Test::Unit::TestCase
     )
     out_text =
 '{
-  "format_version": 2,
-  "data_version": 9,
   "clusters": [
     {
       "name": "cluster71",
@@ -312,13 +318,15 @@ class TestConfig < Test::Unit::TestCase
       ]
     }
   ],
+  "data_version": 9,
+  "format_version": 2,
   "permissions": {
     "local_cluster": [
 
     ]
   }
 }'
-    assert_equal(out_text, cfg.text)
+    assert_equal_json(out_text, cfg.text)
   end
 
   def test_parse_format2_bad_cluster()
@@ -347,10 +355,8 @@ class TestConfig < Test::Unit::TestCase
     assert_equal(1, cfg.clusters.length)
     assert_equal("cluster71", cfg.clusters[0].name)
     assert_equal(["rh71-node1", "rh71-node2"], cfg.clusters[0].nodes)
-    assert_equal(
+    assert_equal_json(
 '{
-  "format_version": 2,
-  "data_version": 9,
   "clusters": [
     {
       "name": "cluster71",
@@ -360,6 +366,8 @@ class TestConfig < Test::Unit::TestCase
       ]
     }
   ],
+  "data_version": 9,
+  "format_version": 2,
   "permissions": {
     "local_cluster": [
 
@@ -426,8 +434,6 @@ class TestConfig < Test::Unit::TestCase
 }'
     out_text =
 '{
-  "format_version": 2,
-  "data_version": 9,
   "clusters": [
     {
       "name": "cluster71",
@@ -437,45 +443,47 @@ class TestConfig < Test::Unit::TestCase
       ]
     }
   ],
+  "data_version": 9,
+  "format_version": 2,
   "permissions": {
     "local_cluster": [
       {
-        "type": "group",
-        "name": "group1",
         "allow": [
           "full",
           "write"
-        ]
+        ],
+        "name": "group1",
+        "type": "group"
       },
       {
-        "type": "group",
-        "name": "group2",
         "allow": [
           "grant",
           "read"
-        ]
+        ],
+        "name": "group2",
+        "type": "group"
       },
       {
-        "type": "user",
-        "name": "user1",
         "allow": [
           "grant",
           "read",
           "write"
-        ]
+        ],
+        "name": "user1",
+        "type": "user"
       },
       {
-        "type": "user",
-        "name": "user2",
         "allow": [
 
-        ]
+        ],
+        "name": "user2",
+        "type": "user"
       }
     ]
   }
 }'
     cfg = PCSConfig.new(text)
-    assert_equal(out_text, cfg.text)
+    assert_equal_json(out_text, cfg.text)
 
     perms = cfg.permissions_local
     assert_equal(false, perms.allows?('user1', [], Permissions::FULL))
@@ -672,8 +680,8 @@ class TestCfgKnownHosts < Test::Unit::TestCase
   def fixture_empty_config()
     return(
 '{
-  "format_version": 1,
   "data_version": 0,
+  "format_version": 1,
   "known_hosts": {
   }
 }'
@@ -684,7 +692,7 @@ class TestCfgKnownHosts < Test::Unit::TestCase
     assert_equal(1, cfg.format_version)
     assert_equal(0, cfg.data_version)
     assert_equal(0, cfg.known_hosts.length)
-    assert_equal(fixture_empty_config(), cfg.text)
+    assert_equal_json(fixture_empty_config(), cfg.text)
   end
 
   def assert_known_host(host, name, token, dest_list)
@@ -723,7 +731,7 @@ class TestCfgKnownHosts < Test::Unit::TestCase
     assert_equal('error', $logger.log[0][0])
     assert_match(
       # the number is based on JSON gem version
-      /Unable to parse known-hosts file: (\d+: )?unexpected token/,
+      /Unable to parse known-hosts file: ((\d+: )?unexpected token|expected )/,
       $logger.log[0][1]
     )
     assert_empty_data(cfg)
@@ -738,8 +746,8 @@ class TestCfgKnownHosts < Test::Unit::TestCase
   def test_parse_format1_simple()
     text =
 '{
-  "format_version": 1,
   "data_version": 2,
+  "format_version": 1,
   "known_hosts": {
     "node1": {
       "dest_list": [
@@ -765,14 +773,14 @@ class TestCfgKnownHosts < Test::Unit::TestCase
       ],
       cfg.known_hosts['node1'].dest_list
     )
-    assert_equal(text, cfg.text)
+    assert_equal_json(text, cfg.text)
   end
 
   def test_parse_format1_complex()
     text =
 '{
-  "format_version": 1,
   "data_version": 2,
+  "format_version": 1,
   "known_hosts": {
     "node1": {
       "dest_list": [
@@ -825,7 +833,7 @@ class TestCfgKnownHosts < Test::Unit::TestCase
         {'addr' => '10.0.2.2', 'port' => 2235}
       ]
     )
-    assert_equal(text, cfg.text)
+    assert_equal_json(text, cfg.text)
   end
 
   def test_parse_format1_error()
@@ -888,11 +896,11 @@ class TestCfgKnownHosts < Test::Unit::TestCase
         {'addr' => '10.0.1.3', 'port' => 2224}
       ]
     )
-    assert_equal(
+    assert_equal_json(
       cfg.text,
 '{
-  "format_version": 1,
   "data_version": 3,
+  "format_version": 1,
   "known_hosts": {
     "node1": {
       "dest_list": [
